package edu.georgetown.gucs.experiment;

import javafx.application.Application;
import javafx.embed.swing.SwingFXUtils;
import javafx.scene.Scene;
import javafx.scene.chart.CategoryAxis;
import javafx.scene.chart.LineChart;
import javafx.scene.chart.NumberAxis;
import javafx.scene.chart.XYChart;
import javafx.scene.image.WritableImage;
import javafx.stage.Stage;

import javax.imageio.ImageIO;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * @author Evan B.
 * @since 09/12/14
 */
public class ExperimentGraph extends Application {

    private HashMap<String, ArrayList<Integer>> results = new HashMap<>();

    public void calculateManglerScores(List<ExperimentResults> experimentResults, String matcher) {

        for (ExperimentResults expResults : experimentResults) {

            String mangler = expResults.getMangler();
          //  System.out.println("Mangler " + mangler);

            //choose which matcher you want results for
            int score = expResults.getAverageExactScore();
            if(matcher.equalsIgnoreCase("average")) {
                score = expResults.getAverageMatcherScore();
            }

            if (results.containsKey(mangler)) {
                results.get(mangler).add(score);
            } else {
                ArrayList<Integer> scoreCard = new ArrayList<>();
                scoreCard.add(score);

                results.put(mangler, scoreCard);
            }

        }

        sumResults();

    }


    private void sumResults() {

        for (Map.Entry<String, ArrayList<Integer>> score : results.entrySet()) {

            int scoreSum = 0;
            for (Integer scoreCard : score.getValue()) {

                scoreSum += scoreCard;

            }
            
            int average; 
            if(score.getValue().size() > 0 ) {
              average =   scoreSum / score.getValue().size();
            } else {
              average = scoreSum; 
            }

            score.getValue().clear();
            score.getValue().add(average);
        }

    }

    public HashMap<String,ArrayList<Integer>> getAverages() { return results; }



    @Override
    @SuppressWarnings("unchecked")
    public void start(Stage stage) {
        stage.setTitle("Experiment Results");
        //defining the axes

        final CategoryAxis xAxis = new CategoryAxis();
        final NumberAxis yAxis = new NumberAxis();

        xAxis.setLabel("Mangler");
        // yAxis.setLabel("Score");

        //creating the chart
        final LineChart<String, Number> lineChart =
                new LineChart<>(xAxis, yAxis);

        lineChart.setAnimated(false);

        lineChart.setTitle("Experiment Results");

        //defining a series
        XYChart.Series series = new XYChart.Series();
        series.setName("Trial Results");


        //populating the series with data

        for (Map.Entry<String, ArrayList<Integer>> score : results.entrySet()) {

            //0 because the average should be the only thing in the arrayList

                series.getData().add(new XYChart.Data(score.getKey(), score.getValue().get(0)));

        }

        Scene scene = new Scene(lineChart, 800, 600);
        lineChart.getData().add(series);

        stage.setScene(scene);
        saveAsPng(scene);


        //stage.show();
    }

    public void start() {
        launch();
    }

    //modify to set the name?
    public void saveAsPng(Scene scene) {
        WritableImage image = scene.snapshot(null);
        File file = new File("expResultsChart.png");
        try {
            ImageIO.write(SwingFXUtils.fromFXImage(image, null), "png", file);
        } catch (IOException ex) {
            Logger.getLogger(ExperimentGraph.class.getName()).log(Level.SEVERE, null, ex);
        }

    }


}
