package edu.georgetown.gucs.fingerprinter;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.ArrayList;

import edu.georgetown.gucs.dictionary.Dictionary;
import edu.georgetown.gucs.utility.FileLister;
import edu.georgetown.gucs.utility.ObjectBuilder;
import edu.georgetown.gucs.utility.Pair;
import edu.georgetown.gucs.utility.Token;


/**
 * A thread worker for doing n^2 matching over all files in a
 * directory.
 * <p>
 * Based in  part on code from this answer:
 * http://stackoverflow.com/questions/8974638/blocking-queue-and-multi-threaded-consumer-how-to-know-when-to-stop
 *
 * @author Clay Shields
 */

public class BulkFingerprinterWorker extends Thread {

    private final Fingerprinter fingerprinter;
    private final List<Fingerprint> results;
    private final FileLister fileProducer;
    private final File poisonPill;
    private final BulkFingerprinter parent;


    // Takes a file and a dictionary and refernce to a Map to add the fp to
    // Creates a fingerprint
    // Returns the file name and resulting fingerprint to the parent

    public BulkFingerprinterWorker(String fingerprinterName, Dictionary dictionary, BulkFingerprinter parent,
                                   FileLister fileProducer, File poison) {

        this.fingerprinter = (Fingerprinter) ObjectBuilder.buildObject(fingerprinterName);
        this.fingerprinter.setDictionary(dictionary);
        this.parent = parent;
        this.fileProducer = fileProducer;
        this.poisonPill = poison;

        results = new ArrayList<>();
    }

    @Override
    public void run() {

        while (true) {

            File file = fileProducer.takeFile();
            if (file != poisonPill) {
                List<Fingerprint> fp = null;
                try {
                    fp = fingerprinter.computeFingerprint(file.getPath());
                } catch (IOException e) {
                    e.printStackTrace();
                }
                assert fp != null;
                for (Fingerprint currentFP : fp) {
                    //System.err.println("File: " + file + " FP: " + Converter.asHex(currentFP.getA()));
                    results.add(currentFP);
                }


            } else {
                parent.putResults(results);
                fileProducer.putPoison(poisonPill);
                break;
            }
        }

    }


}