package edu.georgetown.gucs.fingerprinter;

import edu.georgetown.gucs.utility.Token;
import org.apache.xerces.impl.dv.util.Base64;

import java.util.List;

/**
 * @author EvanBloomberg
 * @since 5/12/14
 * Utility class that allows for fingerprint to be
 */
public class Fingerprint {
    private String fileName;
    private byte[] fingerprint;
    private int start_byte;
    private int end_byte;
    private String base64Fingerprint;
    private List<Token> tokenList;

    /**
     * Defualt constructor- fingerprints are byte arrays that contain tokenized
     * dictionary information
     *
     * @param fileName    Filename that the fingerprint was created from
     * @param fingerprint an array of bytes that represent the fingerprint
     * @param start_byte  the start location of a fingerprint
     * @param end_byte    the end location of a fingerprint
     */
    public Fingerprint(String fileName, byte[] fingerprint, int start_byte, int end_byte) {
        this.fileName = fileName;
        this.fingerprint = fingerprint;
        this.start_byte = start_byte;
        this.end_byte = end_byte;
    }


    /**
     * Defualt constructor- fingerprints are byte arrays that contain tokenized
     * dictionary information
     *
     * @param fileName    Filename that the fingerprint was created from
     * @param fingerprint an array of bytes that represent the fingerprint
     * @param start_byte  the start location of a fingerprint
     * @param end_byte    the end location of a fingerprint
     */
    public Fingerprint(String fileName, byte[] fingerprint, List<Token> tokenList, int start_byte, int end_byte) {
        this.fileName = fileName;
        this.fingerprint = fingerprint;
        this.start_byte = start_byte;
        this.end_byte = end_byte;
        this.tokenList = tokenList;
    }

    /**
     * Defualt constructor- fingerprints are byte arrays that contain tokenized
     * dictionary information
     *
     * @param fileName   Filename that the fingerprint was created from
     * @param start_byte the start location of a fingerprint
     * @param end_byte   the end location of a fingerprint
     */
    public Fingerprint(String fileName, int start_byte, int end_byte) {
        this.fileName = fileName;
        this.start_byte = start_byte;
        this.end_byte = end_byte;
    }

    /**
     * Defualt constructor- fingerprints are byte arrays that contain tokenized
     * dictionary information
     *
     * @param fileName   Filename that the fingerprint was created from
     * @param start_byte the start location of a fingerprint
     * @param end_byte   the end location of a fingerprint
     */
    public Fingerprint(String fileName, String base64Fingerprint, int start_byte, int end_byte) {
        this.fileName = fileName;
        this.base64Fingerprint = base64Fingerprint;
        this.start_byte = start_byte;
        this.end_byte = end_byte;
    }


    public void setFingerprint(Fingerprint fingerprint) {
        this.fingerprint = fingerprint.getFingerprint();
        this.start_byte = fingerprint.getStartByte();
        this.end_byte = fingerprint.getEndByte();
        this.fileName = fingerprint.getFileName();
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public void setStartByte(int start_byte) {
        this.start_byte = start_byte;
    }

    public void setEndByte(int end_byte) {
        this.end_byte = end_byte;
    }

    public void setFingerprint(byte[] fingerprint) {
        this.fingerprint = fingerprint;
    }

    public byte[] getFingerprint() {
        return fingerprint;
    }

    public String getBase64Fingerprint() {
        return Base64.encode(fingerprint);
    }

    public int getStartByte() {
        return start_byte;
    }

    public int getEndByte() {
        return end_byte;
    }

    public String getFileName() {
        return fileName;
    }

    public List<Token> getTokenList() {

        return tokenList;

    }

    public void printTokenList(){

        for(Token toke : tokenList) {
            System.out.println(toke);
        }

    }
}
