package edu.georgetown.gucs.testScript;

import java.io.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

/**
 * @author evan bloomberg
 * @since 5/14/14.
 */
public class RunTest extends Thread {
    String dictionary = "";
    String directory = "";
    String input = "";
    String output = "";
    String config = "";
    String matcher = "";
    String minIdf = "";
    String maxIdf = "";
    String path = "";
    String fingerprint = "";
    String targetFingerprint = "";
    String sourceFingerprint = "";

    private static final String JAVA_CMD = "java";

    private static final String JAVA_VM_PARAM = "-jar";

    private String trialArguments;

    private List<String> optionalParameters = new ArrayList<String>();

    //arguments passed to sdText
    private List<String> sdTextParameters = new ArrayList<String>();

    /**
     * @param trialParameters the sdText trial-program to run
     * @param trialArguments  the arguments for each sdText trial
     */
    RunTest(String trialParameters,
            String trialArguments,
            String dictionary,
            String directory,
            String input,
            String output,
            String config,
            String matcher,
            String minIdf,
            String maxIdf,
            String path,
            String fingerprint,
            String targetFingerprint,
            String sourceFingerprint) {

        this.dictionary = dictionary;
        this.directory = directory;
        this.input = input;
        this.output = output;
        this.config = config;
        this.matcher = matcher;
        this.minIdf = minIdf;
        this.maxIdf = maxIdf;
        this.fingerprint = fingerprint;
        this.targetFingerprint = targetFingerprint;
        this.sourceFingerprint = sourceFingerprint;
        this.path = path;

        this.sdTextParameters.add(JAVA_CMD);
        this.sdTextParameters.add(JAVA_VM_PARAM);
        this.sdTextParameters.add(path);

        this.sdTextParameters.add(trialParameters);

        this.trialArguments = trialArguments;

    }

    public void runSdText() {
        String[] sdTextParmsArray = sdTextParameters.toArray(new String[0]);

        ProcessBuilder ps = new ProcessBuilder(sdTextParmsArray);
        ps.redirectErrorStream(true);


        StringBuilder output = new StringBuilder();
        try {
            InputStream inStream = ps.start().getInputStream();

            BufferedReader buffer = new BufferedReader(new InputStreamReader(inStream, "UTF-8"));

            String line;
            while ((line = buffer.readLine()) != null) {
                output.append(line).append(" ");
            }

            System.out.println(sdTextParmsArray[3] + ": " + output.toString() + "\n");
            // printFile(sdTextParmsArray[3], output.toString());

        } catch (IOException e) {
            e.printStackTrace();
        }

    }

    /**
     *
     */
    private void parseCommand() {

        //split array and store with other trial paramaters
        for (String cmdArgs : trialArguments.split(",")) {

            // Seperate optional paramaters
            if (cmdArgs.contains("|")) {

                optionalParameters.add(cmdArgs.substring(
                        0, cmdArgs.lastIndexOf("|")));


            } else {
                // System.out.println(sdTextParameters);
                attachUserInput(cmdArgs);
            }
        }
    }

    private void attachUserInput(String cmdArgs) {

        sdTextParameters.add(cmdArgs);

        if (cmdArgs.equalsIgnoreCase("--directory")) {
            sdTextParameters.add(directory);

        } else if (cmdArgs.equalsIgnoreCase("--Dictionary")) {
            sdTextParameters.add(dictionary);

        } else if (cmdArgs.equalsIgnoreCase("--min-idf")) {
            sdTextParameters.add(minIdf);

        } else if (cmdArgs.equalsIgnoreCase("--max-idf")) {
            sdTextParameters.add(maxIdf);

        } else if (cmdArgs.equalsIgnoreCase("--input")) {
            sdTextParameters.add(input);

        } else if (cmdArgs.equalsIgnoreCase("--output")) {
            sdTextParameters.add(output);

        } else if (cmdArgs.equalsIgnoreCase("--config")) {
            sdTextParameters.add(config);

        } else if (cmdArgs.equalsIgnoreCase("--matcher")) {
            sdTextParameters.add(matcher);

        } else if (cmdArgs.equalsIgnoreCase("--targetFingerprint")) {
            sdTextParameters.add(targetFingerprint);

        } else if (cmdArgs.equalsIgnoreCase("--sourceFingerprint")) {
            sdTextParameters.add(sourceFingerprint);

        } else if (cmdArgs.equalsIgnoreCase("--fingerprint")) {
            sdTextParameters.add(fingerprint);

        }

    }

    private synchronized void  printFile(String sdTextTrial, String sdTextResults) {
        //createFileName
        String fileName = sdTextTrial + getDateTime() + ".txt";

        Writer writer = null;
        try {
            writer = new BufferedWriter(new OutputStreamWriter(
                    new FileOutputStream(fileName), "utf-8"));

            writer.write(sdTextResults);

        } catch (IOException ex) {
            // report
        } finally {
            try {writer.close();} catch (Exception ex) {}
        }
    }

    private String getDateTime() {
        DateFormat dateFormat = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");

        Calendar cal = Calendar.getInstance();

        return dateFormat.format(cal.getTime());

    }

    @Override
    public void run() {
        //stores required and optional parameters in array list
        parseCommand();

        runSdText();


    }

    /*
        for (String command : sdTextParameters) {
            System.out.println(command);
        }
        for (String option : optionalParameters) {
            //   System.out.println("[option] " + option + " " );
        }


    // System.out.println("\n");
       private void generateSubList() {


    }

    public static void subString(String str, String rest) {
        if (rest.isEmpty()) {
            System.out.println(str);
        } else {
            subString(str + rest.charAt(0), rest.substring(1));
            subString(str, rest.substring(1));
        }
    }
     */
}

