
package edu.georgetown.gucs.utility;

import java.io.File;
import java.util.concurrent.BlockingQueue;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Thread for figuring out when the FileListerWorker threads are done and
 * need to be let go
 *
 * @author Clay Shields
 */

class FileListerHR extends Thread {

    private final ArrayList<FileListerWorker> threads;
    private final BlockingQueue<File> sharedDirectoryQueue;
    private final FileLister parent;
    private final File poison;

    private static final Logger logger = Logger.getLogger(FileListerHR.class.getName());

    /**
     * Constructor for the HR thread
     *
     * @param theThreads an array list that holds the FileListerWorkers
     * @param theQueue   the shared queue that holds the list of directories to be processes
     * @param theParent  fileLister that contains a directory of files to read
     * @param thePoison  indicates when there are no more files to choose from
     */
    FileListerHR(ArrayList<FileListerWorker> theThreads, BlockingQueue<File> theQueue,
                 FileLister theParent, File thePoison) {
        this.threads = theThreads;
        this.sharedDirectoryQueue = theQueue;
        this.parent = theParent;
        this.poison = thePoison;
    }


    /**
     * Adds the file to the existing fileLister
     */
    @Override
    public void run() {

        boolean done = false;

        try {
            while (!done) {
                // Sleep a bit while the threads run
                Thread.sleep(100);
                // Check if the queue is empty and all threads in waiting state
                if (sharedDirectoryQueue.peek() == null) {
                    int waitingThreads = 0;
                    for (FileListerWorker thread : threads) {
                        if (thread.getState() == State.valueOf("WAITING")) {
                            waitingThreads++;
                        }
                    }
                    // If so, then we are done loading.
                    if (waitingThreads == threads.size()) {
                        parent.setLoaded();
                        sharedDirectoryQueue.put(poison);
                        // The next line doens't matter, but it makes FindBugs happy
                        done = true;

                        logger.log(Level.INFO, "run", "Detected end");

                        return;

                    } else {
                        logger.log(Level.INFO, "run", "Continue");
                    }
                }
            }
        } catch (InterruptedException e) {
            ExceptionHandler.handleExceptionExit(e);
        }
    }

}
