package edu.georgetown.gucs.utility;

import java.util.Iterator;
import java.util.List;

/**
 * Creates segments from a split fingerprint
 * individual segments
 * @author Evan Bloomberg
 * @since 05/12/14.
 */
public class Segment  {
    private List<Token> fileSegment;

    private int start_byte;

    private int end_byte;

    private String fileName = null;

    /**
     * Default Segment constructor- creates sections using a split fingerprint
     * @param fileSegment list of strings that contain a particular files segment
     * @param start_byte start byte where file segment begins
     * @param end_byte end byte where segment ends
     */
    public Segment(List<Token> fileSegment, int start_byte, int end_byte) {
        this.fileSegment = fileSegment;

        this.start_byte = start_byte;

        this.end_byte = end_byte;
    }

    /**
     * Defualt constructor- creates segments using fingerprinter
     * also includes the segment filename
     * @param fileName the name of the file where the segment came from
     * @param fileSegment list of strings that contain a particular files segment
     * @param start_byte start byte where file segment begins
     * @param end_byte end byte where segment ends
     */
    public Segment(String fileName, List<Token> fileSegment, int start_byte, int end_byte) {
        this.fileName = fileName;

        this.fileSegment = fileSegment;

        this.start_byte = start_byte;

        this.end_byte = end_byte;
    }

    public void setSegment(Segment segment){
        this.fileSegment = segment.getFileSegment();

        this.fileName = segment.getFileName();

        this.start_byte = segment.getStartByte();

        this.end_byte = segment.getEndByte();
    }


    public void setFileName(String fileName){
        this.fileName = fileName;
    }

    public void setStartByte(int start_byte){
       this.start_byte = start_byte;
    }

    public void setEndByte(int end_byte){
        this.end_byte = end_byte;
    }

    public String getFileName(){
        return this.fileName;
    }

    public List<Token> getFileSegment(){
        return this.fileSegment;
    }

    public int getStartByte(){
        return this.start_byte;
    }

    public int getEndByte(){
        return this.end_byte;
    }

    public List<Token> getSegmentTokenList() { return fileSegment; }
}
