package sdtext;

/**
 * Provides the different matchers available within SDText (Similarity Digest Text)
 * 
 * @author Lindsay Neubauer
 * 
 */
enum MatcherEnum {

  /**
   * Provides a score based on a cosine similarity match to be used with a BitVectorFingerprinter
   */
  CosineSimilarityFingerprintMatcher("CosineSimilarityFingerprintMatcher"),

  /**
   * Determines if two fingerprints' documents are the same; uses a BitVectorFingerprinter
   */
  ExactFingerprintMatcher("ExactFingerprintMatcher");

  /**
   * Determines if two fingerprints match based on their HashFingerprinter hash values
   */
  // TODO MatcherEnum: Uncomment HashFingerprintMatcher
  // HashFingerprintMatcher("HashFingerprintMatcher");

  final String name;

  /**
   * Stores information about each matcher
   * 
   * @param name
   *          the string name of the matcher
   */
  MatcherEnum(String name) {
    this.name = name;
  }
}