package sdtext;

import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.datatransfer.UnsupportedFlavorException;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Locale;
import java.util.Set;
import java.util.Vector;

import javax.swing.ButtonGroup;
import javax.swing.DefaultListModel;
import javax.swing.GroupLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSpinner;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.ScrollPaneConstants;
import javax.swing.SpinnerNumberModel;
import javax.swing.SwingConstants;
import javax.swing.TransferHandler;
import edu.georgetown.gucs.utility.Global;

/**
 * Creates a handler for tokenizer selection; used with {@linkplain sdtext.GUI}.
 * 
 * @see <a href="http://www.java-forums.org/awt-swing/3030-help-drag-drop-jlist.html">Help with drag and drop on
 *      JList</a>
 * 
 * @author Lindsay Neubauer
 * 
 */
class TokenizerSelectionHandler extends TransferHandler {

  private static final long serialVersionUID = 8433300841181809587L;

    private JList source = null;
  private int[] indices = null;
  private int itemIndex = -1; // Location of item added
  private int itemsAdded = 0; // Number of items added
  private final JPanel manglerPanel = new JPanel();
  private double minLength = -1;
  private double maxLength = -1;
  DataFlavor localArrayListFlavor;
  final DataFlavor serialArrayListFlavor;
  final Vector<String> tokenizers = new Vector<String>();
  String fileTokenizerName = "FileTokenizer";
  final JRadioButton fileTokenizerOption1 = new JRadioButton("Split based on whitespace");
  final JRadioButton fileTokenizerOption2 = new JRadioButton("Split based on new line character");
  final ExperimentSelectionHandler manglerHandler = new ExperimentSelectionHandler("ManglerEnum");
  DefaultListModel tokenizerModel;
  DefaultListModel selectionModel;

  final Set<String> tokenizerSet = new HashSet<String>();

  /**
   * Constructor that sets the appropriate dataFlavor
   */
  public TokenizerSelectionHandler() {
    try {
        String localArrayListType = DataFlavor.javaJVMLocalObjectMimeType + ";class=java.util.ArrayList";
        this.localArrayListFlavor = new DataFlavor(localArrayListType);
    } catch (ClassNotFoundException e) {
      Global.monitor.printErrorMessage("TokenizerSelectionHandler", "Unable to create data flavor");
      Global.monitor.writeToBuffer("TokenizerSelectionHandler", "TokenizerSelectionHandler",
          "Unable to create data flavor");
    }
    this.serialArrayListFlavor = new DataFlavor(ArrayList.class, "ArrayList");
    this.fileTokenizerOption1.setActionCommand(" tokens");
    this.fileTokenizerOption1.setSelected(true);
    this.fileTokenizerOption2.setActionCommand(" lines");
    String parameter = (this.fileTokenizerOption1.isSelected()) ? this.fileTokenizerOption1.getActionCommand()
        : this.fileTokenizerOption2.getActionCommand();
    this.tokenizers.add(this.fileTokenizerName + parameter);
  }

  /**
   * Creates the panel that contains tokenizer selection
   * 
   * @param layout
   *          the groupLayout to use for the tokenizer panel
   * @param includeManglers
   *          the boolean value indicating whether to display file manglers in the panel
   * @param includeAddButton
   *          the boolean value indicating whether to display an "Add" button; used in experiments
   */
  protected void createPanel(GroupLayout layout, boolean includeManglers, boolean includeAddButton) {
    JLabel fileTokenizerLabel = new JLabel("File Tokenizer");
    fileTokenizerLabel.setFont(Global.boldUnifontFont);

    JLabel manglerLabel = new JLabel("File Manglers");
    manglerLabel.setFont(Global.boldUnifontFont);
    if (includeManglers) {
      this.manglerHandler.createPanel(GUI.createGroupLayout(this.manglerPanel));
    }

    JLabel tokenizerLabel = new JLabel("Other Tokenizers");
    tokenizerLabel.setFont(Global.boldUnifontFont);

    JLabel tokenizerOptionLabel = new JLabel("Tokenizer Options");
    JLabel selectedTokenizerLabel = new JLabel("Selected Tokenizers");
    this.tokenizerModel = new DefaultListModel();
    this.selectionModel = new DefaultListModel();

    this.fileTokenizerOption1.setSelected(true);
    this.fileTokenizerOption1.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent action) {
        TokenizerSelectionHandler.this.tokenizers.set(0,
            TokenizerSelectionHandler.this.fileTokenizerName + action.getActionCommand());
        if (TokenizerSelectionHandler.this.fileTokenizerName.equals("FileTokenizer")
            || TokenizerSelectionHandler.this.fileTokenizerName.equals("GzippedFileTokenizer")) {
          TokenizerSelectionHandler.this.tokenizerModel.removeElement("StripMarkupTokenizer");
          TokenizerSelectionHandler.this.selectionModel.removeElement("StripMarkupTokenizer true");
          TokenizerSelectionHandler.this.selectionModel.removeElement("StripMarkupTokenizer false");
        } else if (TokenizerSelectionHandler.this.fileTokenizerName.equals("ChineseFileTokenizer")) {
          if (!TokenizerSelectionHandler.this.tokenizerModel.contains("MinimumLengthTokenizer")) {
            TokenizerSelectionHandler.this.tokenizerModel.addElement("MinimumLengthTokenizer");
          }
          if (!TokenizerSelectionHandler.this.tokenizerModel.contains("MaximumLengthTokenizer")) {
            TokenizerSelectionHandler.this.tokenizerModel.addElement("MaximumLengthTokenizer");
          }
        }
      }
    });
    this.fileTokenizerOption2.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent action) {
        TokenizerSelectionHandler.this.tokenizers.set(0,
            TokenizerSelectionHandler.this.fileTokenizerName + action.getActionCommand());
        if ((TokenizerSelectionHandler.this.fileTokenizerName.equals("FileTokenizer") || TokenizerSelectionHandler.this.fileTokenizerName
            .equals("GzippedFileTokenizer"))
            && !TokenizerSelectionHandler.this.tokenizerModel.contains("StripMarkupTokenizer")) {
          TokenizerSelectionHandler.this.tokenizerModel.addElement("StripMarkupTokenizer");
        } else if (TokenizerSelectionHandler.this.fileTokenizerName.contains("ChineseFileTokenizer")) {
          TokenizerSelectionHandler.this.tokenizerModel.removeElement("MinimumLengthTokenizer");
          TokenizerSelectionHandler.this.tokenizerModel.removeElement("MaximumLengthTokenizer");
          for (String tokenizerName : TokenizerSelectionHandler.this.tokenizers) {
            if (tokenizerName.contains("MinimumLengthTokenizer") || tokenizerName.contains("MaximumLengthTokenizer")) {
              TokenizerSelectionHandler.this.selectionModel.removeElement(tokenizerName);
            }
          }
        }
      }
    });
    ButtonGroup fileTokenizerButtonGroup = new ButtonGroup();
    fileTokenizerButtonGroup.add(this.fileTokenizerOption1);
    fileTokenizerButtonGroup.add(this.fileTokenizerOption2);
    JPanel fileTokenizerOptions = new JPanel();
    GroupLayout optionsLayout = GUI.createGroupLayout(fileTokenizerOptions);
    optionsLayout.setHorizontalGroup(optionsLayout.createParallelGroup().addComponent(this.fileTokenizerOption1)
        .addComponent(this.fileTokenizerOption2));
    optionsLayout.setVerticalGroup(optionsLayout.createSequentialGroup().addComponent(this.fileTokenizerOption1)
        .addComponent(this.fileTokenizerOption2));

    JComboBox fileTokenizerChooser = new JComboBox();
    for (TokenizerEnum tokenizersEnum : TokenizerEnum.values()) {
      if (tokenizersEnum.name.contains("FileTokenizer")) {
        if (tokenizersEnum.name.equals("OutsideInFileTokenizer")) {
          String osName = System.getProperty("os.name").toLowerCase(Locale.ENGLISH);
          if (osName.contains("nix") || osName.contains("nux") || osName.contains("aix"))
            fileTokenizerChooser.addItem(tokenizersEnum.name);
        } else {
          fileTokenizerChooser.addItem(tokenizersEnum.name);
        }
      } else if (!tokenizersEnum.name.contains("StripMarkupTokenizer")) {
        this.tokenizerModel.addElement(tokenizersEnum.name);
      }
    }

    fileTokenizerChooser.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent event) {
        JComboBox fileChooser = (JComboBox) event.getSource();
        TokenizerSelectionHandler.this.fileTokenizerName = (String) fileChooser.getSelectedItem();
        TokenizerSelectionHandler.this.selectionModel.removeAllElements();
        TokenizerSelectionHandler.this.tokenizerModel.removeAllElements();
        TokenizerSelectionHandler.this.tokenizers.clear();

        for (TokenizerEnum tokenizer : TokenizerEnum.values()) {
          if (tokenizer.parameters.contains(TokenizerSelectionHandler.this.fileTokenizerName)) {
            if (tokenizer.name.equals("StripMarkupTokenizer")) {
              if (TokenizerSelectionHandler.this.fileTokenizerOption2.isSelected()) {
                TokenizerSelectionHandler.this.tokenizerModel.addElement(tokenizer.name);
              }
            } else if (tokenizer.name.equals("MinimumLengthTokenizer")) {
              if ((TokenizerSelectionHandler.this.fileTokenizerName.contains("Chinese") && TokenizerSelectionHandler.this.fileTokenizerOption1
                  .isSelected()) || !TokenizerSelectionHandler.this.fileTokenizerName.contains("Chinese")) {
                TokenizerSelectionHandler.this.tokenizerModel.addElement(tokenizer.name);
              }
            } else if (tokenizer.name.equals("MaximumLengthTokenizer")) {
              if ((TokenizerSelectionHandler.this.fileTokenizerName.contains("Chinese") && TokenizerSelectionHandler.this.fileTokenizerOption1
                  .isSelected()) || !TokenizerSelectionHandler.this.fileTokenizerName.contains("Chinese")) {
                TokenizerSelectionHandler.this.tokenizerModel.addElement(tokenizer.name);
              }
            } else {
              TokenizerSelectionHandler.this.tokenizerModel.addElement(tokenizer.name);
            }
          } else if (TokenizerSelectionHandler.this.fileTokenizerName.equals(tokenizer.name)) {
            String[] parameterArray = tokenizer.parameters.split("\\s");
            if (parameterArray.length > 1) {
              if (tokenizer.name.contains("Chinese")) {
                TokenizerSelectionHandler.this.fileTokenizerOption1.setText("Use probablistic word segmentation");
                TokenizerSelectionHandler.this.fileTokenizerOption2.setText("Split into individual characters");
              } else {
                TokenizerSelectionHandler.this.fileTokenizerOption1.setText("Split based on whitespace");
                TokenizerSelectionHandler.this.fileTokenizerOption2.setText("Split based on new line character");
              }
              TokenizerSelectionHandler.this.fileTokenizerOption1.setVisible(true);
              TokenizerSelectionHandler.this.fileTokenizerOption1.setSelected(true);
              TokenizerSelectionHandler.this.fileTokenizerOption1.setActionCommand(" " + parameterArray[0]);

              TokenizerSelectionHandler.this.fileTokenizerOption2.setVisible(true);
              TokenizerSelectionHandler.this.fileTokenizerOption2.setActionCommand(" " + parameterArray[1]);
            } else {
              TokenizerSelectionHandler.this.fileTokenizerOption1.setVisible(false);
              TokenizerSelectionHandler.this.fileTokenizerOption1.setActionCommand("");

              TokenizerSelectionHandler.this.fileTokenizerOption2.setVisible(false);
              TokenizerSelectionHandler.this.fileTokenizerOption2.setActionCommand("");
            }
            TokenizerSelectionHandler.this.tokenizers.add(0, TokenizerSelectionHandler.this.fileTokenizerName
                + TokenizerSelectionHandler.this.fileTokenizerOption1.getActionCommand());
          }
        }
      }
    });

    JScrollPane optionScrollPane = addTokenizerLists("TokenizerOptions", this.tokenizerModel);
    JScrollPane selectedScrollPane = addTokenizerLists("SelectedTokenizers", this.selectionModel);
    selectedScrollPane.setPreferredSize(new Dimension(300, 180));
    optionScrollPane.setPreferredSize(selectedScrollPane.getPreferredSize());

    JLabel blank1 = new JLabel();
    JLabel blank2 = new JLabel();
    JLabel blank3 = new JLabel();
    JButton addButton = new JButton("Add Tokenizers");
    final JButton clearButton = new JButton("Delete Tokenizers");
    addButton.setVisible(includeAddButton);
    clearButton.setVisible(includeAddButton);
    clearButton.setEnabled(false);

    final SelectableTableModel tokenizerTableModel = new SelectableTableModel(new Vector<String>(), new Vector<String>(
        Arrays.asList(new String[] { "Tokenizers and Manglers" })));
    final JTable tokenizerTable = new JTable(tokenizerTableModel);
    tokenizerTable.setRowHeight(tokenizerTable.getRowHeight() * 2);
    tokenizerTable.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
    tokenizerTable.setPreferredSize(new Dimension(2500, 500));
    JScrollPane tokenizerTableScrollPane = new JScrollPane(tokenizerTable,
        ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED, ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    tokenizerTableScrollPane.setPreferredSize(new Dimension(50, 125));
    addButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent actionEvent) {
        if (TokenizerSelectionHandler.this.tokenizers.size() > 0) {
          String tokenizerString = "Tokenizer(s): "
              + TokenizerSelectionHandler.this.tokenizers.toString().replace("[", "").replace("]", "");
          String manglerString = (TokenizerSelectionHandler.this.manglerHandler.selectedVector.size() > 0) ? "Mangler(s): "
              + TokenizerSelectionHandler.this.manglerHandler.selectedVector.toString().replace("[", "")
                  .replace("]", "")
              : "Mangler(s): ";

          if (TokenizerSelectionHandler.this.tokenizerSet.add((tokenizerString + " " + manglerString).trim())) {
            if (manglerString.length() > 0) {
              tokenizerTableModel.addRow(new String[] { "<html>" + tokenizerString + "<br/>" + manglerString
                  + "</html>" });
            } else {
              tokenizerTableModel.addRow(new String[] { "<html>" + tokenizerString + "<br/> Mangler(s): </html>" });
            }
            // Remove the tokenizers and manglers once they've been added to the table
            while (TokenizerSelectionHandler.this.selectionModel.size() > 0) {
              TokenizerSelectionHandler.this.tokenizerModel.addElement(TokenizerSelectionHandler.this.selectionModel
                  .remove(0).toString().split("\\s")[0]);
            }
            while (TokenizerSelectionHandler.this.manglerHandler.selectionModel.size() > 0) {
              TokenizerSelectionHandler.this.manglerHandler.optionModel
                  .addElement(TokenizerSelectionHandler.this.manglerHandler.selectionModel.remove(0).toString()
                      .split("\\s")[0]);
            }
            TokenizerSelectionHandler.this.tokenizers.setSize(1);
            TokenizerSelectionHandler.this.manglerHandler.selectedVector.setSize(0);
            clearButton.setEnabled(true);
          }
        }
      }
    });
    clearButton.addActionListener(new ActionListener() {
      @Override
      public void actionPerformed(ActionEvent arg0) {
        int[] rows = tokenizerTable.getSelectedRows();
        for (int i = 0; i < rows.length; i++) {
          String toRemove = ((String) tokenizerTable.getValueAt(rows[i] - i, 0)).replace("<html>", "")
              .replace("</html>", "").replace("<br/>", " ").trim();
          TokenizerSelectionHandler.this.tokenizerSet.remove(toRemove);
          tokenizerTableModel.removeRow(rows[i] - i);
        }
        if (TokenizerSelectionHandler.this.tokenizerSet.size() == 0) {
          clearButton.setEnabled(false);
        }
      }
    });

    if (includeManglers) {
      JComponent[] manglerComponents = this.manglerHandler.getManglers();
      layout.setHorizontalGroup(layout
          .createParallelGroup(GroupLayout.Alignment.CENTER)
          .addGroup(
              layout
                  .createSequentialGroup()
                  .addGroup(
                      layout.createParallelGroup().addComponent(fileTokenizerLabel).addComponent(blank1)
                          .addComponent(manglerLabel).addComponent(manglerComponents[0])
                          .addComponent(manglerComponents[1]).addComponent(tokenizerLabel)
                          .addComponent(tokenizerOptionLabel).addComponent(optionScrollPane))
                  .addGroup(
                      layout.createParallelGroup().addComponent(fileTokenizerChooser)
                          .addComponent(fileTokenizerOptions).addComponent(blank2).addComponent(manglerComponents[2])
                          .addComponent(manglerComponents[3]).addComponent(blank3).addComponent(selectedTokenizerLabel)
                          .addComponent(selectedScrollPane)))
          .addGroup(layout.createSequentialGroup().addComponent(addButton).addComponent(clearButton))
          .addComponent(tokenizerTableScrollPane));
      layout.setVerticalGroup(layout
          .createSequentialGroup()
          .addGroup(
              layout
                  .createParallelGroup()
                  .addGroup(
                      layout.createSequentialGroup().addComponent(fileTokenizerLabel).addComponent(blank1)
                          .addComponent(manglerLabel).addComponent(manglerComponents[0])
                          .addComponent(manglerComponents[1]).addComponent(tokenizerLabel)
                          .addComponent(tokenizerOptionLabel).addComponent(optionScrollPane))
                  .addGroup(
                      layout.createSequentialGroup().addComponent(fileTokenizerChooser)
                          .addComponent(fileTokenizerOptions).addComponent(blank2).addComponent(manglerComponents[2])
                          .addComponent(manglerComponents[3]).addComponent(blank3).addComponent(selectedTokenizerLabel)
                          .addComponent(selectedScrollPane)))
          .addGroup(layout.createParallelGroup().addComponent(addButton).addComponent(clearButton))
          .addComponent(tokenizerTableScrollPane));
      layout.linkSize(SwingConstants.VERTICAL, fileTokenizerLabel, fileTokenizerChooser);
      layout.linkSize(SwingConstants.VERTICAL, blank1, fileTokenizerOptions);
      layout.linkSize(SwingConstants.VERTICAL, manglerLabel, blank2);
      layout.linkSize(SwingConstants.VERTICAL, manglerComponents[0], manglerComponents[2]);
      layout.linkSize(SwingConstants.VERTICAL, manglerComponents[1], manglerComponents[3]);
      layout.linkSize(SwingConstants.VERTICAL, tokenizerLabel, blank3);
      layout.linkSize(SwingConstants.VERTICAL, tokenizerOptionLabel, selectedTokenizerLabel);
      layout.linkSize(SwingConstants.VERTICAL, optionScrollPane, selectedScrollPane);
    } else {
      layout.setHorizontalGroup(layout
          .createParallelGroup(GroupLayout.Alignment.CENTER)
          .addGroup(
              layout
                  .createSequentialGroup()
                  .addGroup(
                      layout.createParallelGroup().addComponent(fileTokenizerLabel).addComponent(blank1)
                          .addComponent(tokenizerLabel).addComponent(tokenizerOptionLabel)
                          .addComponent(optionScrollPane))
                  .addGroup(
                      layout.createParallelGroup().addComponent(fileTokenizerChooser)
                          .addComponent(fileTokenizerOptions).addComponent(blank2).addComponent(selectedTokenizerLabel)
                          .addComponent(selectedScrollPane)))
          .addGroup(layout.createSequentialGroup().addComponent(addButton).addComponent(clearButton)));
      layout.setVerticalGroup(layout
          .createSequentialGroup()
          .addGroup(
              layout
                  .createParallelGroup()
                  .addGroup(
                      layout.createSequentialGroup().addComponent(fileTokenizerLabel).addComponent(blank1)
                          .addComponent(tokenizerLabel).addComponent(tokenizerOptionLabel)
                          .addComponent(optionScrollPane))
                  .addGroup(
                      layout.createSequentialGroup().addComponent(fileTokenizerChooser)
                          .addComponent(fileTokenizerOptions).addComponent(blank2).addComponent(selectedTokenizerLabel)
                          .addComponent(selectedScrollPane)))
          .addGroup(layout.createParallelGroup().addComponent(addButton).addComponent(clearButton)));
      layout.linkSize(SwingConstants.VERTICAL, fileTokenizerLabel, fileTokenizerChooser);
      layout.linkSize(SwingConstants.VERTICAL, blank1, fileTokenizerOptions);
      layout.linkSize(SwingConstants.VERTICAL, tokenizerLabel, blank2);
      layout.linkSize(SwingConstants.VERTICAL, tokenizerOptionLabel, selectedTokenizerLabel);
      layout.linkSize(SwingConstants.VERTICAL, optionScrollPane, selectedScrollPane);
    }
  }

  /**
   * Provides the tokenizers selected to use
   * 
   * @return the vector of selected tokenizers
   */
  protected Vector<String> getTokenizers() {
    return this.tokenizers;
  }

  /**
   * Provides the table containing the different groups of tokenizers to use
   * 
   * @return the set of groups of tokenizers
   */
  protected Set<String> getTokenizersAndManglers() {
    return this.tokenizerSet;
  }

  private JScrollPane addTokenizerLists(String listName, DefaultListModel listModel) {
    JList tokenizerList = new JList(listModel);
    tokenizerList.setName(listName);
    tokenizerList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    tokenizerList.setTransferHandler(this);
    tokenizerList.setDragEnabled(true);
    return new JScrollPane(tokenizerList);
  }

  @SuppressWarnings("unchecked")
  @Override
  public boolean importData(JComponent target, Transferable transferable) {
    ArrayList<String> alist = null;
    if (!canImport(target, transferable.getTransferDataFlavors())) {
      return false;
    }
    try {
      if (hasLocalArrayListFlavor(transferable.getTransferDataFlavors())) {
        alist = (ArrayList<String>) transferable.getTransferData(this.localArrayListFlavor);
      } else if (hasSerialArrayListFlavor(transferable.getTransferDataFlavors())) {
        alist = (ArrayList<String>) transferable.getTransferData(this.serialArrayListFlavor);
      } else {
        return false;
      }
    } catch (UnsupportedFlavorException ufe) {
      Global.monitor.printErrorMessage("TokenizerSelectionHandler", "Unsupported data flavor");
      Global.monitor.writeToBuffer("TokenizerSelectionHandler", "importData", "Unsupported data flavor");
      return false;
    } catch (IOException ioe) {
      Global.monitor.printErrorMessage("TokenizerSelectionHandler", "I/O exception");
      Global.monitor.writeToBuffer("TokenizerSelectionHandler", "importData", "I/O exception");
      return false;
    }

    TokenizerEnum currentTokenizer = TokenizerEnum.valueOf(((String) this.source.getSelectedValue()).split("\\s")[0]);
    // Dialog to appear only for drags from the left list and drops on the right JList
    if (target.getName().equals("SelectedTokenizers") && target != this.source) {
      if (currentTokenizer.name.contains("LengthTokenizer")) {
        int value = 15;
        JPanel spinnerPanel = new JPanel(new GridLayout(2, 1));
        JPanel percentPanel = new JPanel(new GridLayout(1, 2));
        if (currentTokenizer.name.contains("Min")) {
          value = (this.fileTokenizerName.equals("ChineseFileTokenizer")) ? 2 : 3;
          spinnerPanel.add(new JLabel("Eliminates tokens that are shorter than the given length"));
          percentPanel.add(new JLabel("Minimum Token Length: "));
        } else {
          value = (this.fileTokenizerName.equals("ChineseFileTokenizer")) ? 4 : 15;
          spinnerPanel.add(new JLabel("Eliminates tokens that are longer than the given length"));
          percentPanel.add(new JLabel("Maximum Token Length: "));
        }
        JSpinner spinner = new JSpinner(new SpinnerNumberModel(value, 1, 100, 1));
        percentPanel.add(spinner);
        spinnerPanel.add(percentPanel);
        int retVal = JOptionPane.showConfirmDialog(target, spinnerPanel, "Length Parameter",
            JOptionPane.DEFAULT_OPTION, JOptionPane.QUESTION_MESSAGE);
        if (retVal == JOptionPane.NO_OPTION || retVal == JOptionPane.CLOSED_OPTION) {
          return false;
        }
        alist.set(alist.indexOf(currentTokenizer.name),
            currentTokenizer.name + " " + String.valueOf(spinner.getValue()));
      } else if (currentTokenizer.name.equalsIgnoreCase("StopWordRemoverTokenizer")) {
        JFileChooser fileChooser = new JFileChooser();
        fileChooser.setDialogTitle("Choose a stop-word text file");
        if (fileChooser.showOpenDialog(null) != JFileChooser.APPROVE_OPTION) {
          return false;
        }
        alist.set(alist.indexOf(currentTokenizer.name), currentTokenizer.name + " "
            + fileChooser.getSelectedFile().getName());
      } else if (currentTokenizer.name.equalsIgnoreCase("StripMarkupTokenizer")) {
        int retVal = JOptionPane.showOptionDialog(target, "Keep tokens nested inside script tags?",
            "StripMarkupTokenizer: Script Tags", JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE,
            new ImageIcon("trunk/images/script.png"), new String[] { "Ignore Script Tokens", "Keep Script Tokens" },
            "Ignore Script Tokens");
        switch (retVal) {
        case 0:
          alist.set(alist.indexOf(currentTokenizer.name), currentTokenizer.name + " true");
          break;
        case 1:
          alist.set(alist.indexOf(currentTokenizer.name), currentTokenizer.name + " false");
          break;
        default:
          break;
        }
      }
    }

    if (target instanceof JList) {
      int index = ((JList) target).getSelectedIndex();

      // Dropping the same data on itself and has no effect
      if (this.source.equals(target)) {
        if (this.source.getName().equals("TokenizerOptions")) {
          return false;
        } else if (this.indices != null && index >= this.indices[0] - 1
            && index <= this.indices[this.indices.length - 1]) {
          this.indices = null;
          return true;
        }
      }

      DefaultListModel listModel = (DefaultListModel) ((JList) target).getModel();
      int max = listModel.getSize();
      if (index < 0) {
        index = max;
      } else {
        index++;
        if (index > max) {
          index = max;
        }
      }
      this.itemIndex = index;
      this.itemsAdded = alist.size();
      for (Object tokenizer : alist) {
        String tokenizerName = (String) tokenizer;
        if (target.getName().equals("TokenizerOptions")) {
          this.tokenizers.remove(tokenizerName);
          tokenizerName = tokenizerName.split("\\s")[0];
          if (tokenizerName.equalsIgnoreCase("MinimumLengthTokenizer")) {
            this.minLength = -1;
          } else if (tokenizerName.equalsIgnoreCase("MaximumLengthTokenizer")) {
            this.maxLength = -1;
          }
        } else if (target.getName().equals("SelectedTokenizers")) {
          if (tokenizerName.contains("MinimumLengthTokenizer")) {
            double minimumLength = Double.valueOf(tokenizerName.substring(tokenizerName.indexOf(" ") + 1));
            if (this.maxLength != -1 && minimumLength >= this.maxLength) {
              this.minLength = -1;
              Global.monitor.writeToBuffer("TokenizerList", "addTokenizer", "minLength=" + this.minLength
                  + "  maxLength=" + this.maxLength);
              Global.monitor.printMessage("TokenizerList", "Trying to set MinimumLengthTokenizer parameter "
                  + "to a number greater than or equal to the MaximumLengthTokenizer parameter");
              this.itemsAdded = 0;
            } else {
              this.minLength = minimumLength;
            }
          }
          if (tokenizerName.contains("MaximumLengthTokenizer")) {
            double maximumLength = Double.valueOf(tokenizerName.substring(tokenizerName.indexOf(" ") + 1));
            if (this.minLength != -1 && maximumLength <= this.minLength) {
              Global.monitor.writeToBuffer("TokenizerList", "addTokenizer", "minLength=" + this.minLength
                  + "  maxLength=" + this.maxLength);
              Global.monitor.printMessage("TokenizerList", "Trying to set MaximumLengthTokenizer parameter "
                  + "to a number less than or equal to the MinimumLengthTokenizer parameter");
              this.itemsAdded = 0;
            } else {
              this.maxLength = maximumLength;
            }
          }
          this.tokenizers.add(tokenizerName); //
        }
        if (this.itemsAdded > 0) {
          if (target.getName().equals("SelectedTokenizers")) {
            if (this.tokenizers.contains(tokenizerName)) {
              this.tokenizers.remove(tokenizerName);
            }
            this.tokenizers.add(tokenizerName);
          }
          listModel.add(index++, tokenizerName);
        }
      }
      return true;
    }
    return false;
  }

  @Override
  protected void exportDone(JComponent component, Transferable transferable, int action) {
    if (this.indices != null) {
      DefaultListModel model = (DefaultListModel) this.source.getModel();

      if (this.itemsAdded > 0) {
        if (this.source.getName().equals("SelectedTokenizers")) {
          for (int i = 0; i < this.indices.length; i++) {
            // If moving items around in the same list, need to adjust the indices accordingly
            if (this.indices[i] > this.itemIndex && this.indices[i] + this.itemsAdded < model.getSize()) {
              this.indices[i] += this.itemsAdded;
            }
          }
        }

        // TODO TokenizerSelectionHandler: If you want to add tokenizers without taking them out of the tokenizerOptions
        // list, alter below
        for (int i = this.indices.length - 1; i >= 0; i--) {
          model.remove(this.indices[i]);
        }
      }
    }
    this.indices = null;
    this.itemIndex = -1;
    this.itemsAdded = 0;
  }

  private boolean hasLocalArrayListFlavor(DataFlavor[] flavors) {
    if (this.localArrayListFlavor == null) {
      return false;
    }

    for (DataFlavor flavor : flavors) {
      if (flavor.equals(this.localArrayListFlavor)) {
        return true;
      }
    }
    return false;
  }

  private boolean hasSerialArrayListFlavor(DataFlavor[] flavors) {
    if (this.serialArrayListFlavor == null) {
      return false;
    }

    for (DataFlavor flavor : flavors) {
      if (flavor.equals(this.serialArrayListFlavor)) {
        return true;
      }
    }
    return false;
  }

  @Override
  public boolean canImport(JComponent c, DataFlavor[] flavors) {
    if (hasLocalArrayListFlavor(flavors)) {
      return true;
    }
    if (hasSerialArrayListFlavor(flavors)) {
      return true;
    }
    return false;
  }

  @Override
  protected Transferable createTransferable(JComponent component) {
    if (component instanceof JList) {
      this.source = (JList) component;
      this.indices = this.source.getSelectedIndices();
      Object[] values = this.source.getSelectedValues();
      if (values.length == 0) {
        return null;
      }
      ArrayList<String> alist = new ArrayList<String>(values.length);
      for (Object tokenizer : values) {
        alist.add(tokenizer.toString());
      }
      return new TokenizerListTransferable(alist);
    }
    return null;
  }

  @Override
  public int getSourceActions(JComponent c) {
    return MOVE;
  }

  private class TokenizerListTransferable implements Transferable {
    private final ArrayList<String> data;

    TokenizerListTransferable(ArrayList<String> alist) {
      this.data = alist;
    }

    @Override
    public Object getTransferData(DataFlavor flavor) throws UnsupportedFlavorException {
      if (!isDataFlavorSupported(flavor)) {
        throw new UnsupportedFlavorException(flavor);
      }
      return this.data;
    }

    @Override
    public DataFlavor[] getTransferDataFlavors() {
      return new DataFlavor[] { TokenizerSelectionHandler.this.localArrayListFlavor,
          TokenizerSelectionHandler.this.serialArrayListFlavor };
    }

    @Override
    public boolean isDataFlavorSupported(DataFlavor flavor) {
      if (TokenizerSelectionHandler.this.localArrayListFlavor.equals(flavor)) {
        return true;
      }
      if (TokenizerSelectionHandler.this.serialArrayListFlavor.equals(flavor)) {
        return true;
      }
      return false;
    }
  }
}
