/*
|  Copyright (c) Oracle Corporation 2001 - 2007.  All Rights Reserved.
|
|  This file contains material copyrighted by Oracle Corp. and is the
|  confidential unpublished property of Oracle Corp, and may not be
|  copied in whole or part, or disclosed to any third party, without the
|  written prior consent of Oracle
|
|  SCC Viewer Technology - Source file
|
|  Code:    scclostr_u.c
|  Module:  SCCLO
|  Developer:
*/

#if !defined(_DARWIN_SOURCE) || !defined(SCC_GENSTRINGS)
#include "scclo_u.h"
#include <sccid.h>
#include <sccfi.h>
#include <lomenu.h>
#endif /* !_DARWIN_SOURCE || !SCC_GENSTRINGS */

#include "lodlgstr.h"

#if defined(_DARWIN_SOURCE)

/*
|  Mac OS X
|  This source file will serve two purposes for OS X builds. First, it will
|  define the keys and default values to use for string lookups. The keys will
|  be string-ized versions of the string IDs, and the default values will be
|  the equivalent string as defined in lodlgstr.h.
|  This will also be used as input to Apple's genstrings utility for creating
|  the localizable string file (in
|  libsc_lo.bundle/Contents/Resources/English.lproj/Localizable.strings).
|  Genstrings will parse NSLocalizedStringWithDefaultValue macros to get the
|  strings for this file.
|  Genstrings will be run via a shell script build phase, which will define
|  SCC_GENSTRINGS. In this case, we want to surround the strings with the
|  NSLocalizedStringWithDefaultValue macro so genstrings can do its job.
|  During the normal build phase (SCC_GENSTRINGS not defined), the table just
|  contains C strings and the localization macro will be used by LOGetString to
|  perform the lookup.
*/

#define SCC_CASTSTRING

#if defined(SCC_GENSTRINGS)

/* Building the string table. Set up the macro call for genstrings. */
#define SCC_LOCALIZESTRING(s)  \
  NSLocalizedStringWithDefaultValue(@#s, nil, LOGetBundle(), @s, @#s)

#else

/*
|  Normal build. Construct the string literals for the key and default.
|  The key is just the string-ized ID.
*/
#define SCC_LOCALIZESTRING(s) \
  (VTCHAR *)#s, (VTCHAR *)s

#endif /* SCC_GENSTRINGS */

#else

#define SCC_CASTSTRING   (VTCHAR *)
#define SCC_LOCALIZESTRING(s)   s

#endif /* _DARWIN_SOURCE */

#define LO_FISTR_DEFINE(finame)  { SCCIDTYPE_STRING | finame,  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_##finame) }
SCCSTRINGTABLE  SCCLOStringTable[] = {

  { 0,                                                 SCC_CASTSTRING SCC_LOCALIZESTRING("unknown") },

  { SCCID_SPREADSHEETDENAME,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SPREADSHEETDENAME) },
  { SCCID_DATABASEDENAME,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DATABASEDENAME) },
  { SCCID_DOCUMENTDENAME,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DOCUMENTDENAME) },
  { SCCID_BITMAPDENAME,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_BITMAPDENAME) },
  { SCCID_ARCHIVEDENAME,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCHIVEDENAME) },
  { SCCID_HEXDENAME,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HEXDENAME) },
  { SCCID_VECTORDENAME,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VECTORDENAME) },
  { SCCID_MULTIMEDIADENAME,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIADENAME) },

  { SCCID_HARDOPTIONS,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HARDOPTIONS) },

  { SCCID_VWSTATE_OK,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_OK) },
  { SCCID_VWSTATE_ERROR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_ERROR) },
  { SCCID_VWSTATE_EMPTY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_EMPTY) },
  { SCCID_VWSTATE_PROTECTED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_PROTECTED) },
  { SCCID_VWSTATE_SORRY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_SORRY) },
  { SCCID_VWSTATE_BAILOUT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_BAILOUT) },
  { SCCID_VWSTATE_FATAL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWSTATE_FATAL) },

  { SCCID_VWMESSAGE_MEMORY,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_MEMORY) },
  { SCCID_VWMESSAGE_STREAMBAIL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_STREAMBAIL) },
  { SCCID_VWMESSAGE_FILEOPENFAILED,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_FILEOPENFAILED_U) },
  { SCCID_VWMESSAGE_MISSINGELEMENT,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_MISSINGELEMENT) },
  { SCCID_VWMESSAGE_BADFILE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_BADFILE) },
  { SCCID_VWMESSAGE_DRMFILE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_DRMFILE) },
  { SCCID_VWMESSAGE_UNSUPPORTEDCOMPRESSION,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_UNSUPPORTEDCOMPRESSION) },
  { SCCID_VWMESSAGE_SUPFILEOPENFAILS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_SUPFILEOPENFAILS) },
  { SCCID_VWMESSAGE_UNKNOWN,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_UNKNOWN) },
  { SCCID_VWMESSAGE_EMPTYFILE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_EMPTYFILE) },
  { SCCID_VWMESSAGE_EMPTYSECTION,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_EMPTYSECTION) },
  { SCCID_VWMESSAGE_NOFILTER,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_NOFILTER) },
  { SCCID_VWMESSAGE_WRITEERROR,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_WRITEERROR_U) },
  { SCCID_VWMESSAGE_FILECHANGED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_FILECHANGED) },
  { SCCID_VWMESSAGE_GPFAULT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_GPFAULT) },
  { SCCID_VWMESSAGE_DIVIDEBYZERO,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_DIVIDEBYZERO) },
  { SCCID_VWMESSAGE_NOSUPPORTEDFILE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_NOSUPPORTEDFILE) },

  { SCCID_VWMESSAGE_OTHEREXCEPTION,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_OTHEREXCEPTION) },
  { SCCID_VWMESSAGE_NOENGINE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_NOENGINE) },
  { SCCID_VWMESSAGE_UNKNOWNNOTVIEWED,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_UNKNOWNNOTVIEWED) },
  { SCCID_VWMESSAGE_FILTERTIMEOUT,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_FILTERTIMEOUT) },
  { SCCID_VWMESSAGE_BADCREDENTIALS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWMESSAGE_BADCREDENTIALS) },
  { SCCID_VWCLIP_CAPTION,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_CAPTION) },
  { SCCID_VWCLIP_NOMEMORY,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_NOMEMORY) },
  { SCCID_VWCLIP_NOEMBEDDED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_NOEMBEDDED_U) },

  { SCCID_VWCLIP_TEXT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_TEXT) },
  { SCCID_VWCLIP_RTF,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_RTF) },
  { SCCID_VWCLIP_WINBITMAP,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_WINBITMAP) },
  { SCCID_VWCLIP_WINDIB,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_WINDIB) },
  { SCCID_VWCLIP_WINMETAFILE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_WINMETAFILE) },

  { SCCID_VWCLIP_WINPALETTE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_WINPALETTE) },
  { SCCID_VWCLIP_MACPICT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWCLIP_MACPICT) },
  { SCCID_VWGRAF_EMBEDDEDGRAPHIC,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWGRAF_EMBEDDEDGRAPHIC) },
  { SCCID_VWGRAF_LINKEDGRAPHIC,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VWGRAF_LINKEDGRAPHIC) },

  { SCCID_PRINTABORTDLG_PAGE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PRINTABORTDLG_PAGE) },
  { SCCID_PRINTOPTIONSDLG_FONT,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PRINTOPTIONSDLG_FONT) },

  { SCCID_FILTERLISTDLG_SELECTFILTER,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_SELECTFILTER) },
  { SCCID_FILTERLISTDLG_FILTERLOAD,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_FILTERLOAD) },
  { SCCID_FILTERLISTDLG_FILTERINFO,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_FILTERINFO) },
  { SCCID_FILTERLISTDLG_REBUILD,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_REBUILD) },
  { SCCID_FILTERLISTDLG_FILEHEADER,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_FILEHEADER) },
  { SCCID_FILTERLISTDLG_WRITEINFO,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTDLG_WRITEINFO) },

  { SCCID_FONT_NORMAL,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_NORMAL) },
  { SCCID_FONT_U,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_U) },
  { SCCID_FONT_I,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_I) },
  { SCCID_FONT_UI,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_UI) },
  { SCCID_FONT_B,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_B) },
  { SCCID_FONT_BU,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_BU) },
  { SCCID_FONT_BI,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_BI) },
  { SCCID_FONT_BUI,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FONT_BUI) },

  { SCCID_FULLDAYNAME_1,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_1) },
  { SCCID_FULLDAYNAME_2,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_2) },
  { SCCID_FULLDAYNAME_3,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_3) },
  { SCCID_FULLDAYNAME_4,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_4) },
  { SCCID_FULLDAYNAME_5,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_5) },
  { SCCID_FULLDAYNAME_6,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_6) },
  { SCCID_FULLDAYNAME_7,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLDAYNAME_7) },

  { SCCID_ABBREVDAYNAME_1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_1) },
  { SCCID_ABBREVDAYNAME_2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_2) },
  { SCCID_ABBREVDAYNAME_3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_3) },
  { SCCID_ABBREVDAYNAME_4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_4) },
  { SCCID_ABBREVDAYNAME_5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_5) },
  { SCCID_ABBREVDAYNAME_6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_6) },
  { SCCID_ABBREVDAYNAME_7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVDAYNAME_7) },

  { SCCID_FULLMONTHNAME_1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_1) },
  { SCCID_FULLMONTHNAME_2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_2) },
  { SCCID_FULLMONTHNAME_3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_3) },
  { SCCID_FULLMONTHNAME_4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_4) },
  { SCCID_FULLMONTHNAME_5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_5) },
  { SCCID_FULLMONTHNAME_6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_6) },
  { SCCID_FULLMONTHNAME_7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_7) },
  { SCCID_FULLMONTHNAME_8,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_8) },
  { SCCID_FULLMONTHNAME_9,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_9) },
  { SCCID_FULLMONTHNAME_10,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_10) },
  { SCCID_FULLMONTHNAME_11,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_11) },
  { SCCID_FULLMONTHNAME_12,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FULLMONTHNAME_12) },

  { SCCID_ABBREVMONTHNAME_1,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_1) },
  { SCCID_ABBREVMONTHNAME_2,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_2) },
  { SCCID_ABBREVMONTHNAME_3,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_3) },
  { SCCID_ABBREVMONTHNAME_4,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_4) },
  { SCCID_ABBREVMONTHNAME_5,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_5) },
  { SCCID_ABBREVMONTHNAME_6,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_6) },
  { SCCID_ABBREVMONTHNAME_7,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_7) },
  { SCCID_ABBREVMONTHNAME_8,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_8) },
  { SCCID_ABBREVMONTHNAME_9,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_9) },
  { SCCID_ABBREVMONTHNAME_10,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_10) },
  { SCCID_ABBREVMONTHNAME_11,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_11) },
  { SCCID_ABBREVMONTHNAME_12,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ABBREVMONTHNAME_12) },

  { SCCID_INVALIDDATE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_INVALIDDATE) },
  { SCCID_INVALIDTIME,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_INVALIDTIME) },
  { SCCID_CELLERROR,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_CELLERROR) },
  { SCCID_TRUE,                                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_TRUE) },
  { SCCID_FALSE,                                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FALSE) },
  { SCCID_ARCMSGNODIR,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNODIR) },
  { SCCID_ARCMSGOVERWRITE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGOVERWRITE) },
  { SCCID_ARCMSGNOFILE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNOFILE) },
  { SCCID_ARCMSGFILEENCRYPTED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGFILEENCRYPTED) },
  { SCCID_ARCMSGUNKNOWNCOMP,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGUNKNOWNCOMP) },
  { SCCID_ARCMSGUNSUPPORTEDCOMP,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGUNSUPPORTEDCOMP) },
  { SCCID_ARCMSGNOSAVE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNOSAVE) },
  { SCCID_YES,                                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YES) },
  { SCCID_NO,                                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_NO) },

  { SCCID_ARCMSGDATAERROR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGDATAERROR) },
  { SCCID_ARCMSGNODECOMP,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNODECOMP) },
  { SCCID_ARCMSGDISKFULL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGDISKFULL) },
  { SCCID_ARCNAME,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCNAME) },
  { SCCID_ARCSIZE,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCSIZE) },
  { SCCID_ARCMODIFIED,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMODIFIED) },
  { SCCID_ARCSTATUSTITLE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCSTATUSTITLE) },
  { SCCID_ARCSAVEDLGTEXT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCSAVEDLGTEXT) },
  { SCCID_ARCSTOREDDIRS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCSTOREDDIRS_U) },
  { SCCID_ARCIGNORE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCIGNORE) },
  { SCCID_ARCRESTORE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCRESTORE) },
  { SCCID_ARCNONAME,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCNONAME) },
  { SCCID_ARCSIZEUNKNOWN,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCSIZEUNKNOWN) },
  { SCCID_ARCMSGNAMEUSED,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNAMEUSED) },
  { SCCID_ARCMSGNAMEUSED2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCMSGNAMEUSED2) },
  { SCCID_ARCEXTRACTING,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCEXTRACTING) },
  { SCCID_ARCDLG_BADNAMEREPLACE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMEREPLACE) },
  { SCCID_ARCDLG_BADNAMEGEN,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMEGEN) },
  { SCCID_ARCDLG_BADNAMECREATE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMECREATE) },
  { SCCID_ARCCOMMENT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCCOMMENT) },
  { SCCID_ARCTYPE,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCTYPE) },

  { SCCID_ARCORIGFORMAT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCORIGFORMAT) },
  { SCCID_ARCCHOOSEDIR,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCCHOOSEDIR) },

  { SCCID_ARCUSER,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCUSER) },
  { SCCID_ARCGROUP,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCGROUP) },
  { SCCID_ARCUSERID,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCUSERID) },
  { SCCID_ARCGROUPID,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCGROUPID) },
  { SCCID_ARCDLG_BADNAMETITLE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMETITLE) },
  { SCCID_ARCDLG_BADNAMETEXT1,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMETEXT1) },
  { SCCID_ARCDLG_BADNAMETEXT2,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMETEXT2) },
  { SCCID_ARCDLG_BADNAMEBOX,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMEBOX) },
  { SCCID_ARCDLG_BADNAMEOK,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMEOK) },
  { SCCID_ARCDLG_BADNAMECANCEL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMECANCEL) },
  { SCCID_ARCDLG_BADNAMESKIP,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMESKIP) },
  { SCCID_ARCDLG_CANTWRITE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_CANTWRITE) },
  { SCCID_ARCCLASSID,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCCLASSID) },

  { SCCID_ARCDLG_FILENAME,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_FILENAME) },
  { SCCID_ARCDLG_BADNAMETEXT3,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMETEXT3) },
  { SCCID_ARCDLG_BADNAMETEXT4,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_BADNAMETEXT4) },
  { SCCID_ARCDLG_YES,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_YES) },
  { SCCID_ARCDLG_NO,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_NO) },
  { SCCID_ARCDLG_RENAME,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ARCDLG_RENAME) },


  { SCCID_WPDISPLAYMODE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPDISPLAYMODE) },
  { SCCID_WPDATECHAR,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPDATECHAR) },
  { SCCID_WPTIMECHAR,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPTIMECHAR) },
  { SCCID_WPPAGENUMCHAR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPPAGENUMCHAR) },
  { SCCID_WPPAGE,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPPAGE) },
  { SCCID_PRINTHEADERPAGE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PRINTHEADERPAGE) },
  { SCCID_WPEMAILOVERFLOW,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_WPEMAILOVERFLOW) },
  { SCCID_SSBADTYPE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SSBADTYPE) },

  { SCCID_DLGDOCUMENT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGDOCUMENT) },
  { SCCID_DLGSHEET,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGSHEET) },
  { SCCID_DLGIMAGE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGIMAGE) },
  { SCCID_DLGDATABASE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGDATABASE) },
  { SCCID_DLGARCHIVE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGARCHIVE) },
  { SCCID_DLGCURRENT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGCURRENT_U) },
  { SCCID_DLGSLIDE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGSLIDE) },
  { SCCID_DLGCHART,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DLGCHART) },

  { SCCIDTYPE_STRING | FI_NONE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_NONE) },
  { SCCIDTYPE_STRING | FI_WINWORKSDB,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSDB) },
  { SCCIDTYPE_STRING | FI_PARADOX4,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PARADOX4) },
  { SCCIDTYPE_STRING | FI_ACCESS1,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ACCESS1) },
  { SCCIDTYPE_STRING | FI_CEODB,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CEODB) },
  { SCCIDTYPE_STRING | FI_WINWORKSDB3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSDB3) },
  { SCCIDTYPE_STRING | FI_WINWORKSDB4,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSDB4) },
  { SCCIDTYPE_STRING | FI_ACCESS7,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ACCESS7) },
  { SCCIDTYPE_STRING | FI_MSPROJECT98,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSPROJECT98) },
  { SCCIDTYPE_STRING | FI_MSPROJECT2000,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSPROJECT2000) },
  { SCCIDTYPE_STRING | FI_MSPROJECT2002,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSPROJECT2002) },
  { SCCIDTYPE_STRING | FI_MSPROJECT2007,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSPROJECT2007) },
  { SCCIDTYPE_STRING | FI_MSPROJECT2010,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSPROJECT2010) },
  { SCCIDTYPE_STRING | FI_LOTUSNOTESDB,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LOTUSNOTESDB) },

  { SCCIDTYPE_STRING | FI_AUTOCADDWG12,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG12) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG13,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG13) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2000,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2000) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2004,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2004) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2007,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2007) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2008,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2008) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2010,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2010) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2DOT5,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2DOT5) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG2DOT6,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG2DOT6) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG9,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG9) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG10,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG10) },
  { SCCIDTYPE_STRING | FI_ILLUSTRATOR,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ILLUSTRATOR) },
  { SCCIDTYPE_STRING | FI_ILLUSTRATOR9,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ILLUSTRATOR9) },
  { SCCIDTYPE_STRING | FI_PRESENTATIONS7,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PRESENTATIONS7) },
  { SCCIDTYPE_STRING | FI_PRESENTATIONS_X4,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PRESENTATIONS_X4) },
  { SCCIDTYPE_STRING | FI_WPG7,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG7) },
  { SCCIDTYPE_STRING | FI_WPG10,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG10) },
  { SCCIDTYPE_STRING | FI_PDF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PDF) },
  { SCCIDTYPE_STRING | FI_FRAMEMAKER,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FRAMEMAKER) },
  { SCCIDTYPE_STRING | FI_SUNRASTER,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SUNRASTER) },
  { SCCIDTYPE_STRING | FI_AUTOSHADE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOSHADE) },
  { SCCIDTYPE_STRING | FI_KODAKPCD,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_KODAKPCD) },
  { SCCIDTYPE_STRING | FI_EXTPOWERPOINT4,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXTPOWERPOINT4) },
  { SCCIDTYPE_STRING | FI_EXTPOWERPOINTMAC4,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXTPOWERPOINTMAC4) },
  { SCCIDTYPE_STRING | FI_ENHWINDOWSMETA,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENHWINDOWSMETA) },
  { SCCIDTYPE_STRING | FI_GEM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GEM) },
  { SCCIDTYPE_STRING | FI_POWERPOINTMACB3,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTMACB3) },
  { SCCIDTYPE_STRING | FI_POWERPOINTMACB4,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTMACB4) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG) },
  { SCCIDTYPE_STRING | FI_VISIO4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VISIO4) },
  { SCCIDTYPE_STRING | FI_AUTOCADDWG14,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTOCADDWG14) },
  { SCCIDTYPE_STRING | FI_PBM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PBM) },
  { SCCIDTYPE_STRING | FI_PGM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PGM) },
  { SCCIDTYPE_STRING | FI_PPM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PPM) },
  { SCCIDTYPE_STRING | FI_ADOBEPHOTOSHOP,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ADOBEPHOTOSHOP) },
  { SCCIDTYPE_STRING | FI_POWERPOINT9597,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT9597) },
  { SCCIDTYPE_STRING | FI_PAINTSHOPPRO,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PAINTSHOPPRO) },
  { SCCIDTYPE_STRING | FI_FLASHPIX,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FLASHPIX) },
  { SCCIDTYPE_STRING | FI_VISIO5,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VISIO5) },
  { SCCIDTYPE_STRING | FI_CORELDRAW8,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW8) },
  { SCCIDTYPE_STRING | FI_VISIO6,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VISIO6) },
  { SCCIDTYPE_STRING | FI_VISIO3,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VISIO3) },
  { SCCIDTYPE_STRING | FI_CORELDRAW9,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW9) },
  { SCCIDTYPE_STRING | FI_CORELDRAW10,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW10) },
  { SCCIDTYPE_STRING | FI_CORELDRAW11,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW11) },
  { SCCIDTYPE_STRING | FI_CORELDRAW12,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW12) },
  { SCCIDTYPE_STRING | FI_PROGRESSIVEJPEG,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PROGRESSIVEJPEG) },
  { SCCIDTYPE_STRING | FI_JPEG2000,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JPEG2000) },
  { SCCIDTYPE_STRING | FI_JPEG2000JPF,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JPEG2000JPF) },
  { SCCIDTYPE_STRING | FI_JPEG2000MJ2,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JPEG2000MJ2) },
  { SCCIDTYPE_STRING | FI_MIFF4J,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF4J) },
  { SCCIDTYPE_STRING | FI_MIFF5J,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF5J) },
  { SCCIDTYPE_STRING | FI_MIFF55,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF55) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT8,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT8) },
  { SCCIDTYPE_STRING | FI_ICHITARO8,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ICHITARO8) },
  { SCCIDTYPE_STRING | FI_VCARD,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VCARD) },
  { SCCIDTYPE_STRING | FI_VCAL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VCAL) },
  { SCCIDTYPE_STRING | FI_HTML_CSS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CSS) },
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_MAIL),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_MAIL),
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_APPT),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_APPT),
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_TASK),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_TASK),
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_NOTE),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_NOTE),
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_JOURNAL),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_JOURNAL),
  LO_FISTR_DEFINE(FI_OUTLOOK_MSG_CONTACT),
  LO_FISTR_DEFINE(FI_OUTLOOK_OFT_CONTACT),
  { SCCIDTYPE_STRING | FI_OUTLOOK_PST,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OUTLOOK_PST) },
  { SCCIDTYPE_STRING | FI_PST_2003,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PST_2003)},
  { SCCIDTYPE_STRING | FI_PAB_2002,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PAB_2002)},
  { SCCIDTYPE_STRING | FI_PSTF,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PSTF) },
  { SCCIDTYPE_STRING | FI_POCKETWORD,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POCKETWORD) },
  { SCCIDTYPE_STRING | FI_POCKETWORD20,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POCKETWORD20) },
  { SCCIDTYPE_STRING | FI_WORDPRO97,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPRO97) },
  { SCCIDTYPE_STRING | FI_WINWORD2000,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2000) },
  { SCCIDTYPE_STRING | FI_W2KHTML,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_W2KHTML) },
  { SCCIDTYPE_STRING | FI_XL2KHTML,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XL2KHTML) },
  { SCCIDTYPE_STRING | FI_PP2KHTML,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PP2KHTML) },
  { SCCIDTYPE_STRING | FI_XML,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML) },
  { SCCIDTYPE_STRING | FI_WPL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPL) },
  { SCCIDTYPE_STRING | FI_WML,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC4,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC4) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5_1,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5_1) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5_2,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5_2) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5_3,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5_3) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5_4,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5_4) },
  { SCCIDTYPE_STRING | FI_XML_FLEXIONDOC5_5,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_FLEXIONDOC5_5) },
  { SCCIDTYPE_STRING | FI_XML_DXL,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_DXL) },
  { SCCIDTYPE_STRING | FI_XML_OPENDOCUMENT_1_0,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_OPENDOCUMENT_1_0) },
  { SCCIDTYPE_STRING | FI_MBOX,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MBOX) },
  { SCCIDTYPE_STRING | FI_MIME,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIME) },
  { SCCIDTYPE_STRING | FI_MIMENEWS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIMENEWS) },
  { SCCIDTYPE_STRING | FI_MIMEMAIL,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIMEMAIL) },
  { SCCIDTYPE_STRING | FI_MIMEOUTLOOKNEWS,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIMEOUTLOOKNEWS) },
  { SCCIDTYPE_STRING | FI_MIMEOUTLOOKEML,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIMEOUTLOOKEML) },
  { SCCIDTYPE_STRING | FI_MHTML,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIMEHTML) },
  { SCCIDTYPE_STRING | FI_UUENCODEDTEXT,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UUENCODEDTEXT) },
  { SCCIDTYPE_STRING | FI_UUENCODEDPART,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UUENCODEDPART) },
  { SCCIDTYPE_STRING | FI_XXENCODEDTEXT,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XXENCODEDTEXT) },
  { SCCIDTYPE_STRING | FI_XXENCODEDPART,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XXENCODEDPART) },
  { SCCIDTYPE_STRING | FI_YENCODEDTEXT,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_YENCODEDTEXT) },
  { SCCIDTYPE_STRING | FI_YENCODEDPART,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_YENCODEDPART) },
  { SCCIDTYPE_STRING | FI_BINHEXENCODEDTEXT,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINHEXENCODEDTEXT) },
  { SCCIDTYPE_STRING | FI_BINHEXENCODEDPART,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINHEXENCODEDPART) },
  { SCCIDTYPE_STRING | FI_TNEF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TNEF) },
  { SCCIDTYPE_STRING | FI_EMLX,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EMLX) },
  { SCCIDTYPE_STRING | FI_PDFIMAGE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PDFIMAGE) },
  { SCCIDTYPE_STRING | FI_PDFMACBIN,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PDFMACBIN) },
  { SCCIDTYPE_STRING | FI_EXPORTIMAGE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXPORTIMAGE) },
  { SCCIDTYPE_STRING | FI_PUBLISHER2003,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PUBLISHER2003) },
  { SCCIDTYPE_STRING | FI_PUBLISHER2007,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PUBLISHER2007) },


  { SCCIDTYPE_STRING | FI_AMI,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AMI) },
  { SCCIDTYPE_STRING | FI_AMIPRO,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AMIPRO) },
  { SCCIDTYPE_STRING | FI_FIRSTCHOICE3,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FIRSTCHOICE3) },
  { SCCIDTYPE_STRING | FI_MACWORDPERFECT2,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORDPERFECT2) },
  { SCCIDTYPE_STRING | FI_MACWORKSWP2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORKSWP2) },
  { SCCIDTYPE_STRING | FI_PROWRITEPLUS,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PROWRITEPLUS) },
  { SCCIDTYPE_STRING | FI_LEGACY,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LEGACY) },
  { SCCIDTYPE_STRING | FI_SIGNATURE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SIGNATURE) },
  { SCCIDTYPE_STRING | FI_WINWORDSTAR,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORDSTAR) },
  { SCCIDTYPE_STRING | FI_WINWORD2,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2) },
  { SCCIDTYPE_STRING | FI_JUSTWRITE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JUSTWRITE) },
  { SCCIDTYPE_STRING | FI_WORDSTAR7,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR7) },
  { SCCIDTYPE_STRING | FI_WINWORKSWP,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSWP) },
  { SCCIDTYPE_STRING | FI_JUSTWRITE2,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JUSTWRITE2) },
  { SCCIDTYPE_STRING | FI_AMICLIP,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AMICLIP) },
  { SCCIDTYPE_STRING | FI_LEGACYCLIP,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LEGACYCLIP) },

  { SCCIDTYPE_STRING | FI_BINARYMETAFILE,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINARYMETAFILE) },
  { SCCIDTYPE_STRING | FI_WPFWPG,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPFWPG) },
  { SCCIDTYPE_STRING | FI_AMISNAPSHOT,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AMISNAPSHOT) },
  { SCCIDTYPE_STRING | FI_WORDSNAPSHOT,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSNAPSHOT) },
  { SCCIDTYPE_STRING | FI_BINARYMACPICT,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINARYMACPICT) },
  { SCCIDTYPE_STRING | FI_BINARYMETABMP,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINARYMETABMP) },
  { SCCIDTYPE_STRING | FI_BINARYMETAPICT,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINARYMETAPICT) },
  { SCCIDTYPE_STRING | FI_WPFWORKSEMBED,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPFWORKSEMBED) },

  { SCCIDTYPE_STRING | FI_WPG2EMBED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG2EMBED) },
  { SCCIDTYPE_STRING | FI_WINDOWSDIB,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINDOWSDIB) },
  { SCCIDTYPE_STRING | FI_WPG1EMBED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG1EMBED) },
  { SCCIDTYPE_STRING | FI_GDSFEMBED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GDSFEMBED) },
  { SCCIDTYPE_STRING | FI_WINBMPCOREINFO,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINBMPCOREINFO) },
  { SCCIDTYPE_STRING | FI_IAFBWEMBED,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IAFBWEMBED) },
  { SCCIDTYPE_STRING | FI_IAFCOLOREMBED,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IAFCOLOREMBED) },
  { SCCIDTYPE_STRING | FI_PICTEMBED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PICTEMBED) },

  { SCCIDTYPE_STRING | FI_EPSTIFF,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EPSTIFF) },
  { SCCIDTYPE_STRING | FI_CCITTGRP3,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CCITTGRP3) },
  { SCCIDTYPE_STRING | FI_MACPICT2,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACPICT2) },
  { SCCIDTYPE_STRING | FI_WPG,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG) },
  { SCCIDTYPE_STRING | FI_WINDOWSMETA,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINDOWSMETA) },
  { SCCIDTYPE_STRING | FI_LOTUSPIC,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LOTUSPIC) },
  { SCCIDTYPE_STRING | FI_MACPICT1,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACPICT1) },
  { SCCIDTYPE_STRING | FI_AMIDRAW,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AMIDRAW) },
  { SCCIDTYPE_STRING | FI_TARGA,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TARGA) },
  { SCCIDTYPE_STRING | FI_GEMIMG,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GEMIMG) },
  { SCCIDTYPE_STRING | FI_OS2DIB,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OS2DIB) },
  { SCCIDTYPE_STRING | FI_OS2V2BMP,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OS2V2BMP) },
  { SCCIDTYPE_STRING | FI_WINDOWSICON,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINDOWSICON) },
  { SCCIDTYPE_STRING | FI_WINDOWSCURSOR,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINDOWSCURSOR) },
  { SCCIDTYPE_STRING | FI_MICROGRAFX,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MICROGRAFX) },
  { SCCIDTYPE_STRING | FI_MACPAINT,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACPAINT) },
  { SCCIDTYPE_STRING | FI_SVM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SVM) },
  { SCCIDTYPE_STRING | FI_EFAX,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EFAX) },

  { SCCIDTYPE_STRING | FI_MATSU4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MATSU4) },
  { SCCIDTYPE_STRING | FI_MATSU5,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MATSU5) },
  { SCCIDTYPE_STRING | FI_P1,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_P1) },
  { SCCIDTYPE_STRING | FI_RTFJ,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RTFJ) },
  { SCCIDTYPE_STRING | FI_CEOWRITE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CEOWRITE) },
  { SCCIDTYPE_STRING | FI_WINWORKSWP3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSWP3) },
  { SCCIDTYPE_STRING | FI_WORDPAD,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPAD) },
  { SCCIDTYPE_STRING | FI_WPFUNKNOWN,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPFUNKNOWN) },
  { SCCIDTYPE_STRING | FI_WINWORD2_OLECONV,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2_OLECONV) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT61,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT61) },
  { SCCIDTYPE_STRING | FI_FTDF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FTDF) },
  { SCCIDTYPE_STRING | FI_HTML,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML) },
  { SCCIDTYPE_STRING | FI_HTMLUNICODE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTMLUNICODE) },
  { SCCIDTYPE_STRING | FI_XML_DOCTYPE_HTML,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_DOCTYPE_HTML) },
  { SCCIDTYPE_STRING | FI_WINWORD7,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD7) },
  { SCCIDTYPE_STRING | FI_MSWORKS2000,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSWORKS2000) },
  { SCCIDTYPE_STRING | FI_AREHANGEUL,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AREHANGEUL) },

  { SCCIDTYPE_STRING | FI_HTML_JAPANESEJIS,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_JAPANESEJIS) },
  { SCCIDTYPE_STRING | FI_WML_CHINESEBIG5,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_CHINESEBIG5) },
  { SCCIDTYPE_STRING | FI_WML_CHINESEEUC,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_CHINESEEUC) },
  { SCCIDTYPE_STRING | FI_WML_CHINESEGB,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_CHINESEGB) },
  { SCCIDTYPE_STRING | FI_WML_CYRILLIC1251,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_CYRILLIC1251) },
  { SCCIDTYPE_STRING | FI_WML_CYRILLICKOI8,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_CYRILLICKOI8) },
  { SCCIDTYPE_STRING | FI_WML_JAPANESEJIS,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_JAPANESEJIS) },
  { SCCIDTYPE_STRING | FI_WML_JAPANESESJIS,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_JAPANESESJIS) },
  { SCCIDTYPE_STRING | FI_WML_JAPANESEEUC,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_JAPANESEEUC) },
  { SCCIDTYPE_STRING | FI_WML_KOREANHANGUL,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_KOREANHANGUL) },
  { SCCIDTYPE_STRING | FI_WML_LATIN2,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WML_LATIN2) },
  { SCCIDTYPE_STRING | FI_STAROFFICEWRITER52,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEWRITER52) },
  { SCCIDTYPE_STRING | FI_MIFF6,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF6) },
  { SCCIDTYPE_STRING | FI_MIFF6J,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF6J) },

  { SCCIDTYPE_STRING | FI_EXCEL5CHART,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL5CHART) },
  { SCCIDTYPE_STRING | FI_CORELDRAW4,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW4) },
  { SCCIDTYPE_STRING | FI_POWERPOINT4,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT4) },
  { SCCIDTYPE_STRING | FI_DCX,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DCX) },
  { SCCIDTYPE_STRING | FI_POWERPOINT3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT3) },
  { SCCIDTYPE_STRING | FI_CORELDRAW5,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW5) },
  { SCCIDTYPE_STRING | FI_OS2METAFILE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OS2METAFILE) },
  { SCCIDTYPE_STRING | FI_POWERPOINT7,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT7) },
  { SCCIDTYPE_STRING | FI_DXFA,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXFA) },
  { SCCIDTYPE_STRING | FI_DXFB,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXFB) },
  { SCCIDTYPE_STRING | FI_DXB,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXB) },
  { SCCIDTYPE_STRING | FI_FREELANCE3,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FREELANCE3) },
  { SCCIDTYPE_STRING | FI_POWERPOINTMAC3,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTMAC3) },
  { SCCIDTYPE_STRING | FI_POWERPOINTMAC4,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTMAC4) },
  { SCCIDTYPE_STRING | FI_PRESENTATIONS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PRESENTATIONS) },
  { SCCIDTYPE_STRING | FI_OS2WARPBMP,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OS2WARPBMP) },

  { SCCIDTYPE_STRING | FI_CORELDRAW2,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW2) },
  { SCCIDTYPE_STRING | FI_CORELDRAW3,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW3) },
  { SCCIDTYPE_STRING | FI_HPGL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HPGL) },
  { SCCIDTYPE_STRING | FI_HARVARDDOS3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HARVARDDOS3) },
  { SCCIDTYPE_STRING | FI_HARVARDDOS2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HARVARDDOS2) },
  { SCCIDTYPE_STRING | FI_HARVARDDOS3PRS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HARVARDDOS3PRS) },
  { SCCIDTYPE_STRING | FI_FREELANCE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FREELANCE) },
  { SCCIDTYPE_STRING | FI_WPG2,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPG2) },
  { SCCIDTYPE_STRING | FI_CGM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CGM) },
  { SCCIDTYPE_STRING | FI_EXCELCHART,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCELCHART) },
  { SCCIDTYPE_STRING | FI_EXCEL3CHART,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL3CHART) },
  { SCCIDTYPE_STRING | FI_EXCEL4CHART,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL4CHART) },
  { SCCIDTYPE_STRING | FI_CANDY4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CANDY4) },
  { SCCIDTYPE_STRING | FI_HANAKO1,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANAKO1) },
  { SCCIDTYPE_STRING | FI_HANAKO2,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANAKO2) },
  { SCCIDTYPE_STRING | FI_JPEGFIF,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JPEGFIF) },
  { SCCIDTYPE_STRING | FI_POWERPOINT2000,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT2000) },
  { SCCIDTYPE_STRING | FI_POWERPOINT2007,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT2007) },
  { SCCIDTYPE_STRING | FI_ENCRYPTED_PPT2007,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENCRYPTED_PPT2007) },
  { SCCIDTYPE_STRING | FI_MICROSOFT_XPS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MICROSOFT_XPS) },

  { SCCIDTYPE_STRING | FI_POWERPOINT2,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT2) },
  { SCCIDTYPE_STRING | FI_DGN,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DGN) },
  { SCCIDTYPE_STRING | FI_BMP5,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BMP5) },
  { SCCIDTYPE_STRING | FI_WBMP,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WBMP) },
  { SCCIDTYPE_STRING | FI_VPPLANNER,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VPPLANNER) },
  { SCCIDTYPE_STRING | FI_TWIN,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TWIN) },
  { SCCIDTYPE_STRING | FI_SUPERCALC5,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SUPERCALC5) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO) },
  { SCCIDTYPE_STRING | FI_QUATTRO,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTRO) },
  { SCCIDTYPE_STRING | FI_PFS_PLAN,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PFS_PLAN) },
  { SCCIDTYPE_STRING | FI_FIRSTCHOICE_SS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FIRSTCHOICE_SS) },
  { SCCIDTYPE_STRING | FI_EXCEL3,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL3) },
  { SCCIDTYPE_STRING | FI_GENERIC_WKS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GENERIC_WKS) },
  { SCCIDTYPE_STRING | FI_MACWORKSSS2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORKSSS2) },
  { SCCIDTYPE_STRING | FI_WINWORKSSS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSSS) },
  { SCCIDTYPE_STRING | FI_MSWORKSSS6,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSWORKSSS6) },
  { SCCIDTYPE_STRING | FI_EXCEL4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL4) },
  { SCCIDTYPE_STRING | FI_QUATTROPROWIN,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPROWIN) },
  { SCCIDTYPE_STRING | FI_123R4,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R4) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO1J,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO1J) },
  { SCCIDTYPE_STRING | FI_CEOSS,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CEOSS) },

  { SCCIDTYPE_STRING | FI_PROWRITEPLUSCLIP,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PROWRITEPLUSCLIP) },
  { SCCIDTYPE_STRING | FI_MACWORD5,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORD5) },
  { SCCIDTYPE_STRING | FI_ENABLEWP4,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENABLEWP4) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT6,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT6) },
  { SCCIDTYPE_STRING | FI_WORD6,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORD6) },
  { SCCIDTYPE_STRING | FI_DX31,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DX31) },
  { SCCIDTYPE_STRING | FI_WPFENCRYPT,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPFENCRYPT) },
  { SCCIDTYPE_STRING | FI_QAWRITE3,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QAWRITE3) },
  { SCCIDTYPE_STRING | FI_MACWORDPERFECT3,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORDPERFECT3) },
  { SCCIDTYPE_STRING | FI_CEOWORD,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CEOWORD) },
  { SCCIDTYPE_STRING | FI_WINWORD6,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD6) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT51J,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT51J) },
  { SCCIDTYPE_STRING | FI_ICHITARO3,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ICHITARO3) },
  { SCCIDTYPE_STRING | FI_ICHITARO4,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ICHITARO4) },
  { SCCIDTYPE_STRING | FI_WINWORD1J,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD1J) },
  { SCCIDTYPE_STRING | FI_WINWORD5J,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD5J) },

  { SCCIDTYPE_STRING | FI_QUARKEXP_MAC30,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_MAC30)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_MAC31,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_MAC31)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_MAC32,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_MAC32)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_MAC33,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_MAC33)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_MAC40,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_MAC40)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_WIN33,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_WIN33)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_WIN40,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_WIN40)},
  { SCCIDTYPE_STRING | FI_QUARKEXP_WIN50,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUARKEXP_WIN50)},

  { SCCIDTYPE_STRING | FI_EBCDIC,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC)},
  { SCCIDTYPE_STRING | FI_EBCDIC_500,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_500)},
  { SCCIDTYPE_STRING | FI_EBCDIC_37,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_37)},
  { SCCIDTYPE_STRING | FI_EBCDIC_273,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_273)},
  { SCCIDTYPE_STRING | FI_EBCDIC_277,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_277)},
  { SCCIDTYPE_STRING | FI_EBCDIC_278,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_278)},
  { SCCIDTYPE_STRING | FI_EBCDIC_280,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_280)},
  { SCCIDTYPE_STRING | FI_EBCDIC_284,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_284)},
  { SCCIDTYPE_STRING | FI_EBCDIC_285,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_285)},
  { SCCIDTYPE_STRING | FI_EBCDIC_297,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_297)},
  { SCCIDTYPE_STRING | FI_EBCDIC_870,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_870)},
  { SCCIDTYPE_STRING | FI_EBCDIC_871,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_871)},
  { SCCIDTYPE_STRING | FI_EBCDIC_1026,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EBCDIC_1026)},
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_37,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_37)   },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_273,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_273)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_277,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_277)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_278,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_278)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_280,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_280)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_284,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_284)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_285,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_285)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_297,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_297)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_500,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_500)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_870,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_870)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_871,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_871)  },
  { SCCIDTYPE_STRING | FI_HTML_EBCDIC_1026,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_EBCDIC_1026) },
  { SCCIDTYPE_STRING | FI_ARABIC_WINDOWS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_ARABIC_WINDOWS)},

  { SCCIDTYPE_STRING | FI_ARABIC_ASMO708,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ARABIC_ASMO708)                  },
  { SCCIDTYPE_STRING | FI_ARABIC_DOS,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ARABIC_DOS)                      },
  { SCCIDTYPE_STRING | FI_ARABIC_ISO,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ARABIC_ISO)                      },
  { SCCIDTYPE_STRING | FI_ARABIC_MAC,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ARABIC_MAC)                      },
  { SCCIDTYPE_STRING | FI_BALTIC_ISO,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BALTIC_ISO)                      },
  { SCCIDTYPE_STRING | FI_BALTIC_WINDOWS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BALTIC_WINDOWS)                  },
  { SCCIDTYPE_STRING | FI_CENTRALEUROPEAN_DOS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CENTRALEUROPEAN_DOS)             },
  { SCCIDTYPE_STRING | FI_CENTRALEUROPEAN_ISO,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CENTRALEUROPEAN_ISO)             },
  { SCCIDTYPE_STRING | FI_CENTRALEUROPEAN_MAC,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CENTRALEUROPEAN_MAC)             },
  { SCCIDTYPE_STRING | FI_CENTRALEUROPEAN_WINDOWS,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CENTRALEUROPEAN_WINDOWS)         },
  { SCCIDTYPE_STRING | FI_CHINESESIMPLIFIED_WINDOWS,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CHINESESIMPLIFIED_WINDOWS)       },
  { SCCIDTYPE_STRING | FI_CHINESETRADITIONAL_WINDOWS,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CHINESETRADITIONAL_WINDOWS)      },
  { SCCIDTYPE_STRING | FI_CYRILLIC_DOS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC_DOS)                    },
  { SCCIDTYPE_STRING | FI_CYRILLIC_ISO,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC_ISO)                    },
  { SCCIDTYPE_STRING | FI_CYRILLIC_KOI8R,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC_KOI8R)                  },
  { SCCIDTYPE_STRING | FI_CYRILLIC_MAC,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC_MAC)                    },
  { SCCIDTYPE_STRING | FI_CYRILLIC_WINDOWS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC_WINDOWS)                },
  { SCCIDTYPE_STRING | FI_GREEK_ISO,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GREEK_ISO)                       },
  { SCCIDTYPE_STRING | FI_GREEK_MAC,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GREEK_MAC)                       },
  { SCCIDTYPE_STRING | FI_GREEK_WINDOWS,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GREEK_WINDOWS)                   },
  { SCCIDTYPE_STRING | FI_HEBREW_DOS,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_DOS)                      },
  { SCCIDTYPE_STRING | FI_HEBREW_E0,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_E0)                       },
  { SCCIDTYPE_STRING | FI_HEBREW_ISO_VISUAL,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_ISO_VISUAL)               },
  { SCCIDTYPE_STRING | FI_HEBREW_PC8,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_PC8)                      },
  { SCCIDTYPE_STRING | FI_JAPANESE_MAC,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JAPANESE_MAC)                    },
  /* DEPRECATED - see issue #USER100113521 - { SCCIDTYPE_STRING | FI_JAPANESE_SHIFTJIS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JAPANESE_SHIFTJIS)               }, */
  { SCCIDTYPE_STRING | FI_KOREAN_JOHAB,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_KOREAN_JOHAB)                    },
  { SCCIDTYPE_STRING | FI_KOREAN_WINDOWS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_KOREAN_WINDOWS)                  },
  { SCCIDTYPE_STRING | FI_RUSSIAN_DOS,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RUSSIAN_DOS)                     },
  { SCCIDTYPE_STRING | FI_THAI_WINDOWS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_THAI_WINDOWS)                    },
  { SCCIDTYPE_STRING | FI_TURKISH_DOS,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TURKISH_DOS)                     },
  { SCCIDTYPE_STRING | FI_TURKISH_ISO,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TURKISH_ISO)                     },
  { SCCIDTYPE_STRING | FI_TURKISH_MAC,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TURKISH_MAC)                     },
  { SCCIDTYPE_STRING | FI_TURKISH_WINDOWS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TURKISH_WINDOWS)                 },
  { SCCIDTYPE_STRING | FI_VIETNAMESE_WINDOWS,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VIETNAMESE_WINDOWS)              },
  { SCCIDTYPE_STRING | FI_WESTERNEUROPEAN_ISO,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WESTERNEUROPEAN_ISO)             },
  { SCCIDTYPE_STRING | FI_WESTERNEUROPEAN_MAC,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WESTERNEUROPEAN_MAC)             },
  { SCCIDTYPE_STRING | FI_WESTERNEUROPEAN_WINDOWS,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WESTERNEUROPEAN_WINDOWS)         },
  { SCCIDTYPE_STRING | FI_HTML_ARABIC_ASMO708,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_ARABIC_ASMO708)             },
  { SCCIDTYPE_STRING | FI_HTML_ARABIC_DOS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_ARABIC_DOS)                 },
  { SCCIDTYPE_STRING | FI_HTML_ARABIC_ISO,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_ARABIC_ISO)                 },
  { SCCIDTYPE_STRING | FI_HTML_ARABIC_MAC,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_ARABIC_MAC)                 },
  { SCCIDTYPE_STRING | FI_HTML_ARABIC_WINDOWS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_ARABIC_WINDOWS)             },
  { SCCIDTYPE_STRING | FI_HTML_BALTIC_WINDOWS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_BALTIC_WINDOWS)             },
  { SCCIDTYPE_STRING | FI_HTML_CENTRALEUROPEAN_DOS,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CENTRALEUROPEAN_DOS)        },
  { SCCIDTYPE_STRING | FI_HTML_CENTRALEUROPEAN_ISO,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CENTRALEUROPEAN_ISO)        },
  { SCCIDTYPE_STRING | FI_HTML_CENTRALEUROPEAN_MAC,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CENTRALEUROPEAN_MAC)        },
  { SCCIDTYPE_STRING | FI_HTML_CENTRALEUROPEAN_WINDOWS,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CENTRALEUROPEAN_WINDOWS)    },
  { SCCIDTYPE_STRING | FI_HTML_CHINESESIMPLIFIED_EUC,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESESIMPLIFIED_EUC)      },
  { SCCIDTYPE_STRING | FI_HTML_CHINESESIMPLIFIED_WINDOWS,    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESESIMPLIFIED_WINDOWS)  },
  { SCCIDTYPE_STRING | FI_HTML_CHINESETRADITIONAL_WINDOWS,   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESETRADITIONAL_WINDOWS) },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC_DOS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC_DOS)               },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC_ISO,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC_ISO)               },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC_KOI8R,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC_KOI8R)             },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC_MAC,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC_MAC)               },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC_WINDOWS,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC_WINDOWS)           },
  { SCCIDTYPE_STRING | FI_HTML_GREEK_ISO,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_GREEK_ISO)                  },
  { SCCIDTYPE_STRING | FI_HTML_GREEK_MAC,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_GREEK_MAC)                  },
  { SCCIDTYPE_STRING | FI_HTML_GREEK_WINDOWS,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_GREEK_WINDOWS)              },
  { SCCIDTYPE_STRING | FI_HTML_HEBREW_DOS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_HEBREW_DOS)                 },
  { SCCIDTYPE_STRING | FI_HTML_HEBREW_ISO_VISUAL,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_HEBREW_ISO_VISUAL)          },
  { SCCIDTYPE_STRING | FI_HTML_HEBREW_WINDOWS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_HEBREW_WINDOWS)             },
  { SCCIDTYPE_STRING | FI_HTML_JAPANESE_MAC,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_JAPANESE_MAC)               },
  { SCCIDTYPE_STRING | FI_HTML_JAPANESE_SHIFTJIS,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_JAPANESE_SHIFTJIS)          },
  { SCCIDTYPE_STRING | FI_HTML_KOREAN_JOHAB,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_KOREAN_JOHAB)               },
  { SCCIDTYPE_STRING | FI_HTML_KOREAN_WINDOWS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_KOREAN_WINDOWS)             },
  { SCCIDTYPE_STRING | FI_HTML_RUSSIAN_DOS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_RUSSIAN_DOS)                },
  { SCCIDTYPE_STRING | FI_HTML_THAI_WINDOWS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_THAI_WINDOWS)               },
  { SCCIDTYPE_STRING | FI_HTML_TURKISH_DOS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_TURKISH_DOS)                },
  { SCCIDTYPE_STRING | FI_HTML_TURKISH_ISO,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_TURKISH_ISO)                },
  { SCCIDTYPE_STRING | FI_HTML_TURKISH_MAC,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_TURKISH_MAC)                },
  { SCCIDTYPE_STRING | FI_HTML_TURKISH_WINDOWS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_TURKISH_WINDOWS)            },
  { SCCIDTYPE_STRING | FI_HTML_VIETNAMESE_WINDOWS,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_VIETNAMESE_WINDOWS)         },
  { SCCIDTYPE_STRING | FI_HTML_WESTERNEUROPEAN_ISO,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_WESTERNEUROPEAN_ISO)        },
  { SCCIDTYPE_STRING | FI_HTML_WESTERNEUROPEAN_MAC,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_WESTERNEUROPEAN_MAC)        },
  { SCCIDTYPE_STRING | FI_HTML_WESTERNEUROPEAN_WINDOWS,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_WESTERNEUROPEAN_WINDOWS)    },

  { SCCIDTYPE_STRING | FI_BMP,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BMP) },
  { SCCIDTYPE_STRING | FI_TIFF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TIFF) },
  { SCCIDTYPE_STRING | FI_PCX,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PCX) },
  { SCCIDTYPE_STRING | FI_GIF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GIF) },

  { SCCIDTYPE_STRING | FI_HANA,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANA) },
  { SCCIDTYPE_STRING | FI_WINWORKSWP4,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSWP4) },
  { SCCIDTYPE_STRING | FI_PERFECTWORKS1,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PERFECTWORKS1) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT7,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT7) },
  { SCCIDTYPE_STRING | FI_WORDPRO,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPRO) },
  { SCCIDTYPE_STRING | FI_HTML_LATIN2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_LATIN2) },
  { SCCIDTYPE_STRING | FI_HTML_JAPANESESJIS,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_JAPANESESJIS) },
  { SCCIDTYPE_STRING | FI_HTML_JAPANESEEUC,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_JAPANESEEUC) },
  { SCCIDTYPE_STRING | FI_HTML_CHINESEBIG5,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESEBIG5) },
  { SCCIDTYPE_STRING | FI_HTML_CHINESEEUC,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESEEUC) },
  { SCCIDTYPE_STRING | FI_HTML_CHINESEGB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CHINESEGB) },
  { SCCIDTYPE_STRING | FI_HTML_KOREANHANGUL,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_KOREANHANGUL) },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLIC1251,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLIC1251) },
  { SCCIDTYPE_STRING | FI_HTML_CYRILLICKOI8,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTML_CYRILLICKOI8) },
  { SCCIDTYPE_STRING | FI_CYRILLIC1251,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLIC1251) },
  { SCCIDTYPE_STRING | FI_CYRILLICKOI8,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CYRILLICKOI8) },

  { SCCIDTYPE_STRING | FI_SMARTDATA,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SMARTDATA) },
  { SCCIDTYPE_STRING | FI_DBASE3,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DBASE3) },
  { SCCIDTYPE_STRING | FI_DBASE4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DBASE4) },
  { SCCIDTYPE_STRING | FI_FRAMEWORKIII,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FRAMEWORKIII) },
  { SCCIDTYPE_STRING | FI_WORKSDATA,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORKSDATA) },
  { SCCIDTYPE_STRING | FI_DATAEASE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DATAEASE) },
  { SCCIDTYPE_STRING | FI_PARADOX3,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PARADOX3) },
  { SCCIDTYPE_STRING | FI_PARADOX35,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PARADOX35) },
  { SCCIDTYPE_STRING | FI_QADBASE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QADBASE) },
  { SCCIDTYPE_STRING | FI_REFLEX,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_REFLEX) },
  { SCCIDTYPE_STRING | FI_RBASEV,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RBASEV) },
  { SCCIDTYPE_STRING | FI_RBASE5000,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RBASE5000) },
  { SCCIDTYPE_STRING | FI_RBASEFILE1,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RBASEFILE1) },
  { SCCIDTYPE_STRING | FI_RBASEFILE3,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RBASEFILE3) },
  { SCCIDTYPE_STRING | FI_FIRSTCHOICE_DB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FIRSTCHOICE_DB) },
  { SCCIDTYPE_STRING | FI_MACWORKSDB2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORKSDB2) },

  { SCCIDTYPE_STRING | FI_RFT,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RFT) },
  { SCCIDTYPE_STRING | FI_TXT,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TXT) },
  { SCCIDTYPE_STRING | FI_SMART,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SMART) },
  { SCCIDTYPE_STRING | FI_SAMNA,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SAMNA) },
  { SCCIDTYPE_STRING | FI_PFSWRITEA,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PFSWRITEA) },
  { SCCIDTYPE_STRING | FI_PFSWRITEB,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PFSWRITEB) },
  { SCCIDTYPE_STRING | FI_PROWRITE1,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PROWRITE1) },
  { SCCIDTYPE_STRING | FI_PROWRITE2,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PROWRITE2) },
  { SCCIDTYPE_STRING | FI_IBMWRITING,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IBMWRITING) },
  { SCCIDTYPE_STRING | FI_FIRSTCHOICE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FIRSTCHOICE) },
  { SCCIDTYPE_STRING | FI_WORDMARC,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDMARC) },
  { SCCIDTYPE_STRING | FI_DIF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DIF) },
  { SCCIDTYPE_STRING | FI_DIFSS,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DIFSS) },
  { SCCIDTYPE_STRING | FI_VOLKSWRITER,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VOLKSWRITER) },
  { SCCIDTYPE_STRING | FI_DX,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DX) },
  { SCCIDTYPE_STRING | FI_SPRINT,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SPRINT) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT42,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT42) },

  { SCCIDTYPE_STRING | FI_ENVOY,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENVOY) },
  { SCCIDTYPE_STRING | FI_QUICKFINDER,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUICKFINDER) },
  { SCCIDTYPE_STRING | FI_WINCLIPFILE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINCLIPFILE) },
  { SCCIDTYPE_STRING | FI_ENVOY7,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENVOY7) },
  { SCCIDTYPE_STRING | FI_STUFFIT,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STUFFIT) },
  { SCCIDTYPE_STRING | FI_LZH,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LZH) },
  { SCCIDTYPE_STRING | FI_LZH_SFX,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LZH_SFX) },
  { SCCIDTYPE_STRING | FI_GZIP,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GZIP) },

  { SCCIDTYPE_STRING | FI_SYMPHONY1,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SYMPHONY1) },
  { SCCIDTYPE_STRING | FI_123R1,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R1) },
  { SCCIDTYPE_STRING | FI_123R2,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R2) },
  { SCCIDTYPE_STRING | FI_123R3,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R3) },
  { SCCIDTYPE_STRING | FI_SMARTSHEET,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SMARTSHEET) },
  { SCCIDTYPE_STRING | FI_EXCEL,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL) },
  { SCCIDTYPE_STRING | FI_ENABLESHEET,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENABLESHEET) },
  { SCCIDTYPE_STRING | FI_WORKSSHEET,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORKSSHEET) },

  { SCCIDTYPE_STRING | FI_QAWRITE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QAWRITE) },
  { SCCIDTYPE_STRING | FI_MULTIMATENOTE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MULTIMATENOTE) },
  { SCCIDTYPE_STRING | FI_PCFILELETTER,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PCFILELETTER) },
  { SCCIDTYPE_STRING | FI_MANUSCRIPT1,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MANUSCRIPT1) },
  { SCCIDTYPE_STRING | FI_MANUSCRIPT2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MANUSCRIPT2) },
  { SCCIDTYPE_STRING | FI_ENABLEWP,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENABLEWP) },
  { SCCIDTYPE_STRING | FI_WINWRITE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWRITE) },
  { SCCIDTYPE_STRING | FI_WORKS1,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORKS1) },
  { SCCIDTYPE_STRING | FI_WORKS2,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORKS2) },
  { SCCIDTYPE_STRING | FI_WORDSTAR6,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR6) },
  { SCCIDTYPE_STRING | FI_OFFICEWRITER,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OFFICEWRITER) },
  { SCCIDTYPE_STRING | FI_DISPLAYWRITE5,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DISPLAYWRITE5) },
  { SCCIDTYPE_STRING | FI_WINWORD1,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD1) },
  { SCCIDTYPE_STRING | FI_WINWORD1COMPLEX,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD1COMPLEX) },

  { SCCIDTYPE_STRING | FI_TOTALWORD,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TOTALWORD) },
  { SCCIDTYPE_STRING | FI_IWP,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IWP) },
  { SCCIDTYPE_STRING | FI_WORDSTAR55,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR55) },
  { SCCIDTYPE_STRING | FI_RTF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RTF) },
  { SCCIDTYPE_STRING | FI_MACWORD3,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORD3) },
  { SCCIDTYPE_STRING | FI_MACWORD4,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORD4) },
  { SCCIDTYPE_STRING | FI_MASS11PC,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MASS11PC) },
  { SCCIDTYPE_STRING | FI_MACWRITEII,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWRITEII) },
  { SCCIDTYPE_STRING | FI_XYWRITE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XYWRITE) },
  { SCCIDTYPE_STRING | FI_FFT,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_FFT) },
  { SCCIDTYPE_STRING | FI_MACWORDPERFECT,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORDPERFECT) },
  { SCCIDTYPE_STRING | FI_DISPLAYWRITE4,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DISPLAYWRITE4) },
  { SCCIDTYPE_STRING | FI_MASS11VAX,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MASS11VAX) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT51,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT51) },
  { SCCIDTYPE_STRING | FI_MULTIMATE40,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MULTIMATE40) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT5E,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT5E) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT6E,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT6E) },


  { SCCIDTYPE_STRING | FI_EXCEL5,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL5) },
  { SCCIDTYPE_STRING | FI_MULTIPLAN4,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MULTIPLAN4) },
  { SCCIDTYPE_STRING | FI_WINWORKSSS3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSSS3) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO4,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO4) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO5,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO5) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO6,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO6) },
  { SCCIDTYPE_STRING | FI_123R2OS2,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R2OS2) },
  { SCCIDTYPE_STRING | FI_123R2OS2CHART,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R2OS2CHART) },
  { SCCIDTYPE_STRING | FI_WINWORKSSS4,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORKSSS4) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO7NB,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO7NB) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO7GR,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO7GR) },
  { SCCIDTYPE_STRING | FI_123R6,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R6) },
  { SCCIDTYPE_STRING | FI_MACEXCEL4,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACEXCEL4) },
  { SCCIDTYPE_STRING | FI_MACEXCEL5,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACEXCEL5) },
  { SCCIDTYPE_STRING | FI_EXCEL97,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL97) },
  { SCCIDTYPE_STRING | FI_EXCEL3WORKBOOK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL3WORKBOOK) },

  { SCCIDTYPE_STRING | FI_EXCEL4WORKBOOK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL4WORKBOOK) },
  { SCCIDTYPE_STRING | FI_MACEXCEL4WORKBOOK,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACEXCEL4WORKBOOK) },
  { SCCIDTYPE_STRING | FI_REGMACEXCEL4WB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_REGMACEXCEL4WB) },
  { SCCIDTYPE_STRING | FI_123R9,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_123R9) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO8,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO8) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO9NB,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO9NB) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO10NB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO10NB) },
  { SCCIDTYPE_STRING | FI_EXCEL2000,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2000) },
  { SCCIDTYPE_STRING | FI_EXCEL2002,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2002) },
  { SCCIDTYPE_STRING | FI_STAROFFICECALC52,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICECALC52) },
  { SCCIDTYPE_STRING | FI_STAROFFICEDRAW6,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEDRAW6) },
  { SCCIDTYPE_STRING | FI_STAROFFICEIMPRESS6,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEIMPRESS6) },
  { SCCIDTYPE_STRING | FI_STAROFFICECALC6,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICECALC6) },
  { SCCIDTYPE_STRING | FI_STAROFFICEWRITER6,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEWRITER6) },
  { SCCIDTYPE_STRING | FI_STAROFFICEDRAW8,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEDRAW8) },
  { SCCIDTYPE_STRING | FI_STAROFFICEIMPRESS8,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEIMPRESS8) },
  { SCCIDTYPE_STRING | FI_STAROFFICEWRITER8,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEWRITER8) },
  { SCCIDTYPE_STRING | FI_STAROFFICECALC8,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICECALC8) },
  { SCCIDTYPE_STRING | FI_STAROFFICEDRAW9,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEDRAW9) },
  { SCCIDTYPE_STRING | FI_STAROFFICEIMPRESS9,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEIMPRESS9) },
  { SCCIDTYPE_STRING | FI_STAROFFICEWRITER9,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEWRITER9) },
  { SCCIDTYPE_STRING | FI_STAROFFICECALC9,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICECALC9) },

  { SCCIDTYPE_STRING | FI_OPENOFFICEDRAW1,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEDRAW1) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEIMPRESS1,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEIMPRESS1) },
  { SCCIDTYPE_STRING | FI_OPENOFFICECALC1,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICECALC1) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEWRITER1,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEWRITER1) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEDRAW2,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEDRAW2) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEIMPRESS2,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEIMPRESS2) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEWRITER2,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEWRITER2) },
  { SCCIDTYPE_STRING | FI_OPENOFFICECALC2,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICECALC2) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEDRAW3,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEDRAW3) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEIMPRESS3,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEIMPRESS3) },
  { SCCIDTYPE_STRING | FI_OPENOFFICEWRITER3,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICEWRITER3) },
  { SCCIDTYPE_STRING | FI_OPENOFFICECALC3,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OPENOFFICECALC3) },
  { SCCIDTYPE_STRING | FI_ORACLEOPENOFFICEDRAW3,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ORACLEOPENOFFICEDRAW3) },
  { SCCIDTYPE_STRING | FI_ORACLEOPENOFFICEIMPRESS3,    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ORACLEOPENOFFICEIMPRESS3) },
  { SCCIDTYPE_STRING | FI_ORACLEOPENOFFICEWRITER3,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ORACLEOPENOFFICEWRITER3) },
  { SCCIDTYPE_STRING | FI_ORACLEOPENOFFICECALC3,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ORACLEOPENOFFICECALC3) },

  { SCCIDTYPE_STRING | FI_SYMPHONYPRESENTATION,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SYMPHONYPRESENTATION) },
  { SCCIDTYPE_STRING | FI_SYMPHONYDOCUMENT,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SYMPHONYDOCUMENT) },
  { SCCIDTYPE_STRING | FI_SYMPHONYSPREADSHEET,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SYMPHONYSPREADSHEET) },

  { SCCIDTYPE_STRING | FI_VISIO2003,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_VISIO2003) },
  { SCCIDTYPE_STRING | FI_YAHOOIM,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_YAHOOIM) },

  { SCCIDTYPE_STRING | FI_WPINFORMS1,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPINFORMS1) },
  { SCCIDTYPE_STRING | FI_SNAPSHOTTEXT,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SNAPSHOTTEXT) },
  { SCCIDTYPE_STRING | FI_SNAPSHOTBMP,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SNAPSHOTBMP) },
  { SCCIDTYPE_STRING | FI_ICF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ICF) },
  { SCCIDTYPE_STRING | FI_ESCHER,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ESCHER) },
  { SCCIDTYPE_STRING | FI_JBIG2,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JBIG2) },

  { SCCIDTYPE_STRING | FI_WORD4,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORD4) },
  { SCCIDTYPE_STRING | FI_WORD5,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORD5) },
  { SCCIDTYPE_STRING | FI_WORDSTAR5,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR5) },
  { SCCIDTYPE_STRING | FI_WORDSTAR4,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR4) },
  { SCCIDTYPE_STRING | FI_WORDSTAR2000,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDSTAR2000) },
  { SCCIDTYPE_STRING | FI_WORDPERFECT5,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDPERFECT5) },
  { SCCIDTYPE_STRING | FI_MULTIMATE36,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MULTIMATE36) },
  { SCCIDTYPE_STRING | FI_MULTIMATEADV,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MULTIMATEADV) },

  { SCCIDTYPE_STRING | FI_RIFFWAVE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RIFFWAVE) },
  { SCCIDTYPE_STRING | FI_RIFFAVI,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RIFFAVI) },
  { SCCIDTYPE_STRING | FI_MIDI,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIDI) },
  { SCCIDTYPE_STRING | FI_DIRECTOR,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DIRECTOR) },
  LO_FISTR_DEFINE(FI_FLASH6),
  LO_FISTR_DEFINE(FI_FLASH9),
  LO_FISTR_DEFINE(FI_FLASH10),
  { SCCIDTYPE_STRING | FI_QUICKTIME,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUICKTIME) },
  { SCCIDTYPE_STRING | FI_MP3_ID31,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MP3_ID31) },
  { SCCIDTYPE_STRING | FI_MP3_ID32,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MP3_ID32) },
  { SCCIDTYPE_STRING | FI_ID31,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ID31) },
  { SCCIDTYPE_STRING | FI_ID32,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ID32) },
  { SCCIDTYPE_STRING | FI_MP3,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MP3) },
  { SCCIDTYPE_STRING | FI_MPGAV1L1,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPGAV1L1) },
  { SCCIDTYPE_STRING | FI_MPGAV1L2,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPGAV1L2) },
  { SCCIDTYPE_STRING | FI_MPGAV2L1,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPGAV2L1) },
  { SCCIDTYPE_STRING | FI_MPGAV2L2,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPGAV2L2) },
  { SCCIDTYPE_STRING | FI_MPGAV2L3,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPGAV2L3) },
  { SCCIDTYPE_STRING | FI_ASF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ASF) },
  { SCCIDTYPE_STRING | FI_WMV,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WMV) },
  { SCCIDTYPE_STRING | FI_WMA,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WMA) },
  { SCCIDTYPE_STRING | FI_DVR_MS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DVR_MS) },
  { SCCIDTYPE_STRING | FI_REALMEDIA,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_REALMEDIA) },
  { SCCIDTYPE_STRING | FI_MPEG1,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPEG1) },
  { SCCIDTYPE_STRING | FI_MPEG2,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPEG2) },
  { SCCIDTYPE_STRING | FI_ISOBASEMEDIAFILE,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ISOBASEMEDIAFILE) },
  { SCCIDTYPE_STRING | FI_MPEG4,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPEG4) },
  { SCCIDTYPE_STRING | FI_MPEG7,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MPEG7) },
  { SCCIDTYPE_STRING | FI_RIFF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RIFF) },

  { SCCIDTYPE_STRING | FI_EXECUTABLE,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXECUTABLE) },
  { SCCIDTYPE_STRING | FI_JAVACLASS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JAVACLASS) },
  { SCCIDTYPE_STRING | FI_COM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_COM) },
  { SCCIDTYPE_STRING | FI_ZIP,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ZIP) },
  { SCCIDTYPE_STRING | FI_ZIPEXE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ZIPEXE) },
  { SCCIDTYPE_STRING | FI_ARC,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ARC) },
  { SCCIDTYPE_STRING | FI_BINDER,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_BINDER) },
  { SCCIDTYPE_STRING | FI_UNIXCOMP,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UNIXCOMP) },
  { SCCIDTYPE_STRING | FI_TAR,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TAR) },
  { SCCIDTYPE_STRING | FI_NSF6,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_NSF6) },
  { SCCIDTYPE_STRING | FI_MSCAB,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSCAB) },
  { SCCIDTYPE_STRING | FI_RAR,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RAR) },
  { SCCIDTYPE_STRING | FI_RAREXE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RAREXE) },
  { SCCIDTYPE_STRING | FI_MICROSOFTINFOPATH,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MICROSOFTINFOPATH) },
  { SCCIDTYPE_STRING | FI_ONENOTE2007,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ONENOTE2007) },
  { SCCIDTYPE_STRING | FI_ACCESSSNAPSHOT,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ACCESSSNAPSHOT) },

  { SCCIDTYPE_STRING | FI_UNKNOWN,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UNKNOWN) },
  { SCCIDTYPE_STRING | FI_ENCRYPTED_UNKNOWNMSFTOFFICEDOC, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENCRYPTED_UNKNOWNMSFTOFFICEDOC) },

  { SCCIDTYPE_STRING | FI_ASCII,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ASCII) },
  { SCCIDTYPE_STRING | FI_HEX,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEX) },
  { SCCIDTYPE_STRING | FI_ANSI,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ANSI) },
  { SCCIDTYPE_STRING | FI_UNICODE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UNICODE) },
  { SCCIDTYPE_STRING | FI_ASCII8,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ASCII8) },
  { SCCIDTYPE_STRING | FI_ANSI8,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ANSI8) },
  { SCCIDTYPE_STRING | FI_DONTVIEW,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DONTVIEW) },
  { SCCIDTYPE_STRING | FI_MAC,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MAC) },
  { SCCIDTYPE_STRING | FI_MAC8,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MAC8) },
  { SCCIDTYPE_STRING | FI_SHIFTJIS,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SHIFTJIS) },
  { SCCIDTYPE_STRING | FI_CHINESEGB,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CHINESEGB) },
  { SCCIDTYPE_STRING | FI_HANGEUL,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANGEUL) },
  { SCCIDTYPE_STRING | FI_CHINESEBIG5,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CHINESEBIG5) },
  { SCCIDTYPE_STRING | FI_LATIN2,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_LATIN2) },
  { SCCIDTYPE_STRING | FI_JAPANESE_EUC,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JAPANESE_EUC) },
  { SCCIDTYPE_STRING | FI_7BITTEXT,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_7BITTEXT) },
  { SCCIDTYPE_STRING | FI_JAPANESE_JIS,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_JAPANESE_JIS) },
  { SCCIDTYPE_STRING | FI_CENTRALEU_1250,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CENTRALEU_1250) },
  { SCCIDTYPE_STRING | FI_HEBREW_OLDCODE,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_OLDCODE) },
  { SCCIDTYPE_STRING | FI_HEBREW_WINDOWS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HEBREW_WINDOWS) },

  { SCCIDTYPE_STRING | FI_WPSPLUS,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WPSPLUS) },
  { SCCIDTYPE_STRING | FI_MACWORD6,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORD6) },
  { SCCIDTYPE_STRING | FI_WINWORD97,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD97) },
  { SCCIDTYPE_STRING | FI_RAINBOW,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RAINBOW) },
  { SCCIDTYPE_STRING | FI_INTERLEAF,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_INTERLEAF) },
  { SCCIDTYPE_STRING | FI_MIFF3,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF3) },
  { SCCIDTYPE_STRING | FI_MIFF4,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF4) },
  { SCCIDTYPE_STRING | FI_MIFF5,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF5) },
  { SCCIDTYPE_STRING | FI_TEXTMAIL,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TEXTMAIL) },
  { SCCIDTYPE_STRING | FI_MACWORD97,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MACWORD97) },
  { SCCIDTYPE_STRING | FI_INTERLEAFJ,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_INTERLEAFJ) },
  { SCCIDTYPE_STRING | FI_MIFF3J,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF3J) },
  { SCCIDTYPE_STRING | FI_MIFF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFF) },
  { SCCIDTYPE_STRING | FI_TEXT,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_TEXT) },
  { SCCIDTYPE_STRING | FI_HDML,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HDML) },
  { SCCIDTYPE_STRING | FI_CHTML,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CHTML) },
  { SCCIDTYPE_STRING | FI_XHTMLB,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XHTMLB) },
  { SCCIDTYPE_STRING | FI_HTMLAG,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTMLAG) },
  { SCCIDTYPE_STRING | FI_HTMLWCA,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HTMLWCA) },
  { SCCIDTYPE_STRING | FI_WIRELESSHTML,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WIRELESSHTML) },
  { SCCIDTYPE_STRING | FI_MIFFG,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MIFFG) },
  { SCCIDTYPE_STRING | FI_HANGULWP97,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANGULWP97) },
  { SCCIDTYPE_STRING | FI_HANGULWP2002,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HANGULWP2002) },

  { SCCIDTYPE_STRING | FI_HARVARDWINDOWS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HARVARDWINDOWS) },
  { SCCIDTYPE_STRING | FI_IGES,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IGES) },
  { SCCIDTYPE_STRING | FI_IBMPIF,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_IBMPIF) },
  { SCCIDTYPE_STRING | FI_XBITMAP,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XBITMAP) },
  { SCCIDTYPE_STRING | FI_XPIXMAP,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XPIXMAP) },
  { SCCIDTYPE_STRING | FI_CALSRASTER,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CALSRASTER) },
  { SCCIDTYPE_STRING | FI_PNG,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PNG) },
  { SCCIDTYPE_STRING | FI_XDUMP,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XDUMP) },
  { SCCIDTYPE_STRING | FI_CORELDRAWCLIPART,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAWCLIPART) },
  { SCCIDTYPE_STRING | FI_HPGALLERY,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_HPGALLERY) },
  { SCCIDTYPE_STRING | FI_GDF,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_GDF) },
  { SCCIDTYPE_STRING | FI_DESIGNER,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DESIGNER) },
  { SCCIDTYPE_STRING | FI_DESIGNER7,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DESIGNER7) },
  { SCCIDTYPE_STRING | FI_POSTSCRIPT,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POSTSCRIPT) },
  { SCCIDTYPE_STRING | FI_POWERPOINT97,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT97) },
  { SCCIDTYPE_STRING | FI_CORELDRAW6,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW6) },
  { SCCIDTYPE_STRING | FI_CORELDRAW7,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_CORELDRAW7) },
  { SCCIDTYPE_STRING | FI_STAROFFICEIMPRESS52,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEIMPRESS52) },
  { SCCIDTYPE_STRING | FI_KINGSOFTSPREADSHEETS,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_KINGSOFTSPREADSHEETS) },
  { SCCIDTYPE_STRING | FI_KINGSOFTWRITER,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_KINGSOFTWRITER) },
  { SCCIDTYPE_STRING | FI_WINWORD2002,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2002) },
  { SCCIDTYPE_STRING | FI_WINWORD2003,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2003) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO11NB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO11NB) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO12NB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO12NB) },
  { SCCIDTYPE_STRING | FI_QUATTROPROX4NB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPROX4NB) },
  { SCCIDTYPE_STRING | FI_EXCEL2003,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2003) },
  { SCCIDTYPE_STRING | FI_EXCELXML2003,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCELXML2003) },
  { SCCIDTYPE_STRING | FI_EXCEL2007,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2007) },
  { SCCIDTYPE_STRING | FI_ENCRYPTED_EXCEL2007,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENCRYPTED_EXCEL2007) },
  { SCCIDTYPE_STRING | FI_EXCEL2007_BINARY,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2007_BINARY) },
  { SCCIDTYPE_STRING | FI_ENCRYPTED_EXCEL2007_BINARY,  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENCRYPTED_EXCEL2007_BINARY) },
  { SCCIDTYPE_STRING | FI_EXCEL2007_ADDINMACRO,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2007_ADDINMACRO) },

  { SCCIDTYPE_STRING | FI_UTF8,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UTF8) },
  { SCCIDTYPE_STRING | FI_OUTLOOK_PST,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_OUTLOOK_PST) },
  { SCCIDTYPE_STRING | FI_WINWORD2002,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2002) },
  { SCCIDTYPE_STRING | FI_WINWORD2003,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2003) },
  { SCCIDTYPE_STRING | FI_WORDXML2003,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WORDXML2003) },
  { SCCIDTYPE_STRING | FI_WINWORD2007,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2007) },

  { SCCIDTYPE_STRING | FI_ENCRYPTED_WORD2007,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ENCRYPTED_WORD2007) },
  { SCCIDTYPE_STRING | FI_WINWORDTEMPLATE2007,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORDTEMPLATE2007) },
  { SCCIDTYPE_STRING | FI_MSWORDPICTURE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_MSWORDPICTURE) },
  { SCCIDTYPE_STRING | FI_QUATTROPRO11NB,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_QUATTROPRO11NB) },
  { SCCIDTYPE_STRING | FI_EXCEL2003,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2003) },
  { SCCIDTYPE_STRING | FI_STAROFFICEDRAW6,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEDRAW6) },
  { SCCIDTYPE_STRING | FI_STAROFFICEIMPRESS6,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEIMPRESS6) },
  { SCCIDTYPE_STRING | FI_STAROFFICECALC6,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICECALC6) },
  { SCCIDTYPE_STRING | FI_STAROFFICEWRITER6,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_STAROFFICEWRITER6) },
  { SCCIDTYPE_STRING | FI_UTF8,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_UTF8) },

  LO_FISTR_DEFINE(FI_WINWORD2010),
  LO_FISTR_DEFINE(FI_WINWORDTEMPLATE2010),
  LO_FISTR_DEFINE(FI_WINWORD2010_MACRO),
  LO_FISTR_DEFINE(FI_WINWORDTEMPLATE2010_MACRO),
  LO_FISTR_DEFINE(FI_ENCRYPTED_WORD2010),
  LO_FISTR_DEFINE(FI_EXCEL2010),
  LO_FISTR_DEFINE(FI_EXCEL2010_MACRO),
  LO_FISTR_DEFINE(FI_EXCELTEMPLATE2010),
  LO_FISTR_DEFINE(FI_EXCELTEMPLATE2010_MACRO),
  LO_FISTR_DEFINE(FI_ENCRYPTED_EXCEL2010),
  LO_FISTR_DEFINE(FI_EXCEL2010_BINARY),
  LO_FISTR_DEFINE(FI_ENCRYPTED_EXCEL2010_BINARY),
  LO_FISTR_DEFINE(FI_EXCEL2010_ADDINMACRO),
  LO_FISTR_DEFINE(FI_POWERPOINT2010),
  LO_FISTR_DEFINE(FI_POWERPOINTTEMPLATE2010),
  LO_FISTR_DEFINE(FI_POWERPOINTTEMPLATE2010_MACRO),
  LO_FISTR_DEFINE(FI_POWERPOINTSLIDESHOW2010),
  LO_FISTR_DEFINE(FI_POWERPOINT2010_MACRO),
  LO_FISTR_DEFINE(FI_POWERPOINTSLIDESHOW2010_MACRO),
  LO_FISTR_DEFINE(FI_ENCRYPTED_PPT2010),
  LO_FISTR_DEFINE(FI_WIN_EXPLORERCMD),
  LO_FISTR_DEFINE(FI_7Z),
  LO_FISTR_DEFINE(FI_7ZEXE),
  LO_FISTR_DEFINE(FI_TRILLIAN_TEXT),
  LO_FISTR_DEFINE(FI_TRILLIAN_XML),
  LO_FISTR_DEFINE(FI_LIVEMESSENGER),
  LO_FISTR_DEFINE(FI_AOLMESSENGER),
  LO_FISTR_DEFINE(FI_WINDOWSHELP),
  LO_FISTR_DEFINE(FI_WIN_COMPILEDHELP),
  LO_FISTR_DEFINE(FI_WIN_SHORTCUT),
  LO_FISTR_DEFINE(FI_TRUETYPEFONT),
  LO_FISTR_DEFINE(FI_TRUETYPECOLLECTION),
  LO_FISTR_DEFINE(FI_TRUETYPEFONT_MAC),
  { SCCIDTYPE_STRING | FI_DRM_WORD,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_WORD) },
  { SCCIDTYPE_STRING | FI_DRM_EXCEL,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_EXCEL) },
  { SCCIDTYPE_STRING | FI_DRM_POWERPOINT,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_POWERPOINT) },
  { SCCIDTYPE_STRING | FI_DRM_WORD2007,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_WORD2007) },
  { SCCIDTYPE_STRING | FI_DRM_EXCEL2007,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_EXCEL2007) },
  { SCCIDTYPE_STRING | FI_DRM_POWERPOINT2007,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_POWERPOINT2007) },

  { SCCIDTYPE_STRING | FI_DRM_UNKNOWN,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DRM_UNKNOWN) },
  { SCCIDTYPE_STRING | FI_ORACLE_IRM,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ORACLE_IRM) },
  { SCCIDTYPE_STRING | FI_PERFORMANCE,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_PERFORMANCE) },

  { SCCIDTYPE_STRING | FI_AUTODESK_DWF,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_AUTODESK_DWF) },

  { SCCIDTYPE_STRING | FI_XMP,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XMP) },
  { SCCIDTYPE_STRING | FI_ADOBEINDESIGN,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_ADOBEINDESIGN) },
  { SCCIDTYPE_STRING | FI_XML_ADOBEINX,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_ADOBEINX) },
  { SCCIDTYPE_STRING | FI_XML_VISIO,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_XML_VISIO) },

  { SCCIDTYPE_STRING | FI_DXL_MAILARCHIVE,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXL_MAILARCHIVE) },
  { SCCIDTYPE_STRING | FI_DXL_MAILMESSAGE,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXL_MAILMESSAGE) },
  { SCCIDTYPE_STRING | FI_DXL_GENERIC,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_DXL_GENERIC) },

  { SCCIDTYPE_STRING | FI_POWERPOINTTEMPLATE2007,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTTEMPLATE2007) },
  { SCCIDTYPE_STRING | FI_POWERPOINTSLIDESHOW2007,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTSLIDESHOW2007) },
  { SCCIDTYPE_STRING | FI_POWERPOINT2007_MACRO,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINT2007_MACRO) },
  { SCCIDTYPE_STRING | FI_POWERPOINTTEMPLATE2007_MACRO,  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTTEMPLATE2007_MACRO) },
  { SCCIDTYPE_STRING | FI_POWERPOINTSLIDESHOW2007_MACRO, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_POWERPOINTSLIDESHOW2007_MACRO) },
  { SCCIDTYPE_STRING | FI_WINWORD2007_MACRO,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORD2007_MACRO) },
  { SCCIDTYPE_STRING | FI_WINWORDTEMPLATE2007_MACRO,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_WINWORDTEMPLATE2007_MACRO) },
  { SCCIDTYPE_STRING | FI_EXCELTEMPLATE2007,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCELTEMPLATE2007) },
  { SCCIDTYPE_STRING | FI_EXCEL2007_MACRO,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCEL2007_MACRO) },
  { SCCIDTYPE_STRING | FI_EXCELTEMPLATE2007_MACRO,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_EXCELTEMPLATE2007_MACRO) },
  { SCCIDTYPE_STRING | FI_RPIX,							 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_RPIX) },
  { SCCIDTYPE_STRING | FI_SAMSUNGJUNGUM,							 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_FI_SAMSUNGJUNGUM) },

  { SCCID_FILTERLISTREG,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_FILTERLISTREG) },
  { SCCID_DELISTREG,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DELISTREG) },

  { SCCID_DEFAULTDISPLAYFONT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONT) },
  { SCCID_PRINTHEADER,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PRINTHEADER) },
  { SCCID_DEFAULTPRINTMARGINS,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTMARGINS) },

  { SCCID_DXF_ISOMETRIC,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_ISOMETRIC) },
  { SCCID_DXF_PLAN,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_PLAN) },
  { SCCID_DXF_FRONT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_FRONT) },
  { SCCID_DXF_RIGHT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_RIGHT) },
  { SCCID_DXF_DEFAULTVIEW,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_DEFAULTVIEW) },
  { SCCID_DXF_ACTIVEVIEW,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXF_ACTIVEVIEW) },

  { SCCID_TEXT_UUENCODE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_TEXT_UUENCODE) },
  { SCCID_TEXT_XXENCODE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_TEXT_XXENCODE) },
  { SCCID_TEXT_BASE64ENCODE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_TEXT_BASE64ENCODE) },
  { SCCID_CCOD_GENERATOR,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_CCOD_GENERATOR) },

  { SCCID_EXE_OLDHEADER,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OLDHEADER) },
  { SCCID_EXE_TECHINFO,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_TECHINFO) },
  { SCCID_EXE_LOADHI,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOADHI) },
  { SCCID_EXE_DLLFILE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DLLFILE) },

  { SCCID_EXE_WINEXE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WINEXE) },
  { SCCID_EXE_LIBRARY,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LIBRARY) },
  { SCCID_EXE_OPSYSOS2,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OPSYSOS2) },
  { SCCID_EXE_OPSYSWIN,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OPSYSWIN) },
  { SCCID_EXE_OPSYSDOS,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OPSYSDOS) },
  { SCCID_EXE_OPSYSWIN386,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OPSYSWIN386) },
  { SCCID_EXE_UNKNOWN,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_UNKNOWN) },
  { SCCID_EXE_SUPPORTLONG,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SUPPORTLONG) },
  { SCCID_EXE_PROTECTMODE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_PROTECTMODE) },
  { SCCID_EXE_PROPFONT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_PROPFONT) },
  { SCCID_EXE_FASTLOAD,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_FASTLOAD) },
  { SCCID_EXE_BIT,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_BIT) },
  { SCCID_EXE_OFFSET,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OFFSET) },
  { SCCID_EXE_LENGTH,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LENGTH) },
  { SCCID_EXE_ENTRIES,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ENTRIES) },

  { SCCID_EXE_SEGMENTS,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SEGMENTS) },
  { SCCID_EXE_BYTES,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_BYTES) },
  { SCCID_EXE_SINGLEDATA,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SINGLEDATA) },
  { SCCID_EXE_MULTIDATA,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MULTIDATA) },
  { SCCID_EXE_PROTMODE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_PROTMODE) },
  { SCCID_EXE_NOTCOMPT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOTCOMPT) },
  { SCCID_EXE_WINAPI,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WINAPI) },
  { SCCID_EXE_COMPT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_COMPT) },
  { SCCID_EXE_SEGLOADER,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SEGLOADER) },
  { SCCID_EXE_LINKERR,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LINKERR) },
  { SCCID_EXE_EMSBANK,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EMSBANK) },
  { SCCID_EXE_PREINIT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_PREINIT) },
  { SCCID_EXE_GLOBINIT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_GLOBINIT) },
  { SCCID_EXE_ISSET,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ISSET) },
  { SCCID_EXE_SEGTABLE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SEGTABLE) },
  { SCCID_EXE_NUM,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NUM) },

  { SCCID_EXE_TYPE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_TYPE) },
  { SCCID_EXE_OFFSETCAP,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OFFSETCAP) },
  { SCCID_EXE_LENGTHCAP,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LENGTHCAP) },
  { SCCID_EXE_ALLOC,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ALLOC) },
  { SCCID_EXE_FLAGS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_FLAGS) },
  { SCCID_EXE_SMTYPE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SMTYPE) },
  { SCCID_EXE_DATA,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DATA) },
  { SCCID_EXE_CODE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_CODE) },
  { SCCID_EXE_READONLY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_READONLY) },
  { SCCID_EXE_EXEONLY,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXEONLY) },
  { SCCID_EXE_READWRITE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_READWRITE) },
  { SCCID_EXE_EXEREAD,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXEREAD) },
  { SCCID_EXE_SHARED,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SHARED) },
  { SCCID_EXE_NONSHARED,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NONSHARED) },
  { SCCID_EXE_PRELOAD,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_PRELOAD) },
  { SCCID_EXE_LOADONCALL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOADONCALL) },

  { SCCID_EXE_EXPDOWN,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXPDOWN) },
  { SCCID_EXE_NOEXPDOWN,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOEXPDOWN) },
  { SCCID_EXE_CONFORM,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_CONFORM) },
  { SCCID_EXE_NONCONFORM,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NONCONFORM) },
  { SCCID_EXE_NOIOPL,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOIOPL) },
  { SCCID_EXE_IOPL,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IOPL) },
  { SCCID_EXE_286DPL,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_286DPL) },
  { SCCID_EXE_32BIT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_32BIT) },
  { SCCID_EXE_HUGE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_HUGE) },
  { SCCID_EXE_RELOCS,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_RELOCS) },
  { SCCID_EXE_ITERATE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ITERATE) },
  { SCCID_EXE_MOVEABLE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MOVEABLE) },
  { SCCID_EXE_FIXED,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_FIXED) },
  { SCCID_EXE_DISCARD,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DISCARD) },
  { SCCID_EXE_NONDISCARD,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NONDISCARD) },
  { SCCID_EXE_SMSHARED,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SMSHARED) },

  { SCCID_EXE_SMNONSHARED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SMNONSHARED) },
  { SCCID_EXE_RESEXPORT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_RESEXPORT) },
  { SCCID_EXE_NONRESEXPORT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NONRESEXPORT) },
  { SCCID_EXE_ENTRYTABLE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ENTRYTABLE) },
  { SCCID_EXE_NAME,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NAME) },
  { SCCID_EXE_IMPORTTABLE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IMPORTTABLE) },
  { SCCID_EXE_WIN16EXE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WIN16EXE) },
  { SCCID_EXE_WIN32EXE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WIN32EXE) },
  { SCCID_EXE_WIN64EXE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WIN64EXE) },
  { SCCID_EXE_IMOPTHEADER,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IMOPTHEADER) },
  { SCCID_EXE_INTEL860,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_INTEL860) },
  { SCCID_EXE_INTEL386,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_INTEL386) },
  { SCCID_EXE_IA64,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IA64) },
  { SCCID_EXE_R10000,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_R10000) },
  { SCCID_EXE_WCEMIPSV2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WCEMIPSV2) },
  { SCCID_EXE_SH3,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SH3) },
  { SCCID_EXE_SH3DSP,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SH3DSP) },
  { SCCID_EXE_SH3E,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SH3E) },
  { SCCID_EXE_SH4,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SH4) },
  { SCCID_EXE_SH5,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SH5) },
  { SCCID_EXE_ARM,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ARM) },
  { SCCID_EXE_THUMB,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_THUMB) },
  { SCCID_EXE_AM33,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_AM33) },
  { SCCID_EXE_POWERPC,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_POWERPC) },
  { SCCID_EXE_POWERPCFP,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_POWERPCFP) },
  { SCCID_EXE_MIPS16,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPS16) },
  { SCCID_EXE_ALPHA64,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ALPHA64) },
  { SCCID_EXE_MIPSFPU,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPSFPU) },
  { SCCID_EXE_MIPSFPU16,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPSFPU16) },
  { SCCID_EXE_TRICORE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_TRICORE) },
  { SCCID_EXE_CEF,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_CEF) },
  { SCCID_EXE_EBC,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EBC) },
  { SCCID_EXE_AMD64,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_AMD64) },
  { SCCID_EXE_M32R,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_M32R) },
  { SCCID_EXE_CEE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_CEE) },
  { SCCID_EXE_MIPS,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPS) },
  { SCCID_EXE_MIPS4000,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPS4000) },
  { SCCID_EXE_DECALPHA,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DECALPHA) },
  { SCCID_EXE_RELOCSTRIPPED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_RELOCSTRIPPED) },
  { SCCID_EXE_EXEFILE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXEFILE) },
  { SCCID_EXE_LINESTRIPPED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LINESTRIPPED) },

  { SCCID_EXE_LOCSTRIPPED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOCSTRIPPED) },
  { SCCID_EXE_16BITWORD,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_16BITWORD) },
  { SCCID_EXE_LOWBYTEREV,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOWBYTEREV) },
  { SCCID_EXE_32BITWORD,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_32BITWORD) },
  { SCCID_EXE_DBGSTRIPPED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DBGSTRIPPED) },
  { SCCID_EXE_SYSFILE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SYSFILE) },
  { SCCID_EXE_FILEISDLL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_FILEISDLL) },
  { SCCID_EXE_HIBYTEREV,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_HIBYTEREV) },
  { SCCID_EXE_UNKSUBSYS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_UNKSUBSYS) },
  { SCCID_EXE_NOSUBSYSREQ,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOSUBSYSREQ) },
  { SCCID_EXE_GUISUBSYS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_GUISUBSYS) },
  { SCCID_EXE_WINSUBSYS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WINSUBSYS) },
  { SCCID_EXE_OS2SUBSYS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OS2SUBSYS) },
  { SCCID_EXE_POSIXSUBSYS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_POSIXSUBSYS) },
  { SCCID_EXE_DLLINITROUT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DLLINITROUT) },
  { SCCID_EXE_DLLTHRDTERM,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DLLTHRDTERM) },

  { SCCID_EXE_DLLTHRDINIT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DLLTHRDINIT) },
  { SCCID_EXE_BREAKONLOAD,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_BREAKONLOAD) },
  { SCCID_EXE_DEBUGONLOAD,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DEBUGONLOAD) },
  { SCCID_EXE_EXPORTVADDR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXPORTVADDR) },
  { SCCID_EXE_EXPORTSIZE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXPORTSIZE) },
  { SCCID_EXE_IMPORTVADDR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IMPORTVADDR) },
  { SCCID_EXE_IMPORTSIZE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IMPORTSIZE) },
  { SCCID_EXE_RESOURCEDIR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_RESOURCEDIR) },
  { SCCID_EXE_VADDRESS,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_VADDRESS) },
  { SCCID_EXE_RESOURCESIZ,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_RESOURCESIZ) },
  { SCCID_EXE_EXCEPTVADDR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXCEPTVADDR) },
  { SCCID_EXE_EXCEPTSIZE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXCEPTSIZE) },
  { SCCID_EXE_SECURVADDR,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SECURVADDR) },
  { SCCID_EXE_SECURSIZE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SECURSIZE) },
  { SCCID_EXE_BASERELOC,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_BASERELOC) },
  { SCCID_EXE_BASESIZE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_BASESIZE) },

  { SCCID_EXE_DEBUGVADDR,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DEBUGVADDR) },
  { SCCID_EXE_DEBUGSIZE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DEBUGSIZE) },
  { SCCID_EXE_COPYVADDR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_COPYVADDR) },
  { SCCID_EXE_COPYSIZE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_COPYSIZE) },
  { SCCID_EXE_MIPSVADDR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPSVADDR) },
  { SCCID_EXE_MIPSSIZE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_MIPSSIZE) },
  { SCCID_EXE_TLSVADDR,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_TLSVADDR) },
  { SCCID_EXE_TLSSIZE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_TLSSIZE) },
  { SCCID_EXE_LOADVADDR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOADVADDR) },
  { SCCID_EXE_LOADSIZE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_LOADSIZE) },
  { SCCID_EXE_EDATA,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EDATA) },
  { SCCID_EXE_IDATA,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IDATA) },
  { SCCID_EXE_NOEXPFUNC,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOEXPFUNC) },
  { SCCID_EXE_ORDINAL,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_ORDINAL) },
  { SCCID_EXE_EXTRYPT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXTRYPT) },

  { SCCID_EXE_FUNCNAME,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_FUNCNAME) },
  { SCCID_EXE_CODESECT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_CODESECT) },
  { SCCID_EXE_IDATASECT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_IDATASECT) },
  { SCCID_EXE_UNIDATASECT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_UNIDATASECT) },
  { SCCID_EXE_COMMENTSECT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_COMMENTSECT) },
  { SCCID_EXE_OVRLAYSECT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_OVRLAYSECT) },
  { SCCID_EXE_NOTPARTSECT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOTPARTSECT) },
  { SCCID_EXE_COMDATSECT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_COMDATSECT) },
  { SCCID_EXE_DISCARDSECT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_DISCARDSECT) },
  { SCCID_EXE_NOCACHSECT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOCACHSECT) },
  { SCCID_EXE_NOPAGESECT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_NOPAGESECT) },
  { SCCID_EXE_SHARESECT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_SHARESECT) },
  { SCCID_EXE_EXESECT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_EXESECT) },
  { SCCID_EXE_READSECT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_READSECT) },
  { SCCID_EXE_WRITESECT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXE_WRITESECT) },

  { SCCID_EXEINIT_HEADERINFO,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_HEADERINFO) },
  { SCCID_EXEINIT_SIGNATURE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIGNATURE) },
  { SCCID_EXEINIT_LASTPAGE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_LASTPAGE) },
  { SCCID_EXEINIT_TOTPAGES,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_TOTPAGES) },

  { SCCID_EXEINIT_RELOCITEMS,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RELOCITEMS) },
  { SCCID_EXEINIT_PARAINHEAD,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_PARAINHEAD) },
  { SCCID_EXEINIT_MINPARA,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MINPARA) },
  { SCCID_EXEINIT_MAXPARA,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MAXPARA) },
  { SCCID_EXEINIT_INITSS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITSS) },
  { SCCID_EXEINIT_INITSP,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITSP) },
  { SCCID_EXEINIT_COMPCHKSUM,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_COMPCHKSUM) },
  { SCCID_EXEINIT_INITIP,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITIP) },
  { SCCID_EXEINIT_INITCODE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITCODE) },
  { SCCID_EXEINIT_RELOCTABLE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RELOCTABLE) },
  { SCCID_EXEINIT_OVERNUM,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_OVERNUM) },
  { SCCID_EXEINIT_RESERVED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RESERVED) },
  { SCCID_EXEINIT_OFFSET2HDR,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_OFFSET2HDR) },
  { SCCID_EXEINIT_MEMNEEDED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MEMNEEDED) },
  { SCCID_EXEINIT_GENINFO,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_GENINFO) },
  { SCCID_EXEINIT_MODNAME,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MODNAME) },

  { SCCID_EXEINIT_DESCRIP,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_DESCRIP) },
  { SCCID_EXEINIT_OS,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_OS) },
  { SCCID_EXEINIT_LINKVER,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_LINKVER) },
  { SCCID_EXEINIT_CHECKSUM,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_CHECKSUM) },
  { SCCID_EXEINIT_ADS,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_ADS) },
  { SCCID_EXEINIT_INITHS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITHS) },
  { SCCID_EXEINIT_INITCSIP,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITCSIP) },
  { SCCID_EXEINIT_INITCSSP,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_INITCSSP) },
  { SCCID_EXEINIT_ADDNFO,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_ADDNFO) },
  { SCCID_EXEINIT_FLOADSTART,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_FLOADSTART) },
  { SCCID_EXEINIT_FLOADLEN,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_FLOADLEN) },
  { SCCID_EXEINIT_WINVER,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_WINVER) },
  { SCCID_EXEINIT_ENTRYTABLE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_ENTRYTABLE) },
  { SCCID_EXEINIT_SEGTABLE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SEGTABLE) },
  { SCCID_EXEINIT_RESOURCETABLE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RESOURCETABLE) },

  { SCCID_EXEINIT_RESTABLENAME,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RESTABLENAME) },
  { SCCID_EXEINIT_MODULEREF,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MODULEREF) },
  { SCCID_EXEINIT_IMPORTEDTABLE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_IMPORTEDTABLE) },
  { SCCID_EXEINIT_NONRESTABLE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NONRESTABLE) },
  { SCCID_EXEINIT_MOVEENPT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MOVEENPT) },
  { SCCID_EXEINIT_ALIGN,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_ALIGN) },
  { SCCID_EXEINIT_FLAGS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_FLAGS) },
  { SCCID_EXEINIT_IMAGEHEADER,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_IMAGEHEADER) },
  { SCCID_EXEINIT_MACHINE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MACHINE) },
  { SCCID_EXEINIT_NUMSECTION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMSECTION) },
  { SCCID_EXEINIT_PSYMBOL,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_PSYMBOL) },
  { SCCID_EXEINIT_NUMSYMBOL,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMSYMBOL) },
  { SCCID_EXEINIT_SIZOPHEAD,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZOPHEAD) },
  { SCCID_EXEINIT_MAGIC,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_MAGIC) },
  { SCCID_EXEINIT_SIZECODE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZECODE) },

  { SCCID_EXEINIT_NUMRELOC,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMRELOC) },
  { SCCID_EXEINIT_NUMLINES,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMLINES) },
  { SCCID_EXEINIT_EXPTABLE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_EXPTABLE) },
  { SCCID_EXEINIT_NAME,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NAME) },
  { SCCID_EXEINIT_CHARACTER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_CHARACTER) },
  { SCCID_EXEINIT_TIMEDATE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_TIMEDATE) },
  { SCCID_EXEINIT_VERSION,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_VERSION) },
  { SCCID_EXEINIT_BASE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_BASE) },
  { SCCID_EXEINIT_NUMFUNCT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMFUNCT) },
  { SCCID_EXEINIT_NUMNAMES,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_NUMNAMES) },
  { SCCID_EXEINIT_IMPTABLE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_IMPTABLE) },
  { SCCID_EXEINIT_LINKVERS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_LINKVERS) },
  { SCCID_EXEINIT_BLANK,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_BLANK) },

  { SCCID_EXEINIT_SIZINITDATA,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZINITDATA) },
  { SCCID_EXEINIT_SIZUNITDATA,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZUNITDATA) },
  { SCCID_EXEINIT_ADDRENTRY,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_ADDRENTRY) },
  { SCCID_EXEINIT_BASECODE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_BASECODE) },
  { SCCID_EXEINIT_BASEDATA,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_BASEDATA) },
  { SCCID_EXEINIT_IMAGEBASE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_IMAGEBASE) },
  { SCCID_EXEINIT_SECTALIGN,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SECTALIGN) },
  { SCCID_EXEINIT_FILEALIGN,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_FILEALIGN) },
  { SCCID_EXEINIT_OSVER,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_OSVER) },
  { SCCID_EXEINIT_IMAGEVER,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_IMAGEVER) },
  { SCCID_EXEINIT_SUBSYSVER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SUBSYSVER) },
  { SCCID_EXEINIT_RESERVED1,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_RESERVED1) },
  { SCCID_EXEINIT_SIZEIMAGE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZEIMAGE) },
  { SCCID_EXEINIT_SIZEHEAD,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZEHEAD) },
  { SCCID_EXEINIT_SUBSYS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SUBSYS) },

  { SCCID_EXEINIT_DLLCHAR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_DLLCHAR) },
  { SCCID_EXEINIT_SIZESTKR,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZESTKR) },
  { SCCID_EXEINIT_SIZESTKC,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZESTKC) },
  { SCCID_EXEINIT_SIZEHEAPR,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZEHEAPR) },
  { SCCID_EXEINIT_SIZEHEAPC,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZEHEAPC) },
  { SCCID_EXEINIT_LOADFLAG,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_LOADFLAG) },
  { SCCID_EXEINIT_SIZEDDIR,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZEDDIR) },
  { SCCID_EXEINIT_DATADIR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_DATADIR) },
  { SCCID_EXEINIT_SECTTABLE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SECTTABLE) },
  { SCCID_EXEINIT_SECTNAME,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SECTNAME) },
  { SCCID_EXEINIT_VIRTSIZE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_VIRTSIZE) },
  { SCCID_EXEINIT_VIRTADDR,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_VIRTADDR) },
  { SCCID_EXEINIT_SIZERAWDATA,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_SIZERAWDATA) },
  { SCCID_EXEINIT_PRAWDATA,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_PRAWDATA) },
  { SCCID_EXEINIT_PRELOC,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_PRELOC) },
  { SCCID_EXEINIT_PNLINES,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_EXEINIT_PNLINES) },

  { SCCID_VCARD_URL,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_URL) },
  { SCCID_VCARD_CID,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_CID) },
  { SCCID_VCARD_ADDRESS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_ADDRESS) },
  { SCCID_VCARD_AGENT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_AGENT) },
  { SCCID_VCARD_DISPLAY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_DISPLAY) },
  { SCCID_VCARD_BIRTHDATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_BIRTHDATE) },
  { SCCID_VCARD_EMAIL,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_EMAIL) },
  { SCCID_VCARD_FORMATTEDNAME,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_FORMATTEDNAME) },
  { SCCID_VCARD_GEOPOS,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_GEOPOS) },
  { SCCID_VCARD_PUBLICKEY,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PUBLICKEY) },
  { SCCID_VCARD_LOGO,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_LOGO) },
  { SCCID_VCARD_DELIVERYLABEL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_DELIVERYLABEL) },
  { SCCID_VCARD_MAILER,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_MAILER) },
  { SCCID_VCARD_NAME,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_NAME) },
  { SCCID_VCARD_COMMENT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_COMMENT) },
  { SCCID_VCARD_ORGANIZATION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_ORGANIZATION) },
  { SCCID_VCARD_PHOTOGRAPH,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PHOTOGRAPH) },
  { SCCID_VCARD_LASTREV,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_LASTREV) },
  { SCCID_VCARD_ROLE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_ROLE) },
  { SCCID_VCARD_SOUND,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_SOUND) },
  { SCCID_VCARD_TELENUMBER,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_TELENUMBER) },
  { SCCID_VCARD_TITLE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_TITLE) },
  { SCCID_VCARD_TIMEZONE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_TIMEZONE) },
  { SCCID_VCARD_UID,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_UID) },
  { SCCID_VCARD_UNIRESLOCATOR,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_UNIRESLOCATOR) },
  { SCCID_VCARD_VERSION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_VERSION) },
  { SCCID_VCARD_FAMILY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_FAMILY) },
  { SCCID_VCARD_FIRST,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_FIRST) },
  { SCCID_VCARD_MIDDLE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_MIDDLE) },
  { SCCID_VCARD_PREFIX,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PREFIX) },
  { SCCID_VCARD_SUFFIX,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_SUFFIX) },
  { SCCID_VCARD_POADDRESS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_POADDRESS) },
  { SCCID_VCARD_EXTADDRESS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_EXTADDRESS) },
  { SCCID_VCARD_STREET,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_STREET) },
  { SCCID_VCARD_LOCALITY,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_LOCALITY) },
  { SCCID_VCARD_REGION,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_REGION) },
  { SCCID_VCARD_POSTALCODE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_POSTALCODE) },
  { SCCID_VCARD_COUNTRY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_COUNTRY) },
  { SCCID_VCARD_DOMESTIC,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_DOMESTIC) },
  { SCCID_VCARD_INTERNATIONAL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_INTERNATIONAL) },
  { SCCID_VCARD_POSTAL,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_POSTAL) },
  { SCCID_VCARD_PARCEL,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PARCEL) },
  { SCCID_VCARD_HOME,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_HOME) },
  { SCCID_VCARD_WORK,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_WORK) },
  { SCCID_VCARD_PREFERRED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PREFERRED) },
  { SCCID_VCARD_VOICE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_VOICE) },
  { SCCID_VCARD_FAX,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_FAX) },
  { SCCID_VCARD_MESSAGE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_MESSAGE) },
  { SCCID_VCARD_CELL,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_CELL) },
  { SCCID_VCARD_PAGER,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PAGER) },
  { SCCID_VCARD_BBS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_BBS) },
  { SCCID_VCARD_MODEM,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_MODEM) },
  { SCCID_VCARD_CAR,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_CAR) },
  { SCCID_VCARD_ISDN,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_ISDN) },
  { SCCID_VCARD_VIDEO,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_VIDEO) },
  { SCCID_VCARD_AOL,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_AOL) },
  { SCCID_VCARD_APPLELINK,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_APPLELINK) },
  { SCCID_VCARD_ATTMAIL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_ATTMAIL) },
  { SCCID_VCARD_CIS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_CIS) },
  { SCCID_VCARD_EWORLD,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_EWORLD) },
  { SCCID_VCARD_INTERNET,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_INTERNET) },
  { SCCID_VCARD_IBMMAIL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_IBMMAIL) },
  { SCCID_VCARD_MCIMAIL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_MCIMAIL) },
  { SCCID_VCARD_POWERSHARE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_POWERSHARE) },
  { SCCID_VCARD_PRODIGY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PRODIGY) },
  { SCCID_VCARD_TLX,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_TLX) },
  { SCCID_VCARD_X400,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_X400) },
  { SCCID_VCARD_X509,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_X509) },
  { SCCID_VCARD_PGP,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCARD_PGP) },

  { SCCID_VCAL_ATTACHMENT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_ATTACHMENT) },
  { SCCID_VCAL_AUDIO_REMINDER,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_AUDIO_REMINDER) },
  { SCCID_VCAL_CLASSIFICATION,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_CLASSIFICATION) },
  { SCCID_VCAL_DTCREATED,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTCREATED) },
  { SCCID_VCAL_DTCOMPLETED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTCOMPLETED) },
  { SCCID_VCAL_DESCRIPTION,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DESCRIPTION) },
  { SCCID_VCAL_DISPLAY_REMINDER,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DISPLAY_REMINDER) },
  { SCCID_VCAL_DTDUE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTDUE) },
  { SCCID_VCAL_DTEND,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTEND) },
  { SCCID_VCAL_DTEXCEPTION,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTEXCEPTION) },
  { SCCID_VCAL_EXCEPTION_RULE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_EXCEPTION_RULE) },
  { SCCID_VCAL_LAST_MODIFIED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_LAST_MODIFIED) },
  { SCCID_VCAL_LOCATION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_LOCATION) },
  { SCCID_VCAL_MAIL_REMINDER,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_MAIL_REMINDER) },
  { SCCID_VCAL_NUMBER_RECURRENCES,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_NUMBER_RECURRENCES) },
  { SCCID_VCAL_PROCEDURE_REMINDER,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_PROCEDURE_REMINDER) },
  { SCCID_VCAL_RELATED_TO,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_RELATED_TO) },
  { SCCID_VCAL_DTRECURRENCE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTRECURRENCE) },
  { SCCID_VCAL_RECURRENCE_RULE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_RECURRENCE_RULE) },
  { SCCID_VCAL_RESOURCES,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_RESOURCES) },
  { SCCID_VCAL_SEQUENCE_NUMBER,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_SEQUENCE_NUMBER) },
  { SCCID_VCAL_DTSTART,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_DTSTART) },
  { SCCID_VCAL_TIME_TRANSPARENCY,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_TIME_TRANSPARENCY) },
  { SCCID_VCAL_EXPECT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_EXPECT) },
  { SCCID_VCAL_RSVP,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_RSVP) },
  { SCCID_VCAL_ATTENDEE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_ATTENDEE) },
  { SCCID_VCAL_RUN_TIME,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_RUN_TIME) },
  { SCCID_VCAL_SNOOZE_TIME,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_SNOOZE_TIME) },
  { SCCID_VCAL_REPEAT_COUNT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_REPEAT_COUNT) },
  { SCCID_VCAL_AUDIO_CONTENT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_AUDIO_CONTENT) },
  { SCCID_VCAL_NOTE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_VCAL_NOTE) },

  { SCCID_MAIL_TO,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_TO) },
  { SCCID_MAIL_CC,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_CC) },
  { SCCID_MAIL_BCC,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BCC) },
  { SCCID_MAIL_SUBJECT,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SUBJECT) },
  { SCCID_MAIL_MSGFLAG,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_MSGFLAG) },
  { SCCID_MAIL_FLAGSTS,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_FLAGSTS) },
  { SCCID_MAIL_EXPIRES,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_EXPIRES) },
  { SCCID_MAIL_CATEGORIES,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_CATEGORIES) },
  { SCCID_MAIL_IMPORTANCE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_IMPORTANCE) },
  { SCCID_MAIL_SENSITIVITY,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SENSITIVITY) },
  { SCCID_MAIL_LOCATION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_LOCATION) },
  { SCCID_MAIL_FULLNAME,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_FULLNAME) },
  { SCCID_MAIL_JOBTITLE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_JOBTITLE) },
  { SCCID_MAIL_COMPANY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_COMPANY) },
  { SCCID_MAIL_EMAIL,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_EMAIL) },
  { SCCID_MAIL_WEBPAGE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_WEBPAGE) },
  { SCCID_MAIL_FROM,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_FROM) },
  { SCCID_MAIL_ON_BEHALF_OF,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ON_BEHALF_OF) },
  { SCCID_MAIL_GENDER,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_GENDER) },
  { SCCID_MAIL_NICKNAME,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_NICKNAME) },
  { SCCID_MAIL_DEPARTMENT,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_DEPARTMENT) },
  { SCCID_MAIL_TITLE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_TITLE) },
  { SCCID_MAIL_HOMEADDRESS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEADDRESS) },
  { SCCID_MAIL_BUSINESSADDRESS,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSADDRESS) },
  { SCCID_MAIL_OTHERADDRESS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERADDRESS) },
  { SCCID_MAIL_IMADDRESS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_IMADDRESS) },
  { SCCID_MAIL_DISPLAYAS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_DISPLAYAS) },
  { SCCID_MAIL_DISPLAYAS2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_DISPLAYAS2) },
  { SCCID_MAIL_DISPLAYAS3,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_DISPLAYAS3) },
  { SCCID_MAIL_FILEAS,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_FILEAS) },
  { SCCID_MAIL_ASSISTANTPHONE,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ASSISTANTPHONE) },
  { SCCID_MAIL_BUSINESSPHONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSPHONE) },
  { SCCID_MAIL_BUSINESSPHONE2,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSPHONE2) },
  { SCCID_MAIL_BUSINESSFAX,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSFAX) },
  { SCCID_MAIL_CALLBACKPHONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_CALLBACKPHONE) },
  { SCCID_MAIL_CARPHONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_CARPHONE) },
  { SCCID_MAIL_COMPANYPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_COMPANYPHONE) },
  { SCCID_MAIL_HOMEPHONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEPHONE) },
  { SCCID_MAIL_HOMEPHONE2,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEPHONE2) },
  { SCCID_MAIL_HOMEFAX,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEFAX) },
  { SCCID_MAIL_ISDN,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ISDN) },
  { SCCID_MAIL_MOBILEPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_MOBILEPHONE) },
  { SCCID_MAIL_OTHERPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERPHONE) },
  { SCCID_MAIL_OTHERFAX,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERFAX) },
  { SCCID_MAIL_PAGERPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_PAGERPHONE) },
  { SCCID_MAIL_PRIMARYPHONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_PRIMARYPHONE) },
  { SCCID_MAIL_RADIOPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_RADIOPHONE) },
  { SCCID_MAIL_TELEXPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_TELEXPHONE) },
  { SCCID_MAIL_TTYTTDPHONE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_TTYTTDPHONE) },
  { SCCID_MAIL_REMINDERTOPIC,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_REMINDERTOPIC) },
  { SCCID_MAIL_EMAIL,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_EMAIL) },
  { SCCID_MAIL_EMAIL2,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_EMAIL2) },
  { SCCID_MAIL_EMAIL3,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_EMAIL3) },
  { SCCID_MAIL_BUSINESSSTREET,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSSTREET) },
  { SCCID_MAIL_BUSINESSPOBOX,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSPOBOX) },
  { SCCID_MAIL_BUSINESSCITY,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSCITY) },
  { SCCID_MAIL_BUSINESSSTATE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSSTATE) },
  { SCCID_MAIL_BUSINESSPOSTALCODE,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSPOSTALCODE) },
  { SCCID_MAIL_BUSINESSCOUNTRY,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BUSINESSCOUNTRY) },
  { SCCID_MAIL_HOMESTREET,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMESTREET) },
  { SCCID_MAIL_HOMEPOBOX,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEPOBOX) },
  { SCCID_MAIL_HOMECITY,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMECITY) },
  { SCCID_MAIL_HOMESTATE,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMESTATE) },
  { SCCID_MAIL_HOMEPOSTALCODE,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMEPOSTALCODE) },
  { SCCID_MAIL_HOMECOUNTRY,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_HOMECOUNTRY) },
  { SCCID_MAIL_OTHERSTREET,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERSTREET) },
  { SCCID_MAIL_OTHERPOBOX,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERPOBOX) },
  { SCCID_MAIL_OTHERCITY,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERCITY) },
  { SCCID_MAIL_OTHERSTATE,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERSTATE) },
  { SCCID_MAIL_OTHERPOSTALCODE,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERPOSTALCODE) },
  { SCCID_MAIL_OTHERCOUNTRY,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OTHERCOUNTRY) },
  { SCCID_MAIL_PERSONALHOMEPAGE,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_PERSONALHOMEPAGE) },
  { SCCID_MAIL_INTERNETFREEBUSYADDR,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_INTERNETFREEBUSYADDR) },
  { SCCID_MAIL_MANAGERSNAME,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_MANAGERSNAME) },
  { SCCID_MAIL_ASSISTANTSNAME,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ASSISTANTSNAME) },
  { SCCID_MAIL_OFFICE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_OFFICE) },
  { SCCID_MAIL_PROFESSION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_PROFESSION) },
  { SCCID_MAIL_SPOUSESNAME,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SPOUSESNAME) },
  { SCCID_MAIL_ANNIVERSARY,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ANNIVERSARY) },
  { SCCID_MAIL_BIRTHDAY,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_BIRTHDAY) },
  { SCCID_MAIL_NORMALIZED_SUBJECT,                                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_NORMALIZED_SUBJECT)},

  { SCCID_MAILFIELD_DISPLAY_TO,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_DISPLAY_TO) },
  { SCCID_MAILFIELD_SUBJECT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SUBJECT) },
  { SCCID_MAILFIELD_DISPLAY_CC,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_DISPLAY_CC) },
  { SCCID_MAILFIELD_DISPLAY_BCC,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_DISPLAY_BCC) },
  { SCCID_MAILFIELD_IMPORTANCE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_IMPORTANCE) },
  { SCCID_MAILFIELD_SENSITIVITY,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENSITIVITY) },
  { SCCID_MAILFIELD_FLAGSTS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_FLAGSTS) },
  { SCCID_MAILFIELD_ALTERNATE_RECIPIENT_ALLOWED,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_ALTERNATE_RECIPIENT_ALLOWED) },
  { SCCID_MAILFIELD_PRIORITY,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_PRIORITY) },
  { SCCID_MAILFIELD_CLIENT_SUBMIT_TIME,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CLIENT_SUBMIT_TIME) },
  { SCCID_MAILFIELD_CREATION_TIME,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CREATION_TIME) },
  { SCCID_MAILFIELD_LAST_MODIFICATION_TIME,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_LAST_MODIFICATION_TIME) },
  { SCCID_MAILFIELD_PROVIDER_SUBMIT_TIME,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_PROVIDER_SUBMIT_TIME) },
  { SCCID_MAILFIELD_CONVERSATION_INDEX,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CONVERSATION_INDEX) },
  { SCCID_MAILFIELD_CONVERSATION_TOPIC,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CONVERSATION_TOPIC) },
  { SCCID_MAILFIELD_MESSAGE_CC_ME,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_CC_ME) },
  { SCCID_MAILFIELD_MESSAGE_DELIVERY_TIME,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_DELIVERY_TIME) },
  { SCCID_MAILFIELD_MSGFLAG,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MSGFLAG) },
  { SCCID_MAILFIELD_MESSAGE_SIZE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_SIZE) },
  { SCCID_MAILFIELD_MESSAGE_SUBMISSION_ID,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_SUBMISSION_ID) },
  { SCCID_MAILFIELD_MESSAGE_CLASS,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_CLASS) },
  { SCCID_MAILFIELD_ORIGINATOR_DELIVERY_REPORT_REQUESTED,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_ORIGINATOR_DELIVERY_REPORT_REQUESTED) },
  { SCCID_MAILFIELD_READ_RECEIPT_REQUESTED,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_READ_RECEIPT_REQUESTED) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_ADDRTYPE,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_ADDRTYPE) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_EMAIL_ADDRESS,   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_EMAIL_ADDRESS) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_ENTRYID,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_ENTRYID) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_NAME,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_NAME) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_SEARCH_KEY,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_SEARCH_KEY) },
  { SCCID_MAILFIELD_RECEIVED_BY_ADDRTYPE,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECEIVED_BY_ADDRTYPE) },
  { SCCID_MAILFIELD_RECEIVED_BY_EMAIL_ADDRESS,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECEIVED_BY_EMAIL_ADDRESS) },
  { SCCID_MAILFIELD_RECEIVED_BY_ENTRYID,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECEIVED_BY_ENTRYID) },
  { SCCID_MAILFIELD_RECEIVED_BY_NAME,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECEIVED_BY_NAME) },
  { SCCID_MAILFIELD_RECEIVED_BY_SEARCH_KEY,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECEIVED_BY_SEARCH_KEY) },
  { SCCID_MAILFIELD_RTF_IN_SYNC,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_IN_SYNC) },
  { SCCID_MAILFIELD_RTF_SYNC_BODY_COUNT,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_SYNC_BODY_COUNT) },
  { SCCID_MAILFIELD_RTF_SYNC_BODY_CRC,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_SYNC_BODY_CRC) },
  { SCCID_MAILFIELD_RTF_SYNC_BODY_TAG,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_SYNC_BODY_TAG) },
  { SCCID_MAILFIELD_RTF_SYNC_PREFIX_COUNT,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_SYNC_PREFIX_COUNT) },
  { SCCID_MAILFIELD_RTF_SYNC_TRAILING_COUNT,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RTF_SYNC_TRAILING_COUNT) },
  { SCCID_MAILFIELD_SEARCH_KEY,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SEARCH_KEY) },
  { SCCID_MAILFIELD_SENDER_ADDRTYPE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_ADDRTYPE) },
  { SCCID_MAILFIELD_SENDER_EMAIL_ADDRESS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_EMAIL_ADDRESS) },
  { SCCID_MAILFIELD_SENDER_ENTRYID,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_ENTRYID) },
  { SCCID_MAILFIELD_SENDER_NAME,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_NAME) },
  { SCCID_MAILFIELD_SENDER_SEARCH_KEY,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_SEARCH_KEY) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_ADDRTYPE,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_ADDRTYPE) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_EMAIL_ADDRESS,   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_EMAIL_ADDRESS) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_ENTRYID,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_ENTRYID) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_NAME,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_NAME) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_SEARCH_KEY,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_SEARCH_KEY) },
  { SCCID_MAILFIELD_TRANSPORT_MESSAGE_HEADERS,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_TRANSPORT_MESSAGE_HEADERS) },
  { SCCID_MAILFIELD_AUTO_FORWARDED,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_AUTO_FORWARDED) },
  { SCCID_MAILFIELD_DEFERRED_DELIVERY_TIME,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_DEFERRED_DELIVERY_TIME) },
  { SCCID_MAILFIELD_EXPIRY_TIME,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_EXPIRY_TIME) },
  { SCCID_MAILFIELD_LATEST_DELIVERY_TIME,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_LATEST_DELIVERY_TIME) },
  { SCCID_MAILFIELD_RECIPIENT_REASSIGNMENT_PROHIBITED, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RECIPIENT_REASSIGNMENT_PROHIBITED) },
  { SCCID_MAILFIELD_REPLY_TIME,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_REPLY_TIME) },
  { SCCID_MAILFIELD_REPORT_TAG,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_REPORT_TAG) },
  { SCCID_MAILFIELD_RESPONSE_REQUESTED,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RESPONSE_REQUESTED) },
  { SCCID_MAILFIELD_REPLY_REQUESTED,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_REPLY_REQUESTED) },
  { SCCID_MAILFIELD_DELETE_AFTER_SUBMIT,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_DELETE_AFTER_SUBMIT) },
  { SCCID_MAILFIELD_MESSAGE_LOCALE_ID,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_LOCALE_ID) },
  { SCCID_MAILFIELD_CREATOR_NAME,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CREATOR_NAME) },
  { SCCID_MAILFIELD_CREATOR_ENTRYID,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_CREATOR_ENTRYID) },
  { SCCID_MAILFIELD_LAST_MODIFIER_NAME,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_LAST_MODIFIER_NAME) },
  { SCCID_MAILFIELD_LAST_MODIFIER_ENTRYID,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_LAST_MODIFIER_ENTRYID) },
  { SCCID_MAILFIELD_INTERNET_ARTICLE_NUMBER,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_INTERNET_ARTICLE_NUMBER) },
  { SCCID_MAILFIELD_NT_SECURITY_DESCRIPTOR,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_NT_SECURITY_DESCRIPTOR) },
  { SCCID_MAILFIELD_TRUST_SENDER,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_TRUST_SENDER) },
  { SCCID_MAILFIELD_INTERNET_MESSAGE_ID,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_INTERNET_MESSAGE_ID) },
  { SCCID_MAILFIELD_ATTR_HIDDEN,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_ATTR_HIDDEN) },
  { SCCID_MAILFIELD_ATTR_SYSTEM,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_ATTR_SYSTEM) },
  { SCCID_MAILFIELD_ATTR_READONLY,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_ATTR_READONLY) },
  { SCCID_MAILFIELD_INTERNET_CPID,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_INTERNET_CPID) },
  { SCCID_MAILFIELD_MESSAGE_CODEPAGE,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MESSAGE_CODEPAGE) },
  { SCCID_MAILFIELD_SENDER_FLAGS,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENDER_FLAGS) },
  { SCCID_MAILFIELD_SENT_REPRESENTING_FLAGS,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_SENT_REPRESENTING_FLAGS) },
  { SCCID_MAILFIELD_RCVD_BY_FLAGS,           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_BY_FLAGS) },
  { SCCID_MAILFIELD_RCVD_REPRESENTING_FLAGS,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_RCVD_REPRESENTING_FLAGS) },
  { SCCID_MAILFIELD_INET_MAIL_OVERRIDE_FORMAT,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_INET_MAIL_OVERRIDE_FORMAT) },
  { SCCID_MAILFIELD_MSG_EDITOR_FORMAT,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_MSG_EDITOR_FORMAT) },
  { SCCID_MAILFIELD_PROFILE_CONNECT_FLAGS,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_PROFILE_CONNECT_FLAGS) },
  { SCCID_MAILFIELD_PROOF_OF_DELIVERY_REQUESTED, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_PROOF_OF_DELIVERY_REQUESTED) },
  {	SCCID_MAILFIELD_PROOF_OF_SUBMISSION_REQUESTED,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_PROOF_OF_SUBMISSION_REQUESTED) },
  {	SCCID_MAILFIELD_IN_REPLY_TO_ID,					SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILFIELD_IN_REPLY_TO_ID) },

  { SCCID_MAIL_ATTACHMENT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_ATTACHMENT) },
  { SCCID_MAIL_RTFBODY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_RTFBODY) },
  { SCCID_MAIL_RECEIVED,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_RECEIVED) },
  { SCCID_MAIL_SIZE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SIZE) },
  { SCCID_MAIL_LASTMODIFIED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_LASTMODIFIED) },
  { SCCID_MAIL_NEWSGROUPS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_NEWSGROUPS) },
  { SCCID_MAIL_SUBMITTIME,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SUBMITTIME) },
  { SCCID_MAIL_CCME,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_CCME) },
  { SCCID_MAIL_RECEIVEDDATE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_RECEIVEDDATE) },
  { SCCID_MAIL_DATE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_DATE) },

  { SCCID_MAILTEXT_NOSENDER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILTEXT_NOSENDER) },
  { SCCID_MAILTEXT_NONE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILTEXT_NONE) },
  { SCCID_MAILTEXT_NOSUBJECT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAILTEXT_NOSUBJECT) },

  { SCCID_MAIL_SENT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_SENT) },
  { SCCID_MAIL_APPOINTMENT_DURATION, 	               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_APPOINTMENT_DURATION) },
  { SCCID_MAIL_TASK_COMPLETE,						   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MAIL_TASK_COMPLETE) },

  {SCCID_DXL_NOTEID,								   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXL_NOTEID) },
  {SCCID_DXL_NOTEUNIID,								   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DXL_NOTEUNIID) },

  { SCCID_SCALE_HUNDREDS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_HUNDREDS) },
  { SCCID_SCALE_THOUSANDS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_THOUSANDS) },
  { SCCID_SCALE_MILLIONS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_MILLIONS) },
  { SCCID_SCALE_BILLIONS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_BILLIONS) },
  { SCCID_SCALE_TRILLIONS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_TRILLIONS) },
  { SCCID_SCALE_HUNDREDTHS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_HUNDREDTHS) },
  { SCCID_SCALE_THOUSANDTHS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_THOUSANDTHS) },
  { SCCID_SCALE_MILLIONTHS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_MILLIONTHS) },
  { SCCID_SCALE_BILLIONTHS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_BILLIONTHS) },
  { SCCID_SCALE_TRILLIONTHS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_SCALE_TRILLIONTHS) },

  /* Msproject filter */
  { SCCID_MSPROJECT_PROJECTSHEETNAME,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PROJECTSHEETNAME) },
  { SCCID_MSPROJECT_TASKSHEETNAME,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKSHEETNAME) },
  { SCCID_MSPROJECT_RESOURCESHEETNAME,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCESHEETNAME) },
  { SCCID_MSPROJECT_ASSIGNMENTSHEETNAME,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ASSIGNMENTSHEETNAME) },

  { SCCID_MSPROJECT_CONSTRAINTTYPE0,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE0) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE1,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE1) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE2,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE2) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE3,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE3) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE4,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE4) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE5,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE5) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE6,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE6) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE7,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE7) },

  { SCCID_MSPROJECT_TASKTYPE0,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKTYPE0) },
  { SCCID_MSPROJECT_TASKTYPE1,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKTYPE1) },
  { SCCID_MSPROJECT_TASKTYPE2,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKTYPE2) },

  { SCCID_MSPROJECT_WORKGROUPTYPEA,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUPTYPEA) },
  { SCCID_MSPROJECT_WORKGROUPTYPEB,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUPTYPEB) },
  { SCCID_MSPROJECT_WORKGROUPTYPEC,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUPTYPEC) },
  { SCCID_MSPROJECT_WORKGROUPTYPED,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUPTYPED) },
  { SCCID_MSPROJECT_WORKGROUPTYPEE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUPTYPEE) },

  { SCCID_MSPROJECT_WORKCONTOURTYPEA,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEA) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEB,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEB) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEC,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEC) },
  { SCCID_MSPROJECT_WORKCONTOURTYPED,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPED) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEE,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEE) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEF,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEF) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEG,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEG) },
  { SCCID_MSPROJECT_WORKCONTOURTYPEH,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOURTYPEH) },

  { SCCID_MSPROJECT_PRIORITYTYPE0,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE0) },
  { SCCID_MSPROJECT_PRIORITYTYPE1,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE1) },
  { SCCID_MSPROJECT_PRIORITYTYPE2,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE2) },
  { SCCID_MSPROJECT_PRIORITYTYPE3,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE3) },
  { SCCID_MSPROJECT_PRIORITYTYPE4,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE4) },
  { SCCID_MSPROJECT_PRIORITYTYPE5,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE5) },
  { SCCID_MSPROJECT_PRIORITYTYPE6,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE6) },
  { SCCID_MSPROJECT_PRIORITYTYPE7,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE7) },
  { SCCID_MSPROJECT_PRIORITYTYPE8,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE8) },
  { SCCID_MSPROJECT_PRIORITYTYPE9,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITYTYPE9) },

  { SCCID_MSPROJECT_ACCRUEATTYPE0,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACCRUEATTYPE0) },
  { SCCID_MSPROJECT_ACCRUEATTYPE1,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACCRUEATTYPE1) },
  { SCCID_MSPROJECT_ACCRUEATTYPE2,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACCRUEATTYPE2) },

  { SCCID_MSPROJECT_NAME,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NAME) },
  { SCCID_MSPROJECT_DURATION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION) },
  { SCCID_MSPROJECT_START,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START) },
  { SCCID_MSPROJECT_FINISH,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH) },
  { SCCID_MSPROJECT_UNIQUEIDPREDECESSORS,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_UNIQUEIDPREDECESSORS) },
  { SCCID_MSPROJECT_WORK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORK) },
  { SCCID_MSPROJECT_COST,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST) },
  { SCCID_MSPROJECT_PRIORITY,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRIORITY) },
  { SCCID_MSPROJECT_COMPLETE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COMPLETE) },
  { SCCID_MSPROJECT_WORKCOMPLETE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCOMPLETE) },
  { SCCID_MSPROJECT_UNIQUEID,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_UNIQUEID) },
  { SCCID_MSPROJECT_TASKID,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKID) },
  { SCCID_MSPROJECT_BASELINESTART,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINESTART) },
  { SCCID_MSPROJECT_ACTUALSTART,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALSTART) },
  { SCCID_MSPROJECT_STARTVARIANCE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_STARTVARIANCE) },
  { SCCID_MSPROJECT_BASELINEFINISH,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEFINISH) },
  { SCCID_MSPROJECT_ACTUALFINISH,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALFINISH) },
  { SCCID_MSPROJECT_FINISHVARIANCE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISHVARIANCE) },

  { SCCID_MSPROJECT_BASELINEDURATION,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEDURATION) },
  { SCCID_MSPROJECT_ACTUALDURATION,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALDURATION) },
  { SCCID_MSPROJECT_REMAININGDURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REMAININGDURATION) },
  { SCCID_MSPROJECT_DURATIONVARIANCE,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATIONVARIANCE) },
  { SCCID_MSPROJECT_EARLYSTART,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_EARLYSTART) },
  { SCCID_MSPROJECT_EARLYFINISH,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_EARLYFINISH) },
  { SCCID_MSPROJECT_LATESTART,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LATESTART) },
  { SCCID_MSPROJECT_LATEFINISH,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LATEFINISH) },
  { SCCID_MSPROJECT_FREESLACK,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FREESLACK) },
  { SCCID_MSPROJECT_TOTALSLACK,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TOTALSLACK) },
  { SCCID_MSPROJECT_LEVELINGDELAY,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LEVELINGDELAY) },
  { SCCID_MSPROJECT_BASELINEWORK,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEWORK) },
  { SCCID_MSPROJECT_ACTUALWORK,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALWORK) },
  { SCCID_MSPROJECT_REMAININGWORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REMAININGWORK) },
  { SCCID_MSPROJECT_OVERTIMEWORK,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OVERTIMEWORK) },
  { SCCID_MSPROJECT_ACTUALOVERTIMEWORK,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALOVERTIMEWORK) },
  { SCCID_MSPROJECT_REMAININGOVERTIMEWORK,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REMAININGOVERTIMEWORK) },
  { SCCID_MSPROJECT_REGULARWORK,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REGULARWORK) },
  { SCCID_MSPROJECT_WORKVARIANCE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKVARIANCE) },
  { SCCID_MSPROJECT_FIXEDCOSTACCRUAL,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_COSTVARIANCE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COSTVARIANCE) },
  { SCCID_MSPROJECT_COSTRATETABLE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COSTRATETABLE) },
  { SCCID_MSPROJECT_HYPERLINKHREF,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_HYPERLINKHREF) },
  { SCCID_MSPROJECT_HYPERLINK,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_HYPERLINK) },
  { SCCID_MSPROJECT_HYPERLINKADDRESS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_HYPERLINKADDRESS) },
  { SCCID_MSPROJECT_HYPERLINKSUBADDRESS,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_HYPERLINKSUBADDRESS) },
  { SCCID_MSPROJECT_ASSIGNMENT,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ASSIGNMENT) },
  { SCCID_MSPROJECT_ASSIGNMENTDELAY,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ASSIGNMENTDELAY) },
  { SCCID_MSPROJECT_ASSIGNMENTUNITS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ASSIGNMENTUNITS) },
  { SCCID_MSPROJECT_CONSTRAINTTYPE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTTYPE) },
  { SCCID_MSPROJECT_CONSTRAINTDATE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONSTRAINTDATE) },
  { SCCID_MSPROJECT_CONTACT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONTACT) },
  { SCCID_MSPROJECT_CREATED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CREATED) },
  { SCCID_MSPROJECT_CRITICAL,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CRITICAL) },
  { SCCID_MSPROJECT_EFFORTDRIVEN,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_EFFORTDRIVEN) },
  { SCCID_MSPROJECT_HIDEBAR,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_HIDEBAR) },

  { SCCID_MSPROJECT_FIXEDCOST,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINECOST,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINECOST) },
  { SCCID_MSPROJECT_ACTUALCOST,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALCOST) },
  { SCCID_MSPROJECT_REMAININGCOST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REMAININGCOST) },
  { SCCID_MSPROJECT_OVERTIMECOST,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OVERTIMECOST) },
  { SCCID_MSPROJECT_ACTUALOVERTIMECOST,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTUALOVERTIMECOST) },
  { SCCID_MSPROJECT_REMAININGOVERTIMECOST,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_REMAININGOVERTIMECOST) },

  { SCCID_MSPROJECT_LEVELASSIGNMENTS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LEVELASSIGNMENTS) },
  { SCCID_MSPROJECT_LEVELCANSPLIT,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LEVELCANSPLIT) },
  { SCCID_MSPROJECT_LINKEDFIELD,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_LINKEDFIELD) },
  { SCCID_MSPROJECT_MARKED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_MARKED) },
  { SCCID_MSPROJECT_MILESTONE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_MILESTONE) },
  { SCCID_MSPROJECT_OBJECTS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OBJECTS) },
  { SCCID_MSPROJECT_OUTLINELEVEL,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINELEVEL) },
  { SCCID_MSPROJECT_OUTLINENUMBER,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINENUMBER) },
  { SCCID_MSPROJECT_ROLLUP,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ROLLUP) },
  { SCCID_MSPROJECT_STOP,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_STOP) },
  { SCCID_MSPROJECT_RESUME,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESUME) },
  { SCCID_MSPROJECT_SUBPROJECTFILE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SUBPROJECTFILE) },
  { SCCID_MSPROJECT_SUBPROJECTREADONLY,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SUBPROJECTREADONLY) },
  { SCCID_MSPROJECT_SUMMARY,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SUMMARY) },
  { SCCID_MSPROJECT_UNIQUEIDSUCCESSORS,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_UNIQUEIDSUCCESSORS) },
  { SCCID_MSPROJECT_TYPE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TYPE) },
  { SCCID_MSPROJECT_WORKCONTOUR,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKCONTOUR) },
  { SCCID_MSPROJECT_WBS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WBS) },

  { SCCID_MSPROJECT_COST1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST1) },
  { SCCID_MSPROJECT_COST2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST2) },
  { SCCID_MSPROJECT_COST3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST3) },
  { SCCID_MSPROJECT_COST4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST4) },
  { SCCID_MSPROJECT_COST5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST5) },
  { SCCID_MSPROJECT_COST6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST6) },
  { SCCID_MSPROJECT_COST7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST7) },
  { SCCID_MSPROJECT_COST8,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST8) },
  { SCCID_MSPROJECT_COST9,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST9) },
  { SCCID_MSPROJECT_COST10,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COST10) },

  { SCCID_MSPROJECT_DATE1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE1) },
  { SCCID_MSPROJECT_DATE2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE2) },
  { SCCID_MSPROJECT_DATE3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE3) },
  { SCCID_MSPROJECT_DATE4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE4) },
  { SCCID_MSPROJECT_DATE5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE5) },
  { SCCID_MSPROJECT_DATE6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE6) },
  { SCCID_MSPROJECT_DATE7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE7) },
  { SCCID_MSPROJECT_DATE8,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE8) },
  { SCCID_MSPROJECT_DATE9,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE9) },
  { SCCID_MSPROJECT_DATE10,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DATE10) },

  { SCCID_MSPROJECT_DURATION1,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION1) },
  { SCCID_MSPROJECT_DURATION2,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION2) },
  { SCCID_MSPROJECT_DURATION3,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION3) },
  { SCCID_MSPROJECT_DURATION4,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION4) },
  { SCCID_MSPROJECT_DURATION5,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION5) },
  { SCCID_MSPROJECT_DURATION6,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION6) },
  { SCCID_MSPROJECT_DURATION7,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION7) },
  { SCCID_MSPROJECT_DURATION8,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION8) },
  { SCCID_MSPROJECT_DURATION9,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION9) },
  { SCCID_MSPROJECT_DURATION10,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DURATION10) },

  { SCCID_MSPROJECT_FINISH1,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH1) },
  { SCCID_MSPROJECT_FINISH2,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH2) },
  { SCCID_MSPROJECT_FINISH3,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH3) },
  { SCCID_MSPROJECT_FINISH4,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH4) },
  { SCCID_MSPROJECT_FINISH5,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH5) },
  { SCCID_MSPROJECT_FINISH6,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH6) },
  { SCCID_MSPROJECT_FINISH7,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH7) },
  { SCCID_MSPROJECT_FINISH8,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH8) },
  { SCCID_MSPROJECT_FINISH9,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH9) },
  { SCCID_MSPROJECT_FINISH10,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISH10) },

  { SCCID_MSPROJECT_FLAG1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG1) },
  { SCCID_MSPROJECT_FLAG2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG2) },
  { SCCID_MSPROJECT_FLAG3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG3) },
  { SCCID_MSPROJECT_FLAG4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG4) },
  { SCCID_MSPROJECT_FLAG5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG5) },
  { SCCID_MSPROJECT_FLAG6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG6) },
  { SCCID_MSPROJECT_FLAG7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG7) },
  { SCCID_MSPROJECT_FLAG8,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG8) },
  { SCCID_MSPROJECT_FLAG9,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG9) },
  { SCCID_MSPROJECT_FLAG10,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG10) },
  { SCCID_MSPROJECT_FLAG11,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG11) },
  { SCCID_MSPROJECT_FLAG12,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG12) },
  { SCCID_MSPROJECT_FLAG13,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG13) },
  { SCCID_MSPROJECT_FLAG14,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG14) },
  { SCCID_MSPROJECT_FLAG15,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG15) },
  { SCCID_MSPROJECT_FLAG16,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG16) },
  { SCCID_MSPROJECT_FLAG17,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG17) },
  { SCCID_MSPROJECT_FLAG18,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG18) },
  { SCCID_MSPROJECT_FLAG19,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG19) },
  { SCCID_MSPROJECT_FLAG20,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FLAG20) },

  { SCCID_MSPROJECT_NUMBER1,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER1) },
  { SCCID_MSPROJECT_NUMBER2,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER2) },
  { SCCID_MSPROJECT_NUMBER3,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER3) },
  { SCCID_MSPROJECT_NUMBER4,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER4) },
  { SCCID_MSPROJECT_NUMBER5,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER5) },
  { SCCID_MSPROJECT_NUMBER6,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER6) },
  { SCCID_MSPROJECT_NUMBER7,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER7) },
  { SCCID_MSPROJECT_NUMBER8,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER8) },
  { SCCID_MSPROJECT_NUMBER9,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER9) },
  { SCCID_MSPROJECT_NUMBER10,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER10) },
  { SCCID_MSPROJECT_NUMBER11,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER11) },
  { SCCID_MSPROJECT_NUMBER12,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER12) },
  { SCCID_MSPROJECT_NUMBER13,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER13) },
  { SCCID_MSPROJECT_NUMBER14,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER14) },
  { SCCID_MSPROJECT_NUMBER15,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER15) },
  { SCCID_MSPROJECT_NUMBER16,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER16) },
  { SCCID_MSPROJECT_NUMBER17,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER17) },
  { SCCID_MSPROJECT_NUMBER18,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER18) },
  { SCCID_MSPROJECT_NUMBER19,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER19) },
  { SCCID_MSPROJECT_NUMBER20,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NUMBER20) },

  { SCCID_MSPROJECT_START1,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START1) },
  { SCCID_MSPROJECT_START2,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START2) },
  { SCCID_MSPROJECT_START3,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START3) },
  { SCCID_MSPROJECT_START4,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START4) },
  { SCCID_MSPROJECT_START5,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START5) },
  { SCCID_MSPROJECT_START6,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START6) },
  { SCCID_MSPROJECT_START7,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START7) },
  { SCCID_MSPROJECT_START8,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START8) },
  { SCCID_MSPROJECT_START9,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START9) },
  { SCCID_MSPROJECT_START10,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_START10) },

  { SCCID_MSPROJECT_TEXT1,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT1) },
  { SCCID_MSPROJECT_TEXT2,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT2) },
  { SCCID_MSPROJECT_TEXT3,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT3) },
  { SCCID_MSPROJECT_TEXT4,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT4) },
  { SCCID_MSPROJECT_TEXT5,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT5) },
  { SCCID_MSPROJECT_TEXT6,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT6) },
  { SCCID_MSPROJECT_TEXT7,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT7) },
  { SCCID_MSPROJECT_TEXT8,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT8) },
  { SCCID_MSPROJECT_TEXT9,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT9) },
  { SCCID_MSPROJECT_TEXT10,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT10) },
  { SCCID_MSPROJECT_TEXT11,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT11) },
  { SCCID_MSPROJECT_TEXT12,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT12) },
  { SCCID_MSPROJECT_TEXT13,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT13) },
  { SCCID_MSPROJECT_TEXT14,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT14) },
  { SCCID_MSPROJECT_TEXT15,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT15) },
  { SCCID_MSPROJECT_TEXT16,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT16) },
  { SCCID_MSPROJECT_TEXT17,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT17) },
  { SCCID_MSPROJECT_TEXT18,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT18) },
  { SCCID_MSPROJECT_TEXT19,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT19) },
  { SCCID_MSPROJECT_TEXT20,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT20) },
  { SCCID_MSPROJECT_TEXT21,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT21) },
  { SCCID_MSPROJECT_TEXT22,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT22) },
  { SCCID_MSPROJECT_TEXT23,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT23) },
  { SCCID_MSPROJECT_TEXT24,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT24) },
  { SCCID_MSPROJECT_TEXT25,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT25) },
  { SCCID_MSPROJECT_TEXT26,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT26) },
  { SCCID_MSPROJECT_TEXT27,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT27) },
  { SCCID_MSPROJECT_TEXT28,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT28) },
  { SCCID_MSPROJECT_TEXT29,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT29) },
  { SCCID_MSPROJECT_TEXT30,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TEXT30) },

  { SCCID_MSPROJECT_RESOURCENAME,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCENAME) },
  { SCCID_MSPROJECT_INITIALS,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_INITIALS) },
  { SCCID_MSPROJECT_GROUP,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_GROUP) },
  { SCCID_MSPROJECT_MAXUNITS,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_MAXUNITS) },
  { SCCID_MSPROJECT_STDRATE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_STDRATE) },
  { SCCID_MSPROJECT_OVTRATE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OVTRATE) },
  { SCCID_MSPROJECT_COSTPERUSE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COSTPERUSE) },
  { SCCID_MSPROJECT_ACCRUEAT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACCRUEAT) },
  { SCCID_MSPROJECT_BASECALENDAR,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASECALENDAR) },
  { SCCID_MSPROJECT_CODE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CODE) },
  { SCCID_MSPROJECT_ID,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ID) },
  { SCCID_MSPROJECT_EMAILADDRESS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_EMAILADDRESS) },
  { SCCID_MSPROJECT_AVAILABLEFROM,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_AVAILABLEFROM) },
  { SCCID_MSPROJECT_AVAILABLETO,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_AVAILABLETO) },
  { SCCID_MSPROJECT_WORKGROUP,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WORKGROUP) },
  { SCCID_MSPROJECT_RESOURCEID,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCEID) },
  { SCCID_MSPROJECT_RESOURCEGROUP,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCEGROUP) },
  { SCCID_MSPROJECT_RESOURCEINITIALS,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCEINITIALS) },
  { SCCID_MSPROJECT_CONFIRMED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONFIRMED) },
  { SCCID_MSPROJECT_PEAK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PEAK) },
  { SCCID_MSPROJECT_CANLEVEL,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CANLEVEL) },

  /* new fields for MS 2007 and 2010 */
  { SCCID_MSPROJECT_BASELINE1COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1COST)},
  { SCCID_MSPROJECT_BASELINE2COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2COST) },
  { SCCID_MSPROJECT_BASELINE3COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3COST) },
  { SCCID_MSPROJECT_BASELINE4COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4COST) },
  { SCCID_MSPROJECT_BASELINE5COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5COST) },
  { SCCID_MSPROJECT_BASELINE6COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6COST) },
  { SCCID_MSPROJECT_BASELINE7COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7COST) },
  { SCCID_MSPROJECT_BASELINE8COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8COST) },
  { SCCID_MSPROJECT_BASELINE9COST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9COST) },
  { SCCID_MSPROJECT_BASELINE10COST,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10COST) },

  { SCCID_MSPROJECT_BASELINE1DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1DURATION) },
  { SCCID_MSPROJECT_BASELINE2DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2DURATION) },
  { SCCID_MSPROJECT_BASELINE3DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3DURATION) },
  { SCCID_MSPROJECT_BASELINE4DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4DURATION) },
  { SCCID_MSPROJECT_BASELINE5DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5DURATION) },
  { SCCID_MSPROJECT_BASELINE6DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6DURATION) },
  { SCCID_MSPROJECT_BASELINE7DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7DURATION) },
  { SCCID_MSPROJECT_BASELINE8DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8DURATION) },
  { SCCID_MSPROJECT_BASELINE9DURATION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9DURATION) },
  { SCCID_MSPROJECT_BASELINE10DURATION,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10DURATION) },

  { SCCID_MSPROJECT_BASELINE1FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1FINISH) },
  { SCCID_MSPROJECT_BASELINE2FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2FINISH) },
  { SCCID_MSPROJECT_BASELINE3FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3FINISH) },
  { SCCID_MSPROJECT_BASELINE4FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4FINISH) },
  { SCCID_MSPROJECT_BASELINE5FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5FINISH) },
  { SCCID_MSPROJECT_BASELINE6FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6FINISH) },
  { SCCID_MSPROJECT_BASELINE7FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7FINISH) },
  { SCCID_MSPROJECT_BASELINE8FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8FINISH) },
  { SCCID_MSPROJECT_BASELINE9FINISH,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9FINISH) },
  { SCCID_MSPROJECT_BASELINE10FINISH,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10FINISH) },

  { SCCID_MSPROJECT_BASELINE1START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1START) },
  { SCCID_MSPROJECT_BASELINE2START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2START) },
  { SCCID_MSPROJECT_BASELINE3START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3START) },
  { SCCID_MSPROJECT_BASELINE4START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4START) },
  { SCCID_MSPROJECT_BASELINE5START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5START) },
  { SCCID_MSPROJECT_BASELINE6START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6START) },
  { SCCID_MSPROJECT_BASELINE7START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7START) },
  { SCCID_MSPROJECT_BASELINE8START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8START) },
  { SCCID_MSPROJECT_BASELINE9START,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9START) },
  { SCCID_MSPROJECT_BASELINE10START,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10START) },

  { SCCID_MSPROJECT_BASELINE1WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1WORK) },
  { SCCID_MSPROJECT_BASELINE2WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2WORK) },
  { SCCID_MSPROJECT_BASELINE3WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3WORK) },
  { SCCID_MSPROJECT_BASELINE4WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4WORK) },
  { SCCID_MSPROJECT_BASELINE5WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5WORK) },
  { SCCID_MSPROJECT_BASELINE6WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6WORK) },
  { SCCID_MSPROJECT_BASELINE7WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7WORK) },
  { SCCID_MSPROJECT_BASELINE8WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8WORK) },
  { SCCID_MSPROJECT_BASELINE9WORK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9WORK) },
  { SCCID_MSPROJECT_BASELINE10WORK,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10WORK) },

  { SCCID_MSPROJECT_BASELINE1_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE2_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE3_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE4_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE5_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE6_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE7_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE8_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE9_DELIVERABLE_FINISH,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINE10_DELIVERABLE_FINISH,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_DELIVERABLE_FINISH) },

  { SCCID_MSPROJECT_BASELINE1_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE2_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE3_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE4_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE5_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE6_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE7_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE8_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE9_DELIVERABLE_START,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE10_DELIVERABLE_START,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_DELIVERABLE_START) },

  { SCCID_MSPROJECT_ESTIMATED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ESTIMATED) },
  { SCCID_MSPROJECT_PHYSICALPERCOMPLETE,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PHYSICALPERCOMPLETE) },
  { SCCID_MSPROJECT_DEADLINE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_DEADLINE) },
  { SCCID_MSPROJECT_CONFIRMED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CONFIRMED) },
  { SCCID_MSPROJECT_RECURRING,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RECURRING) },
  { SCCID_MSPROJECT_STARTSLACK,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_STARTSLACK) },
  { SCCID_MSPROJECT_FINISHSLACK,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_FINISHSLACK) },
  { SCCID_MSPROJECT_EARNEDVALUEMETHOD,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_EARNEDVALUEMETHOD) },
  { SCCID_MSPROJECT_BASELINE_DELIVERABLE_START,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE_DELIVERABLE_START) },
  { SCCID_MSPROJECT_BASELINE_DELIVERABLE_FINISH,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE_DELIVERABLE_FINISH) },
  { SCCID_MSPROJECT_BASELINEFIXEDCOST,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEFIXEDCOST) },
  { SCCID_MSPROJECT_MATERIALLABEL,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_MATERIALLABEL) },
  { SCCID_MSPROJECT_WINUSERACCT,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_WINUSERACCT) },
  { SCCID_MSPROJECT_COSTCENTER,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_COSTCENTER) },
  { SCCID_MSPROJECT_PHONETICS,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PHONETICS) },
  { SCCID_MSPROJECT_BUDGET,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BUDGET) },
  { SCCID_MSPROJECT_GENERIC,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_GENERIC) },
  { SCCID_MSPROJECT_BOOKINGTYPE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BOOKINGTYPE) },
  { SCCID_MSPROJECT_BUDGETWORK,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BUDGETWORK) },
  { SCCID_MSPROJECT_BUDGETCOST,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BUDGETCOST) },
  { SCCID_MSPROJECT_ACTIVE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ACTIVE )},
  { SCCID_MSPROJECT_IGNOREWARNING,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_IGNOREWARNING )},
  { SCCID_MSPROJECT_TASKMODE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKMODE )},
  { SCCID_MSPROJECT_TASKCALENDAR,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKCALENDAR)},


  { SCCID_MSPROJECT_BASELINE1_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE2_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE3_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE4_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE5_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE6_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE7_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE8_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE9_BUDGETCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_BUDGETCOST) },
  { SCCID_MSPROJECT_BASELINE10_BUDGETCOST,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_BUDGETCOST) },

  { SCCID_MSPROJECT_BASELINE1_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE2_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE3_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE4_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE5_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE6_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE7_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE8_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE9_BUDGETWORK,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_BUDGETWORK) },
  { SCCID_MSPROJECT_BASELINE10_BUDGETWORK,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_BUDGETWORK) },

  { SCCID_MSPROJECT_BASELINE1_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE2_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE3_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE4_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE5_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE6_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE7_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE8_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE9_FIXEDCOST,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_FIXEDCOST) },
  { SCCID_MSPROJECT_BASELINE10_FIXEDCOST,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_FIXEDCOST) },

  { SCCID_MSPROJECT_BASELINEFIXEDCOSTACCRUAL,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEFIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE1_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE2_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE3_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE4_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE5_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE6_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE7_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE8_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE9_FIXEDCOSTACCRUAL,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_FIXEDCOSTACCRUAL) },
  { SCCID_MSPROJECT_BASELINE10_FIXEDCOSTACCRUAL,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_FIXEDCOSTACCRUAL) },


  { SCCID_MSPROJECT_OUTLINECODE1,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE1) },
  { SCCID_MSPROJECT_OUTLINECODE2,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE2) },
  { SCCID_MSPROJECT_OUTLINECODE3,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE3) },
  { SCCID_MSPROJECT_OUTLINECODE4,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE4) },
  { SCCID_MSPROJECT_OUTLINECODE5,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE5) },
  { SCCID_MSPROJECT_OUTLINECODE6,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE6) },
  { SCCID_MSPROJECT_OUTLINECODE7,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE7) },
  { SCCID_MSPROJECT_OUTLINECODE8,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE8) },
  { SCCID_MSPROJECT_OUTLINECODE9,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE9) },
  { SCCID_MSPROJECT_OUTLINECODE10,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OUTLINECODE10) },
  
  { SCCID_MSPROJECT_BASELINE1_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE2_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE3_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE4_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE5_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE6_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE7_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE8_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE9_ESTIMATED_DURATION,      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_BASELINE10_ESTIMATED_DURATION,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_ESTIMATED_DURATION) },

  { SCCID_MSPROJECT_BASELINE1_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE2_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE3_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE4_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE5_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE6_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE7_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE8_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE9_ESTIMATED_START,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_ESTIMATED_START) },
  { SCCID_MSPROJECT_BASELINE10_ESTIMATED_START,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_ESTIMATED_START) },

  { SCCID_MSPROJECT_BASELINE1_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE1_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE2_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE2_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE3_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE3_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE4_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE4_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE5_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE5_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE6_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE6_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE7_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE7_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE8_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE8_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE9_ESTIMATED_FINISH,        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE9_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_BASELINE10_ESTIMATED_FINISH,       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINE10_ESTIMATED_FINISH) },

  { SCCID_MSPROJECT_ESTIMATED_DURATION,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ESTIMATED_DURATION) },
  { SCCID_MSPROJECT_ESTIMATED_FINISH,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ESTIMATED_FINISH) },
  { SCCID_MSPROJECT_ESTIMATED_START,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_ESTIMATED_START) },

  { SCCID_MSPROJECT_SCHEDULED_DURATION,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SCHEDULED_DURATION) },
  { SCCID_MSPROJECT_SCHEDULED_FINISH,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SCHEDULED_FINISH) },
  { SCCID_MSPROJECT_SCHEDULED_START,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_SCHEDULED_START) },
  { SCCID_MSPROJECT_NOTE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_NOTE) },
  { SCCID_MSPROJECT_BASELINEBUDGETCOST,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEBUDGETCOST) },
  { SCCID_MSPROJECT_BASELINEBUDGETWORK,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_BASELINEBUDGETWORK) },

  { SCCID_MSPROJECT_PLACEHOLDER,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PLACEHOLDER) },
  { SCCID_MSPROJECT_OVERALLOCATED,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_OVERALLOCATED) },
  { SCCID_MSPROJECT_RESOURCETYPE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_RESOURCETYPE) },
  { SCCID_MSPROJECT_PROJECT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PROJECT) },
  { SCCID_MSPROJECT_TASKCALENDARGUID,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKCALENDARGUID) },
  { SCCID_MSPROJECT_GUID,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_GUID) },
  { SCCID_MSPROJECT_CALENDARGUID,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_CALENDARGUID) },
  { SCCID_MSPROJECT_TASKCALENDAR,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_TASKCALENDAR) },
  { SCCID_MSPROJECT_PRELEVELSTART,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRELEVELSTART) },
  { SCCID_MSPROJECT_PRELEVELFINISH,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSPROJECT_PRELEVELFINISH) },

  { SCCID_DEFAULTDISPLAYFONTALIASMAP_COUNT,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_COUNT) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 1, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_1) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 2, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_2) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 3, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_3) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 4, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_4) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 5, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_5) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 6, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_6) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 7, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_7) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 8, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_8) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 9, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_9) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 10, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_10) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 11, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_11) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 12, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_12) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 13, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_13) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 14, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_14) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 15, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_15) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 16, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_16) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 17, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_17) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 18, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_18) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 19, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_19) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 20, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_20) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 21, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_21) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 22, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_22) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 23, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_23) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 24, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_24) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 25, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_25) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 26, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_26) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 27, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_27) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 28, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_28) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 29, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_29) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 30, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_30) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 31, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_31) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 32, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_32) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 33, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_33) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 34, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_34) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 35, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_35) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 36, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_36) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 37, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_37) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 38, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_38) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 39, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_39) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 40, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_40) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 41, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_41) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 42, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_42) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 43, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_43) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 44, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_44) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 45, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_45) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 46, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_46) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 47, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_47) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 48, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_48) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 49, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_49) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 50, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_50) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 51, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_51) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 52, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_52) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 53, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_53) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 54, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_54) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 55, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_55) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 56, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_56) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 57, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_57) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 58, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_58) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 59, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_59) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE + 60, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE_60) },

  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 1, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_1) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 2, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_2) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 3, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_3) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 4, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_4) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 5, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_5) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 6, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_6) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 7, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_7) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 8, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_8) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 9, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_9) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 10, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_10) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 11, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_11) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 12, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_12) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 13, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_13) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 14, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_14) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 15, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_15) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 16, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_16) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 17, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_17) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 18, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_18) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 19, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_19) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 20, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_20) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 21, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_21) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 22, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_22) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 23, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_23) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 24, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_24) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 25, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_25) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 26, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_26) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 27, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_27) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 28, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_28) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 29, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_29) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 30, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_30) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 31, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_31) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 32, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_32) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 33, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_33) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 34, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_34) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 35, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_35) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 36, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_36) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 37, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_37) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 38, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_38) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 39, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_39) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 40, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_40) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 41, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_41) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 42, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_42) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 43, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_43) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 44, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_44) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 45, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_45) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 46, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_46) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 47, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_47) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 48, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_48) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 49, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_49) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 50, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_50) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 51, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_51) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 52, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_52) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 53, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_53) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 54, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_54) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 55, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_55) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 56, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_56) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 57, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_57) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 58, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_58) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 59, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_59) },
  { SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE + 60, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE_60) },

  { SCCID_DEFAULTPRINTFONTALIASMAP_COUNT,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_COUNT) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 1, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_1) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 2, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_2) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 3, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_3) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 4, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_4) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 5, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_5) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 6, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_6) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 7, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_7) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 8, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_8) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 9, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_9) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 10, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_10) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 11, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_11) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 12, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_12) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 13, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_13) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 14, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_14) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 15, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_15) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 16, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_16) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 17, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_17) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 18, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_18) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 19, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_19) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 20, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_20) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 21, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_21) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 22, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_22) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 23, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_23) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 24, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_24) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 25, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_25) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 26, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_26) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 27, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_27) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 28, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_28) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 29, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_29) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 30, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_30) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 31, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_31) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 32, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_32) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 33, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_33) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 34, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_34) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 35, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_35) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 36, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_36) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 37, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_37) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 38, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_38) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 39, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_39) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 40, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_40) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 41, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_41) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 42, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_42) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 43, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_43) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 44, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_44) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 45, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_45) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 46, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_46) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 47, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_47) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 48, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_48) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 49, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_49) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 50, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_50) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 51, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_51) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 52, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_52) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 53, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_53) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 54, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_54) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 55, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_55) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 56, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_56) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 57, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_57) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 58, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_58) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 59, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_59) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE + 60, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE_60) },

  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE,     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 1, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_1) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 2, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_2) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 3, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_3) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 4, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_4) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 5, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_5) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 6, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_6) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 7, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_7) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 8, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_8) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 9, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_9) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 10, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_10) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 11, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_11) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 12, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_12) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 13, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_13) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 14, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_14) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 15, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_15) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 16, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_16) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 17, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_17) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 18, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_18) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 19, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_19) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 20, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_20) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 21, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_21) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 22, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_22) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 23, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_23) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 24, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_24) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 25, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_25) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 26, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_26) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 27, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_27) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 28, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_28) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 29, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_29) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 30, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_30) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 31, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_31) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 32, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_32) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 33, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_33) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 34, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_34) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 35, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_35) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 36, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_36) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 37, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_37) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 38, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_38) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 39, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_39) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 40, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_40) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 41, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_41) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 42, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_42) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 43, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_43) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 44, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_44) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 45, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_45) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 46, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_46) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 47, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_47) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 48, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_48) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 49, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_49) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 50, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_50) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 51, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_51) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 52, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_52) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 53, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_53) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 54, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_54) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 55, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_55) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 56, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_56) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 57, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_57) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 58, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_58) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 59, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_59) },
  { SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE + 60, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE_60) },

  { ( SCCID_MENUBASE + MENU_WP_DRAFT ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_DRAFT) },
  { ( SCCID_MENUBASE + MENU_WP_NORMAL ),                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_NORMAL) },
  { ( SCCID_MENUBASE + MENU_WP_PREVIEW ),                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_PREVIEW) },
  { ( SCCID_MENUBASE + MENU_WP_SIZE ),                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_SIZE) },
  { ( SCCID_MENUBASE + MENU_WP_SIZE_ORIGINAL ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_SIZE_ORIGINAL) },
  { ( SCCID_MENUBASE + MENU_WP_SIZE_FITWINDOW ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_SIZE_FITWINDOW) },
  { ( SCCID_MENUBASE + MENU_WP_SIZE_FITWIDTH ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_SIZE_FITWIDTH) },
  { ( SCCID_MENUBASE + MENU_WP_MODE ),                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_WP_MODE) },
  { ( SCCID_MENUBASE + MENU_VEC_SHOWFULL ),                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SHOWFULL) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_ORIGINAL ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_ORIGINAL) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_FITWINDOW ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_FITWINDOW) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_FITWIDTH ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_FITWIDTH) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_FITHEIGHT ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_FITHEIGHT) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_STRETCHWINDOW ),                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_STRETCHWINDOW) },
  { ( SCCID_MENUBASE + MENU_VEC_SIZE_BEST ),                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_SIZE_BEST) },
  { ( SCCID_MENUBASE + MENU_VEC_ZOOM_IN ),                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_ZOOM_IN) },
  { ( SCCID_MENUBASE + MENU_VEC_ZOOM_OUT ),                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_ZOOM_OUT) },
  { ( SCCID_MENUBASE + MENU_VEC_ZOOM_SELECTION ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_ZOOM_SELECTION) },
  { ( SCCID_MENUBASE + MENU_VEC_ZOOM_RESET ),                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_ZOOM_RESET) },
  { ( SCCID_MENUBASE + MENU_VEC_ZOOM ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_VEC_ZOOM) },
  { ( SCCID_MENUBASE + MENU_BMP_SHOWFULL ),                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SHOWFULL) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_PIXELS ),                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_PIXELS) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_FITWINDOW ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_FITWINDOW) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_FITWIDTH ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_FITWIDTH) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_FITHEIGHT ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_FITHEIGHT) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_BEST ),                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_BEST) },
  { ( SCCID_MENUBASE + MENU_BMP_SIZE_IMAGESIZE ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_SIZE_IMAGESIZE) },
  { ( SCCID_MENUBASE + MENU_BMP_ZOOM_IN ),                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ZOOM_IN) },
  { ( SCCID_MENUBASE + MENU_BMP_ZOOM_OUT ),                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ZOOM_OUT) },
  { ( SCCID_MENUBASE + MENU_BMP_ZOOM_SELECTION ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ZOOM_SELECTION) },
  { ( SCCID_MENUBASE + MENU_BMP_ZOOM_RESET ),                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ZOOM_RESET) },
  { ( SCCID_MENUBASE + MENU_BMP_ZOOM ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ZOOM) },
  { ( SCCID_MENUBASE + MENU_BMP_ROTATION ),                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ROTATION) },
  { ( SCCID_MENUBASE + MENU_BMP_ROTATION_NONE ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ROTATION_NONE) },
  { ( SCCID_MENUBASE + MENU_BMP_ROTATION_90 ),                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ROTATION_90) },
  { ( SCCID_MENUBASE + MENU_BMP_ROTATION_180 ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ROTATION_180) },
  { ( SCCID_MENUBASE + MENU_BMP_ROTATION_270 ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_ROTATION_270) },
  { ( SCCID_MENUBASE + MENU_BMP_DITHER ),                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_BMP_DITHER) },
  { ( SCCID_MENUBASE + MENU_ARC_SAVESELECTION ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_ARC_SAVESELECTION) },
  { ( SCCID_MENUBASE + MENU_ARC_SAVEALL ),                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_ARC_SAVEALL) },

  { ( SCCID_MENUBASE + MENU_SS_SHOWGRIDLINES ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_SS_SHOWGRIDLINES) },
  { ( SCCID_MENUBASE + MENU_DB_SHOWGRIDLINES ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_DB_SHOWGRIDLINES) },
  { ( SCCID_MENUBASE + MENU_SS_DRAFT ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_SS_DRAFT) },
  { ( SCCID_MENUBASE + MENU_SS_SHOWHIDDENCELLS ),                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_SS_SHOWHIDDENCELLS) },
  { ( SCCID_MENUBASE + MENU_OPTIONS ),                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_OPTIONS) },
  { ( SCCID_MENUBASE + MENU_OPTIONS_DISPLAY ),                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_OPTIONS_DISPLAY) },
  { ( SCCID_MENUBASE + MENU_OPTIONS_PRINT ),                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_OPTIONS_PRINT) },
  { ( SCCID_MENUBASE + MENU_OPTIONS_CLIPBOARD ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_OPTIONS_CLIPBOARD) },
  { ( SCCID_MENUBASE + MENU_NOMENU ),                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_NOMENU) },
  { ( SCCID_MENUBASE + MENU_COPY ),                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_COPY) },
  { ( SCCID_MENUBASE + MENU_PRINT ),                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_PRINT) },
  { ( SCCID_MENUBASE + MENU_FONTZOOM ),                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_FONTZOOM) },
  { ( SCCID_MENUBASE + MENU_FONTZOOM_ZOOM_IN ),                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_FONTZOOM_ZOOM_IN) },
  { ( SCCID_MENUBASE + MENU_FONTZOOM_ZOOM_OUT ),                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_FONTZOOM_ZOOM_OUT) },
  { ( SCCID_MENUBASE + MENU_FONTZOOM_ZOOM_RESET ),                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_FONTZOOM_ZOOM_RESET) },
  { ( SCCID_MENUBASE + MENU_SS_4DIGIT_DATES ),                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MENU_SS_4DIGIT_DATES) },

  { SCCID_HX_DOCCOMMENT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DOCCOMMENT) },
  { SCCID_HX_KEYWORD,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_KEYWORD) },
  { SCCID_HX_LASTSAVEDBY,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_LASTSAVEDBY) },
  { SCCID_HX_PRIMARYAUTHOR,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_PRIMARYAUTHOR) },
  { SCCID_HX_SUBJECT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBJECT) },
  { SCCID_HX_TITLE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_TITLE) },
  { SCCID_HX_ABSTRACT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ABSTRACT) },
  { SCCID_HX_ACCOUNT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ACCOUNT) },
  { SCCID_HX_ADDRESS,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ADDRESS) },
  { SCCID_HX_ATTACHMENTS,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ATTACHMENTS) },
  { SCCID_HX_AUTHORIZATION,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_AUTHORIZATION) },
  { SCCID_HX_BACKUPDATE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_BACKUPDATE) },
  { SCCID_HX_BILLTO,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_BILLTO) },
  { SCCID_HX_BLINDCOPY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_BLINDCOPY) },
  { SCCID_HX_CARBONCOPY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CARBONCOPY) },
  { SCCID_HX_CATEGORY,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CATEGORY) },
  { SCCID_HX_CHECKEDBY,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CHECKEDBY) },
  { SCCID_HX_CLIENT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CLIENT) },
  { SCCID_HX_COMPLETEDDATE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COMPLETEDDATE) },
  { SCCID_HX_COUNTCHARS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTCHARS) },
  { SCCID_HX_COUNTPAGES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTPAGES) },
  { SCCID_HX_COUNTWORDS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTWORDS) },
  { SCCID_HX_CREATIONDATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CREATIONDATE) },
  { SCCID_HX_DEPARTMENT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DEPARTMENT) },
  { SCCID_HX_DESTINATION,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DESTINATION) },
  { SCCID_HX_DISPOSITION,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DISPOSITION) },
  { SCCID_HX_DIVISION,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DIVISION) },
  { SCCID_HX_EDITMINUTES,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_EDITMINUTES) },
  { SCCID_HX_EDITOR,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_EDITOR) },
  { SCCID_HX_FORWARDTO,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_FORWARDTO) },
  { SCCID_HX_GROUP,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_GROUP) },
  { SCCID_HX_LANGUAGE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_LANGUAGE) },
  { SCCID_HX_LASTPRINTDATE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_LASTPRINTDATE) },
  { SCCID_HX_MAILSTOP,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MAILSTOP) },
  { SCCID_HX_MATTER,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MATTER) },
  { SCCID_HX_OFFICE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_OFFICE) },
  { SCCID_HX_OPERATOR,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_OPERATOR) },
  { SCCID_HX_OWNER,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_OWNER) },
  { SCCID_HX_PROJECT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_PROJECT) },
  { SCCID_HX_PUBLISHER,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_PUBLISHER) },
  { SCCID_HX_PURPOSE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_PURPOSE) },
  { SCCID_HX_RECEIVEDFROM,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_RECEIVEDFROM) },
  { SCCID_HX_RECORDEDBY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_RECORDEDBY) },
  { SCCID_HX_RECORDEDDATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_RECORDEDDATE) },
  { SCCID_HX_REFERENCE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_REFERENCE) },
  { SCCID_HX_REVISIONDATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_REVISIONDATE) },
  { SCCID_HX_REVISIONNOTES,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_REVISIONNOTES) },
  { SCCID_HX_REVISIONNUMBER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_REVISIONNUMBER) },
  { SCCID_HX_SECONDARYAUTHOR,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SECONDARYAUTHOR) },
  { SCCID_HX_SECTION,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SECTION) },
  { SCCID_HX_SECURITY,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SECURITY) },
  { SCCID_HX_SOURCE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SOURCE) },
  { SCCID_HX_STATUS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_STATUS) },
  { SCCID_HX_DOCTYPE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DOCTYPE) },
  { SCCID_HX_TYPIST,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_TYPIST) },
  { SCCID_HX_VERSIONDATE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_VERSIONDATE) },
  { SCCID_HX_VERSIONNOTES,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_VERSIONNOTES) },
  { SCCID_HX_VERSIONNUMBER,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_VERSIONNUMBER) },
  { SCCID_HX_BASEFILELOCATION,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_BASEFILELOCATION) },
  { SCCID_HX_MANAGER,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MANAGER) },
  { SCCID_HX_COMPANY,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COMPANY) },
  { SCCID_HX_EMPTYCELLS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_EMPTYCELLS) },
  { SCCID_HX_CELLLABELSEPARATOR,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_CELLLABELSEPARATOR) },
  { SCCID_HX_PRESENTATIONFORMAT,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_PRESENTATIONFORMAT)},
  { SCCID_HX_COUNTPARAS,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTPARAS)},
  { SCCID_HX_COUNTSLIDES,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTSLIDES)},
  { SCCID_HX_COUNTNOTES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTNOTES)},
  { SCCID_HX_COUNTSLIDESHIDDEN,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTSLIDESHIDDEN)},
  { SCCID_HX_COUNTMMCLIPS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTMMCLIPS)},
  { SCCID_HX_SCALECROP,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SCALECROP)},
  { SCCID_HX_LINKSDIRTY,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_LINKSDIRTY)},
  { SCCID_HX_COUNTBYTES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTBYTES)},
  { SCCID_HX_LASTSAVEDATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_LASTSAVEDATE)},
  { SCCID_HX_COUNTLINES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTLINES)},
  { SCCID_HX_COUNTCHARSWITHSPACES,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_COUNTCHARSWITHSPACES)},
  { SCCID_HX_DOCNUMBER,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_DOCNUMBER)},
  { SCCID_HX_HEADINGPAIRS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_HEADINGPAIRS)},
  { SCCID_HX_TITLEOFPARTS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_TITLEOFPARTS)},
  { SCCID_HX_APPVERSION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_APPVERSION)},
  { SCCID_HX_XMPNAMESPACE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_XMPNAMESPACE)},
  LO_FISTR_DEFINE(SCCID_HX_DOCTEMPLATE),

  { SCCID_HX_SUBDOC_AUTHOR,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_AUTHOR)},
  { SCCID_HX_SUBDOC_CREATEDATE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_CREATEDATE)},
  { SCCID_HX_SUBDOC_LASTSAVEDATE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_LASTSAVEDATE)},
  { SCCID_HX_SUBDOC_TITLE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_TITLE)},
  { SCCID_HX_SUBDOC_NOTES,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_NOTES)},
  { SCCID_HX_SUBDOC_AUTHORSHORT,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_SUBDOC_AUTHORSHORT)},
 
  { SCCID_HX_MSG_TITLE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_TITLE) },
  { SCCID_HX_MSG_STARTERR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_STARTERR) },
  { SCCID_HX_MSG_ERROR,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_ERROR) },
  { SCCID_HX_MSG_CHECKBELOW,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_CHECKBELOW) },
  { SCCID_HX_MSG_ANCHOR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_ANCHOR_U) },
  { SCCID_HX_MSG_SEEABOVE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_MSG_SEEABOVE) },

  { SCCID_HX_ARCTYPECONTAINER,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPECONTAINER) },
  { SCCID_HX_ARCTYPECOMPFILE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPECOMPFILE) },
  { SCCID_HX_ARCTYPEMESSAGE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPEMESSAGE) },
  { SCCID_HX_ARCTYPECONTACT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPECONTACT) },
  { SCCID_HX_ARCTYPECALENDAR,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPECALENDAR) },
  { SCCID_HX_ARCTYPENOTE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPENOTE) },
  { SCCID_HX_ARCTYPETASK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPETASK) },
  { SCCID_HX_ARCTYPEJOURNAL,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPEJOURNAL) },
  { SCCID_HX_ARCTYPEATTACH,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPEATTACH) },
  { SCCID_HX_ARCTYPEFIELDSFILE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_HX_ARCTYPEFIELDSFILE)},

  { SCCID_PST_SENDER,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_SENDER) },
  { SCCID_PST_RECIPIENT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_RECIPIENT) },
  { SCCID_PST_ATTENDEES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_ATTENDEES) },
  { SCCID_PST_OWNER,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_OWNER) },
  { SCCID_PST_SUBJECT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_SUBJECT) },
  { SCCID_PST_NAME,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_NAME) },
  { SCCID_PST_NONE,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_NONE) },
  { SCCID_PST_COMPANY_NAME,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_COMPANY_NAME) },
  { SCCID_PST_MINUTES,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_MINUTES) },
  { SCCID_PST_HOURS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_HOURS) },
  { SCCID_PST_NOT_STARTED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_NOT_STARTED) },
  { SCCID_PST_IN_PROGRESS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_IN_PROGRESS) },
  { SCCID_PST_COMPLETED,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_COMPLETED) },
  { SCCID_PST_WAITING,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_WAITING) },
  { SCCID_PST_DEFERRED,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_DEFERRED) },
  { SCCID_PST_PERCENT_COMPLETE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_PERCENT_COMPLETE) },
  { SCCID_PST_TOTAL_WORK,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_TOTAL_WORK) },
  { SCCID_PST_LOW,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_LOW) },
  { SCCID_PST_HIGH,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_HIGH) },
  { SCCID_PST_AM,                                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_AM) },
  { SCCID_PST_PM,                                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_PM) },
  { SCCID_PST_START_DATE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_START_DATE) },
  { SCCID_PST_DUE_DATE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_DUE_DATE) },
  { SCCID_PST_BILLING,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_BILLING) },
  { SCCID_PST_CONTACTS,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_CONTACTS) },
  { SCCID_PST_ENTRY_TYPE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_ENTRY_TYPE) },
  { SCCID_PST_COMPANY,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_COMPANY) },
  { SCCID_PST_CATEGORIES,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_CATEGORIES) },
  { SCCID_PST_MILEAGE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_MILEAGE) },
  { SCCID_PST_STATUS,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_STATUS) },
  { SCCID_PST_DAYS,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_DAYS) },
  {SCCID_PST_SENDER,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_SENDER)},
  {SCCID_PST_RECIPIENT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_RECIPIENT)},
  {SCCID_PST_ATTENDEES,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_ATTENDEES)},
  {SCCID_PST_MINUTES,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_MINUTES)},
  {SCCID_PST_HOURS,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_HOURS)},
  {SCCID_PST_WEEKS,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_WEEKS)},
  {SCCID_PST_COMPANY_NAME,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_COMPANY_NAME)},
  {SCCID_PST_ENTRYID,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PST_ENTRYID)},

  {SCCID_MSG_PRIVATE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSG_PRIVATE)},
  {SCCID_MSG_PERSONAL,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSG_PERSONAL)},
  {SCCID_MSG_CONFIDENTIAL,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MSG_CONFIDENTIAL)},

  /* Strings defined by Yahoo! IM */
  { SCCID_YIM_UKNCONT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_UKNCONT) },
  { SCCID_YIM_CHATDATE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_CHATDATE) },
  { SCCID_YIM_CHATWITH,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_CHATWITH) },
  { SCCID_YIM_YOURPRO,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_YOURPRO) },
  { SCCID_YIM_YMESS,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_YMESS) },
  { SCCID_YIM_JOINCONF,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_JOINCONF) },
  { SCCID_YIM_LEFTCONF,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_YIM_LEFTCONF) },

  /* Strings defined by ID3 - rf 8/10/05 */
  { SCCID_ID3_AENC,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_AENC) },
  { SCCID_ID3_APIC,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_APIC) },
  { SCCID_ID3_ASPI,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_ASPI) },
  { SCCID_ID3_COMM,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_COMM) },
  { SCCID_ID3_COMR,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_COMR) },
  { SCCID_ID3_ENCR,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_ENCR) },
  { SCCID_ID3_EQUA,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_EQUA) },
  { SCCID_ID3_EQU2,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_EQU2) },
  { SCCID_ID3_ETCO,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_ETCO) },
  { SCCID_ID3_GEOB,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_GEOB) },
  { SCCID_ID3_GRID,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_GRID) },
  { SCCID_ID3_IPLS,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_IPLS) },
  { SCCID_ID3_LINK,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_LINK) },
  { SCCID_ID3_MCDI,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_MCDI) },
  { SCCID_ID3_MLLT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_MLLT) },
  { SCCID_ID3_OWNE,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_OWNE) },
  { SCCID_ID3_PRIV,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_PRIV) },
  { SCCID_ID3_PCNT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_PCNT) },
  { SCCID_ID3_POPM,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_POPM) },
  { SCCID_ID3_POSS,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_POSS) },
  { SCCID_ID3_RBUF,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_RBUF) },
  { SCCID_ID3_RVAD,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_RVAD) },
  { SCCID_ID3_RVA2,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_RVA2) },
  { SCCID_ID3_RVRB,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_RVRB) },
  { SCCID_ID3_SEEK,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_SEEK) },
  { SCCID_ID3_SIGN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_SIGN) },
  { SCCID_ID3_SYLT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_SYLT) },
  { SCCID_ID3_SYTC,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_SYTC) },
  { SCCID_ID3_TALB,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TALB) },
  { SCCID_ID3_TBPM,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TBPM) },
  { SCCID_ID3_TCOM,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TCOM) },
  { SCCID_ID3_TCON,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TCON) },
  { SCCID_ID3_TCOP,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TCOP) },
  { SCCID_ID3_TDAT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TDAT) },
  { SCCID_ID3_TDLY,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TDLY) },
  { SCCID_ID3_TENC,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TENC) },
  { SCCID_ID3_TEXT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TEXT) },
  { SCCID_ID3_TFLT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TFLT) },
  { SCCID_ID3_TIME,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TIME) },
  { SCCID_ID3_TIPL,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TIPL) },
  { SCCID_ID3_TIT1,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TIT1) },
  { SCCID_ID3_TIT2,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TIT2) },
  { SCCID_ID3_TIT3,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TIT3) },
  { SCCID_ID3_TKEY,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TKEY) },
  { SCCID_ID3_TLAN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TLAN) },
  { SCCID_ID3_TLEN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TLEN) },
  { SCCID_ID3_TMCL,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TMCL) },
  { SCCID_ID3_TMOO,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TMOO) },
  { SCCID_ID3_TMED,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TMED) },
  { SCCID_ID3_TOAL,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TOAL) },
  { SCCID_ID3_TOFN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TOFN) },
  { SCCID_ID3_TOLY,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TOLY) },
  { SCCID_ID3_TOPE,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TOPE) },
  { SCCID_ID3_TORY,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TORY) },
  { SCCID_ID3_TOWN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TOWN) },
  { SCCID_ID3_TPE1,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPE1) },
  { SCCID_ID3_TPE2,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPE2) },
  { SCCID_ID3_TPE3,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPE3) },
  { SCCID_ID3_TPE4,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPE4) },
  { SCCID_ID3_TPOS,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPOS) },
  { SCCID_ID3_TPRO,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPRO) },
  { SCCID_ID3_TPUB,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TPUB) },
  { SCCID_ID3_TRCK,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TRCK) },
  { SCCID_ID3_TRDA,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TRDA) },
  { SCCID_ID3_TRSN,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TRSN) },
  { SCCID_ID3_TRSO,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TRSO) },
  { SCCID_ID3_TSIZ,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSIZ) },
  { SCCID_ID3_TSRC,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSRC) },
  { SCCID_ID3_TSOA,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSOA) },
  { SCCID_ID3_TSOP,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSOP) },
  { SCCID_ID3_TSOT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSOT) },
  { SCCID_ID3_TSSE,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSSE) },
  { SCCID_ID3_TSST,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TSST) },
  { SCCID_ID3_TYER,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_TYER) },
  { SCCID_ID3_UFID,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_UFID) },
  { SCCID_ID3_USER,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_USER) },
  { SCCID_ID3_USLT,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_USLT) },
  { SCCID_ID3_WCOM,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WCOM) },
  { SCCID_ID3_WCOP,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WCOP) },
  { SCCID_ID3_WOAF,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WOAF) },
  { SCCID_ID3_WOAR,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WOAR) },
  { SCCID_ID3_WOAS,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WOAS) },
  { SCCID_ID3_WORS,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WORS) },
  { SCCID_ID3_WPAY,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WPAY) },
  { SCCID_ID3_WPUB,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ID3_WPUB) },

  /* Strings defined by charts in Office 2007 */
  { SCCID_CHART_TITLE,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_CHART_TITLE) },
  { SCCID_CHART_AXISTITLE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_CHART_AXISTITLE) },
  { SCCID_CHART_SERIES,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_CHART_SERIES) },

  /* Strings defined by PDF */
  { SCCID_PDF_PORTFOLIO_CONTENTDIRECTORY,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PDF_PORTFOLIO_CONTENTDIRECTORY) },
  { SCCID_PDF_PORTFOLIO_HOMEDIRECTORY,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PDF_PORTFOLIO_HOMEDIRECTORY) },

  /* Multimedia document property strings - fw 4/22/09 */
  { SCCID_MULTIMEDIA_ALBUM,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ALBUM) },
  { SCCID_MULTIMEDIA_ARRANGER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ARRANGER) },
  { SCCID_MULTIMEDIA_ARTIST,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ARTIST) },
  { SCCID_MULTIMEDIA_AUTHOR,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_AUTHOR) },
  { SCCID_MULTIMEDIA_CHAPTER,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_CHAPTER) },
  { SCCID_MULTIMEDIA_COMMENT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_COMMENT) },
  { SCCID_MULTIMEDIA_COMPOSER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_COMPOSER) },
  { SCCID_MULTIMEDIA_COPYRIGHT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_COPYRIGHT) },
  { SCCID_MULTIMEDIA_CREATIONDATE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_CREATIONDATE) },
  { SCCID_MULTIMEDIA_DESCRIPTION,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_DESCRIPTION) },
  { SCCID_MULTIMEDIA_DIRECTOR,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_DIRECTOR) },
  { SCCID_MULTIMEDIA_DISCLAIMER,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_DISCLAIMER) },
  { SCCID_MULTIMEDIA_EDITDATEDESCRIPTION,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_EDITDATEDESCRIPTION) },
  { SCCID_MULTIMEDIA_ENCODER,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ENCODER) },
  { SCCID_MULTIMEDIA_FORMAT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_FORMAT) },
  { SCCID_MULTIMEDIA_GENRE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_GENRE) },
  { SCCID_MULTIMEDIA_HOSTCOMPUTER,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_HOSTCOMPUTER) },
  { SCCID_MULTIMEDIA_INFO,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_INFO) },
  { SCCID_MULTIMEDIA_ISRC,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ISRC) },
  { SCCID_MULTIMEDIA_RECORDLABEL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RECORDLABEL) },
  { SCCID_MULTIMEDIA_RECORDLABELURL,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RECORDLABELURL) },
  { SCCID_MULTIMEDIA_FILECREATOR,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_FILECREATOR) },
  { SCCID_MULTIMEDIA_FILECREATORURL,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_FILECREATORURL) },
  { SCCID_MULTIMEDIA_MODEL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_MODEL) },
  { SCCID_MULTIMEDIA_TITLE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_TITLE) },
  { SCCID_MULTIMEDIA_ORIGINALARTIST,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ORIGINALARTIST) },
  { SCCID_MULTIMEDIA_RECORDINGCOPYRIGHT,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RECORDINGCOPYRIGHT) },
  { SCCID_MULTIMEDIA_PRODUCER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PRODUCER) },
  { SCCID_MULTIMEDIA_PERFORMER,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PERFORMER) },
  { SCCID_MULTIMEDIA_PERFORMERURL,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PERFORMERURL) },
  { SCCID_MULTIMEDIA_PRODUCT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PRODUCT) },
  { SCCID_MULTIMEDIA_HWSWREQS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_HWSWREQS) },
  { SCCID_MULTIMEDIA_SUBTITLE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SUBTITLE) },
  { SCCID_MULTIMEDIA_SOURCECREDITS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SOURCECREDITS) },
  { SCCID_MULTIMEDIA_SONGWRITER,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SONGWRITER) },
  { SCCID_MULTIMEDIA_SOFTWARE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SOFTWARE) },
  { SCCID_MULTIMEDIA_TRACK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_TRACK) },
  { SCCID_MULTIMEDIA_WARNING,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_WARNING) },
  { SCCID_MULTIMEDIA_WRITER,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_WRITER) },
  { SCCID_MULTIMEDIA_URL,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_URL) },
  { SCCID_MULTIMEDIA_WIDTH,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_WIDTH) },
  { SCCID_MULTIMEDIA_HEIGHT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_HEIGHT) },
  { SCCID_MULTIMEDIA_RATING,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RATING) },
  { SCCID_MULTIMEDIA_ENCODERDESCRIPTION,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ENCODERDESCRIPTION) },
  { SCCID_MULTIMEDIA_KEYWORDS,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_KEYWORDS) },
  { SCCID_MULTIMEDIA_RELATED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RELATED) },
  { SCCID_MULTIMEDIA_CREATIONTIME,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_CREATIONTIME) },
  { SCCID_MULTIMEDIA_MANUFACTURER,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_MANUFACTURER) },
  { SCCID_MULTIMEDIA_ARCHIVE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ARCHIVE) },
  { SCCID_MULTIMEDIA_COMMISSIONEDBY,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_COMMISSIONEDBY) },
  { SCCID_MULTIMEDIA_CROPPED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_CROPPED) },
  { SCCID_MULTIMEDIA_DIMENSIONS,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_DIMENSIONS) },
  { SCCID_MULTIMEDIA_RESOLUTION,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_RESOLUTION) },
  { SCCID_MULTIMEDIA_ENGINEER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_ENGINEER) },
  { SCCID_MULTIMEDIA_LIGHTNESS,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_LIGHTNESS) },
  { SCCID_MULTIMEDIA_MEDIUM,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_MEDIUM) },
  { SCCID_MULTIMEDIA_PALETTE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PALETTE) },
  { SCCID_MULTIMEDIA_SUBJECT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SUBJECT) },
  { SCCID_MULTIMEDIA_SHARPNESS,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SHARPNESS) },
  { SCCID_MULTIMEDIA_SOURCEFORM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SOURCEFORM) },
  { SCCID_MULTIMEDIA_TECHNICIAN,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_TECHNICIAN) },
  { SCCID_MULTIMEDIA_NUMBEROFCHANNELS,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_NUMBEROFCHANNELS) },
  { SCCID_MULTIMEDIA_SAMPLINGRATE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_SAMPLINGRATE) },
  { SCCID_MULTIMEDIA_GROUPING,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_GROUPING) },
  { SCCID_MULTIMEDIA_CATEGORY,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_CATEGORY) },
  { SCCID_MULTIMEDIA_LYRICS,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_LYRICS) },
  { SCCID_MULTIMEDIA_TVNETWORK,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_TVNETWORK) },
  { SCCID_MULTIMEDIA_TVSHOW,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_TVSHOW) },
  { SCCID_MULTIMEDIA_EPISODE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_EPISODE) },
  { SCCID_MULTIMEDIA_PURCHASEDATE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_MULTIMEDIA_PURCHASEDATE) },

  /* Strings defined by PP97*/
  { SCCID_PP97_FIRST_SLIDE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_FIRST_SLIDE) },
  { SCCID_PP97_TITLE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_TITLE) },
  { SCCID_PP97_SUBTITLE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_SUBTITLE) },
  { SCCID_PP97_CLIPART,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_CLIPART) },
  { SCCID_PP97_OBJECT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_OBJECT) },
  { SCCID_PP97_CHART,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_CHART) },
  { SCCID_PP97_TABLE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_TABLE) },
  { SCCID_PP97_ORGCHART,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_ORGCHART) },
  { SCCID_PP97_MEDIACLIP,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_MEDIACLIP) },
  { SCCID_PP97_TEXT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_PP97_TEXT) },

  /* Error messages */
  { SCCID_ERR_OK,                                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OK) },
  { SCCID_ERR_UNKNOWN,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_UNKNOWN) },
  { SCCID_ERR_BADPARAM,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADPARAM) },
  { SCCID_ERR_ABORT,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ABORT) },
  { SCCID_ERR_CANCEL,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CANCEL) },
  { SCCID_ERR_NOINIT,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOINIT) },
  { SCCID_ERR_MACINITFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MACINITFAILED) },
  { SCCID_ERR_MESSAGEHANDLED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MESSAGEHANDLED) },
  { SCCID_ERR_NOITEM,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOITEM) },
  { SCCID_ERR_NONEFOUND,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NONEFOUND) },
  { SCCID_ERR_MORE,                                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MORE) },
  { SCCID_ERR_NOTHANDLED,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOTHANDLED) },
  { SCCID_ERR_SYSTEM,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_SYSTEM) },
  { SCCID_ERR_PROCCREATE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PROCCREATE) },
  { SCCID_ERR_PROCDESTROY,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PROCDESTROY) },
  { SCCID_ERR_PROCTIMEOUT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PROCTIMEOUT) },
  { SCCID_ERR_ASSERTIONFAILED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ASSERTIONFAILED) },
  { SCCID_ERR_DEBUGERROR,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DEBUGERROR) },
  { SCCID_ERR_NOCHANGE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOCHANGE) },
  { SCCID_ERR_DISPLAYOPENFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DISPLAYOPENFAILED) },
  { SCCID_ERR_ALLOCFAILED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ALLOCFAILED) },
  { SCCID_ERR_OUTOFMEMORY,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OUTOFMEMORY) },
  { SCCID_ERR_INSUFFICIENTBUFFER,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INSUFFICIENTBUFFER) },
  { SCCID_ERR_MEMORYLEAK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MEMORYLEAK) },
  { SCCID_ERR_MEMTABLEFULL,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MEMTABLEFULL) },
  { SCCID_ERR_INVALIDHANDLE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDHANDLE) },
  { SCCID_ERR_NULLHANDLE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NULLHANDLE) },
  { SCCID_ERR_LOCKEDHANDLE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LOCKEDHANDLE) },
  { SCCID_ERR_UNLOCKEDHANDLE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_UNLOCKEDHANDLE) },
  { SCCID_ERR_NOFILE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOFILE) },
  { SCCID_ERR_FILEOPENFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILEOPENFAILED) },
  { SCCID_ERR_SUPFILEOPENFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_SUPFILEOPENFAILED) },
  { SCCID_ERR_BADFILE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADFILE) },
  { SCCID_ERR_EMPTYFILE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EMPTYFILE) },
  { SCCID_ERR_PROTECTEDFILE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PROTECTEDFILE) },
  { SCCID_ERR_DRMFILE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DRMFILE) },
  { SCCID_ERR_UNSUPPORTEDCOMPRESSION,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_UNSUPPORTEDCOMPRESSION) },
  { SCCID_ERR_FILECREATE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILECREATE) },
  { SCCID_ERR_FILECHANGED,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILECHANGED) },
  { SCCID_ERR_FILEWRITEFAILED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILEWRITEFAILED) },
  { SCCID_ERR_EOF,                                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EOF) },
  { SCCID_ERR_INVALIDFILEHANDLE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDFILEHANDLE) },
  { SCCID_ERR_OPENINPUTFAILED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OPENINPUTFAILED) },
  { SCCID_ERR_FILECOPYFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILECOPYFAILED) },
  { SCCID_ERR_FILENOTAVAILABLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILENOTAVAILABLE) },
  { SCCID_ERR_RECORDDELETED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_RECORDDELETED) },
  { SCCID_ERR_INVALIDPATH,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDPATH) },
  { SCCID_ERR_INVALIDSPEC,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDSPEC) },
  { SCCID_ERR_BADINFOID,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADINFOID) },
  { SCCID_ERR_SEEKOUTOFRANGE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_SEEKOUTOFRANGE) },
  { SCCID_ERR_INVALIDID,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDID) },
  { SCCID_ERR_UNSUPPORTEDFORMAT,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_UNSUPPORTEDFORMAT) },
  { SCCID_ERR_NOFILTER,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOFILTER) },
  { SCCID_ERR_FILTERLOADFAILED,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERLOADFAILED) },
  { SCCID_ERR_FILTERALLOCFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERALLOCFAILED) },
  { SCCID_ERR_FILTERTIMEOUT,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERTIMEOUT) },
  { SCCID_ERR_FILTEREXCEPTACCESS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTEREXCEPTACCESS) },
  { SCCID_ERR_FILTEREXCEPTZERO,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTEREXCEPTZERO) },
  { SCCID_ERR_FILTEREXCEPTOTHER,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTEREXCEPTOTHER) },
  { SCCID_ERR_FILTERSCRAMBLEERROR,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERSCRAMBLEERROR) },
  { SCCID_ERR_FILTERTILEMAXEXCEEDED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERTILEMAXEXCEEDED) },
  { SCCID_ERR_NODISPLAYENGINE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODISPLAYENGINE) },
  { SCCID_ERR_NODATATORENDER,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODATATORENDER) },
  { SCCID_ERR_DISPLAYINITFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DISPLAYINITFAILED) },
  { SCCID_ERR_CHUNKERINITFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKERINITFAILED) },
  { SCCID_ERR_CHUNKERFAILURE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKERFAILURE) },
  { SCCID_ERR_DATANOTAVAILABLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DATANOTAVAILABLE) },
  { SCCID_ERR_VIEWERBAIL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_VIEWERBAIL) },
  { SCCID_ERR_CHARMAPFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHARMAPFAILED) },
  { SCCID_ERR_LASTPAGE,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LASTPAGE) },
  { SCCID_ERR_NOPAGE,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOPAGE) },
  { SCCID_ERR_OTHERPRINTING,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OTHERPRINTING) },
  { SCCID_ERR_FEATURENOTAVAIL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FEATURENOTAVAIL) },
  { SCCID_ERR_RAWTEXTDISABLED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_RAWTEXTDISABLED) },
  { SCCID_ERR_OUTPUT_SOL_MISSING,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OUTPUT_SOL_MISSING) },
  { SCCID_ERR_DATAREMOTEERROR,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DATAREMOTEERROR) },
  { SCCID_ERR_EXCEPTION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPTION) },
  { SCCID_ERR_EXCEPT_ACCESSVIOLATION,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_ACCESSVIOLATION) },
  { SCCID_ERR_EXCEPT_BREAKPOINT,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_BREAKPOINT) },
  { SCCID_ERR_EXCEPT_DATATYPEMISALIGNMENT,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_DATATYPEMISALIGNMENT) },
  { SCCID_ERR_EXCEPT_SINGLESTEP,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_SINGLESTEP) },
  { SCCID_ERR_EXCEPT_ARRAYBOUNDSEXCEEDED,              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_ARRAYBOUNDSEXCEEDED) },
  { SCCID_ERR_EXCEPT_FPDENORMALOPERAND,                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPDENORMALOPERAND) },
  { SCCID_ERR_EXCEPT_FPDIVIDEBYZERO,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPDIVIDEBYZERO) },
  { SCCID_ERR_EXCEPT_FPINEXACTRESULT,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPINEXACTRESULT) },
  { SCCID_ERR_EXCEPT_FPINVALIDOPERATION,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPINVALIDOPERATION) },
  { SCCID_ERR_EXCEPT_FPOVERFLOW,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPOVERFLOW) },
  { SCCID_ERR_EXCEPT_FPSTACKCHECK,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPSTACKCHECK) },
  { SCCID_ERR_EXCEPT_FPUNDERFLOW,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_FPUNDERFLOW) },
  { SCCID_ERR_EXCEPT_INTDIVIDEBYZERO,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_INTDIVIDEBYZERO) },
  { SCCID_ERR_EXCEPT_INTOVERFLOW,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_INTOVERFLOW) },
  { SCCID_ERR_EXCEPT_PRIVINSTRUCTION,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_PRIVINSTRUCTION) },
  { SCCID_ERR_EXCEPT_NONCONTINUABLE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_NONCONTINUABLE) },
  { SCCID_ERR_EXCEPT_UNKNOWN,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXCEPT_UNKNOWN) },
  { SCCID_ERR_TESTNOTAVAILABLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TESTNOTAVAILABLE) },
  { SCCID_ERR_TESTTIMEOUT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TESTTIMEOUT) },
  { SCCID_ERR_CREATEBINFAILED,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CREATEBINFAILED) },
  { SCCID_ERR_OPENBINFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OPENBINFAILED) },
  { SCCID_ERR_WRITEBINFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_WRITEBINFAILED) },
  { SCCID_ERR_READBINFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_READBINFAILED) },
  { SCCID_ERR_OPENDUMPFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OPENDUMPFAILED) },
  { SCCID_ERR_COMPAREFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMPAREFAILED) },
  { SCCID_ERR_CHUNKERRUNMISMATCH,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKERRUNMISMATCH) },
  { SCCID_ERR_CHUNKERSIZEMISMATCH,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKERSIZEMISMATCH) },
  { SCCID_ERR_CHUNKERFAILED,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKERFAILED) },
  { SCCID_ERR_CHUNKEROVERRUN,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHUNKEROVERRUN) },
  { SCCID_ERR_COMPRESSIONFAILED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMPRESSIONFAILED) },
  { SCCID_ERR_STREAMBAIL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_STREAMBAIL) },
  { SCCID_ERR_MISSINGELEMENT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_MISSINGELEMENT) },
  { SCCID_ERR_TESTCOMPLETE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TESTCOMPLETE) },
  { SCCID_ERR_TESTMODESWITCH,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TESTMODESWITCH) },
  { SCCID_ERR_BASELINEFILENOTFOUND,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BASELINEFILENOTFOUND) },
  { SCCID_ERR_COMPAREFILENOTFOUND,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMPAREFILENOTFOUND) },
  { SCCID_ERR_TECHNOTAVAILABLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TECHNOTAVAILABLE) },
  { SCCID_ERR_TESTFILESEMPTY,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_TESTFILESEMPTY) },
  { SCCID_ERR_INVALIDRESPONSE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDRESPONSE) },
  { SCCID_ERR_COMMTIMEOUT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMMTIMEOUT) },
  { SCCID_ERR_COMMUNKNOWN,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMMUNKNOWN) },
  { SCCID_ERR_CONNECTIONREFUSED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CONNECTIONREFUSED) },
  { SCCID_ERR_COMMFAULT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMMFAULT) },
  { SCCID_ERR_CONNECTIONDOWN,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CONNECTIONDOWN) },
  { SCCID_ERR_CONNECTIONUNREACHABLE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CONNECTIONUNREACHABLE) },
  { SCCID_ERR_DISCONNECTED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DISCONNECTED) },
  { SCCID_ERR_SYNCHRONIZE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_SYNCHRONIZE) },
  { SCCID_ERR_GPFAULT,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_GPFAULT) },
  { SCCID_ERR_DIVIDEBYZERO,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DIVIDEBYZERO) },
  { SCCID_ERR_OTHEREXCEPTION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OTHEREXCEPTION) },
  { SCCID_ERR_HX_GENERAL,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_GENERAL) },
  { SCCID_ERR_HX_TREE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TREE) },
  { SCCID_ERR_HX_INVALIDVAL,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDVAL) },
  { SCCID_ERR_HX_NONE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NONE) },
  { SCCID_ERR_HX_ENDMACRO,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ENDMACRO) },
  { SCCID_ERR_HX_START,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_START) },
  { SCCID_ERR_HX_EQ,                                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_EQ) },
  { SCCID_ERR_HX_END,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_END) },
  { SCCID_ERR_HX_ACTION,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ACTION) },
  { SCCID_ERR_HX_SECTION,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_SECTION) },
  { SCCID_ERR_HX_ELEMENT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ELEMENT) },
  { SCCID_ERR_HX_LINK,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_LINK) },
  { SCCID_ERR_HX_TAG,                                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TAG) },
  { SCCID_ERR_HX_TEMPLATE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TEMPLATE) },
  { SCCID_ERR_HX_TYPE,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TYPE) },
  { SCCID_ERR_HX_TYPENAME,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TYPENAME) },
  { SCCID_ERR_HX_DEFINE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_DEFINE) },
  { SCCID_ERR_HX_DOCUMENT,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_DOCUMENT) },
  { SCCID_ERR_HX_GENLINK,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_GENLINK) },
  { SCCID_ERR_HX_INSERT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INSERT) },
  { SCCID_ERR_HX_REPEAT,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_REPEAT) },
  { SCCID_ERR_HX_ALLOC,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ALLOC) },
  { SCCID_ERR_HX_INVALIDCMD,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDCMD) },
  { SCCID_ERR_HX_INVALIDERRNUM,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDERRNUM) },
  { SCCID_ERR_HX_HANDLEELEM,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_HANDLEELEM) },
  { SCCID_ERR_HX_ASISOUTTEXT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ASISOUTTEXT) },
  { SCCID_ERR_HX_OUTTEXT,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_OUTTEXT) },
  { SCCID_ERR_HX_NOTEMPLATE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOTEMPLATE) },
  { SCCID_ERR_HX_OUTFILEFAIL,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_OUTFILEFAIL) },
  { SCCID_ERR_HX_NOENDREPEAT,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOENDREPEAT) },
  { SCCID_ERR_HX_NOENDIF,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOENDIF) },
  { SCCID_ERR_HX_NOENDIGNORE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOENDIGNORE) },
  { SCCID_ERR_HX_NONREPEAT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NONREPEAT) },
  { SCCID_ERR_HX_REPEATENDONINDEX,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_REPEATENDONINDEX) },
  { SCCID_ERR_HX_IFENDONINDEX,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_IFENDONINDEX) },
  { SCCID_ERR_HX_INSERTENDONINDEX,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INSERTENDONINDEX) },
  { SCCID_ERR_HX_NOELEMENT,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOELEMENT) },
  { SCCID_ERR_HX_NOSTARTTAG,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOSTARTTAG) },
  { SCCID_ERR_HX_INVALIDTYPE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDTYPE) },
  { SCCID_ERR_HX_NOVALUE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOVALUE) },
  { SCCID_ERR_HX_NOCONDITION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOCONDITION) },
  { SCCID_ERR_HX_INVALIDLINKPARAM,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDLINKPARAM) },
  { SCCID_ERR_HX_NOLINKPARAM,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOLINKPARAM) },
  { SCCID_ERR_HX_BADCOUNTORVALUE,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_BADCOUNTORVALUE) },
  { SCCID_ERR_HX_INVALIDELSE,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDELSE) },
  { SCCID_ERR_HX_INVALIDCOND,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDCOND) },
  { SCCID_ERR_HX_TEMPLATECREATE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TEMPLATECREATE) },
  { SCCID_ERR_HX_MAXELEMSPASSED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_MAXELEMSPASSED) },
  { SCCID_ERR_HX_NOTYPE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NOTYPE) },
  { SCCID_ERR_HX_CUSTOMELEMENT,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_CUSTOMELEMENT) },
  { SCCID_ERR_HX_INVALIDELSEIF,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDELSEIF) },
  { SCCID_ERR_HX_CSSPRAGMA,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_CSSPRAGMA) },
  { SCCID_ERR_HX_ANCHOR,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_ANCHOR) },
  { SCCID_ERR_HX_LABEL,                                SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_LABEL) },
  { SCCID_ERR_HX_DECKSIZEEXCEEDED,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_DECKSIZEEXCEEDED) },
  { SCCID_ERR_HX_UNSUPPORTEDMACRO,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_UNSUPPORTEDMACRO) },
  { SCCID_ERR_HX_NONBREAKINGREPEAT,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NONBREAKINGREPEAT) },
  { SCCID_ERR_HX_NONBREAKINGTEMPLATE,                  SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_NONBREAKINGTEMPLATE) },
  { SCCID_ERR_HX_INVALIDATTRIBUTE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDATTRIBUTE) },
  { SCCID_ERR_HX_INVALIDATTRIBVALUE,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INVALIDATTRIBVALUE) },
  { SCCID_ERR_HX_MALFORMEDUNIT,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_MALFORMEDUNIT) },
  { SCCID_ERR_HX_TEXTBUFFERTOOSMALL,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TEXTBUFFERTOOSMALL) },
  { SCCID_ERR_HX_BUFFERTOOSMALLFORGRAPHICS,            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_BUFFERTOOSMALLFORGRAPHICS) },
  { SCCID_ERR_HX_INTERNALEXPORTFILTER,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALEXPORTFILTER) },
  { SCCID_ERR_HX_TEMPLATEPARSE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_TEMPLATEPARSE) },
  { SCCID_ERR_HX_OUTPUTFILE,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_OUTPUTFILE) },
  { SCCID_ERR_HX_INTERNALELEMENT,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALELEMENT) },
  { SCCID_ERR_HX_INTERNALDOCUMENT,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALDOCUMENT) },
  { SCCID_ERR_HX_INTERNALPREVIEW,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALPREVIEW) },
  { SCCID_ERR_HX_INTERNALPROCESS,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALPROCESS) },
  { SCCID_ERR_HX_INTERNALEXLM,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALEXLM) },
  { SCCID_ERR_HX_INTERNALEXMU,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALEXMU) },
  { SCCID_ERR_HX_INTERNALPARA,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALPARA) },
  { SCCID_ERR_HX_INTERNALSTYLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALSTYLE) },
  { SCCID_ERR_HX_INTERNALTABLE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALTABLE) },
  { SCCID_ERR_HX_INTERNALGRAPHICS,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALGRAPHICS) },
  { SCCID_ERR_HX_INTERNALTAGID,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALTAGID) },
  { SCCID_ERR_HX_INTERNALLOCATIONID,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALLOCATIONID) },
  { SCCID_ERR_HX_INTERNALSSCELL,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALSSCELL) },
  { SCCID_ERR_HX_INTERNALEMPTYSHEET,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_INTERNALEMPTYSHEET) },
  { SCCID_ERR_HX_SECTNODATA,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_HX_SECTNODATA)},

  { SCCID_ERR_IX_STARTPAGE,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_IX_STARTPAGE)},
  { SCCID_ERR_IX_ENDPAGE,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_IX_ENDPAGE)},
  { SCCID_ERR_COMPRESSION_DISABLED,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_COMPRESSION_DISABLED)},
  { SCCID_ERR_OLESTORAGENOTSUPPORTED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OLESTORAGENOTSUPPORTED)},
  { SCCID_ERR_CHARMAPBIN_NOFILE,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_CHARMAPBIN_NOFILE)},

  { SCCID_ERR_ANNOLOAD,                                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ANNOLOAD)},
  { SCCID_ERR_ANNOFUNCTION,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ANNOFUNCTION)},
  { SCCID_ERR_OSGD_NOFONTS,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OSGD_NOFONTS)},
  { SCCID_ERR_BADFILENAME,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADFILENAME)},
  { SCCID_ERR_EXTERNALURLREFERENCE,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EXTERNALURLREFERENCE)},
  { SCCID_ERR_LINKTOFILE,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LINKTOFILE)},

  { SCCID_ERR_NOHTMLEXPORTFILTER,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOHTMLEXPORTFILTER) },
  { SCCID_ERR_NOGRAPHICEXPORTFILTER,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOGRAPHICEXPORTFILTER) },
  { SCCID_ERR_OUTPUTSOLUTION_LOADFAILED,               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OUTPUTSOLUTION_LOADFAILED) },

  { SCCID_ERR_IX_WATERMARKWILLNOTFITTARGET,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_IX_WATERMARKWILLNOTFITTARGET)},
  { SCCID_ERR_IX_WATERMARKTYPENOTSUPPORTED,             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_IX_WATERMARKTYPENOTSUPPORTED)},
  { SCCID_ERR_INVALIDFONTDIR,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDFONTDIR)},

  { SCCID_ERR_OCRMISSING,                              SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCRMISSING)},
  { SCCID_ERR_OCR_UNKNOWNERR,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_UNKNOWNERR)},
  { SCCID_ERR_OCR_LICENCEFAIL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_LICENCEFAIL)},
  { SCCID_ERR_OCR_INVALIDTECH,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INVALIDTECH)},
  { SCCID_ERR_OCR_INVALIDQUAL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INVALIDQUAL)},
  { SCCID_ERR_OCR_LOADFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_LOADFAILED)},
  { SCCID_ERR_OCR_INPUTFAILURE,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INPUTFAILURE)},

  { SCCID_ERR_INSUFFICIENTPRINTABLEPAGEHEIGHT,         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INSUFFICIENTPRINTABLEPAGEHEIGHT)},
  { SCCID_ERR_INSUFFICIENTPRINTABLEPAGEWIDTH,          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INSUFFICIENTPRINTABLEPAGEWIDTH)},

    { SCCID_ERR_OCRMISSING, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCRMISSING)},
    { SCCID_ERR_OCR_UNKNOWNERR, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_UNKNOWNERR)},
    { SCCID_ERR_OCR_LICENCEFAIL, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_LICENCEFAIL)},
    { SCCID_ERR_OCR_INVALIDTECH, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INVALIDTECH)},
    { SCCID_ERR_OCR_INVALIDQUAL, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INVALIDQUAL)},
    { SCCID_ERR_OCR_LOADFAILED, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_LOADFAILED)},
    { SCCID_ERR_OCR_INPUTFAILURE, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_OCR_INPUTFAILURE)},

    {SCCID_ERR_NOTARCHIVEFILE, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOTARCHIVEFILE)},
    {SCCID_ERR_NOTSUPPORTEDARCHIVEFILE, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOTSUPPORTEDARCHIVEFILE)},
    {SCCID_ERR_INVALIDHDOC, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_INVALIDHDOC)},
    {SCCID_ERR_BADCREDENTIAL, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADCREDENTIAL)},
    {SCCID_ERR_FILESIZE, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILESIZE)},

    { SCCID_ERR_FILTERGENERAL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILTERGENERAL)},
    { SCCID_ERR_FILEIDFAILED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_FILEIDFAILED)},
    { SCCID_ERR_EMPTYSECTION,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_EMPTYSECTION)},
    { SCCID_ERR_DISPLAYALLOCFAILED,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DISPLAYALLOCFAILED)},
    { SCCID_ERR_UNKNOWNNOTVIEWED,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_UNKNOWNNOTVIEWED)},
    { SCCID_ERR_NOPRINTER,                             SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOPRINTER)},
    { SCCID_ERR_PRINTERINITFAILED,                     SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PRINTERINITFAILED)},
    { SCCID_ERR_PRINTINGFAILED,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PRINTINGFAILED)},
    { SCCID_ERR_BADPRINTERDC,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_BADPRINTERDC)},
    { SCCID_ERR_NOPRINTDEVICE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOPRINTDEVICE)},
    { SCCID_ERR_NOPRINTDIALOG,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NOPRINTDIALOG)},
    { SCCID_ERR_PRINTERSTARTDOCFAILED,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_PRINTERSTARTDOCFAILED)},
    { SCCID_ERR_LOBADID,                               SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LOBADID)},
    { SCCID_ERR_LONOSTRING,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LONOSTRING)},
    { SCCID_ERR_LOLIBLINKFAIL,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LOLIBLINKFAIL)},
    { SCCID_ERR_LOINITLINKFAIL,                        SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LOINITLINKFAIL)},
    { SCCID_ERR_LOGETSTRINGLINKFAIL,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LOGETSTRINGLINKFAIL)},
    { SCCID_ERR_LODEINITLINKFAIL,                      SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LODEINITLINKFAIL)},
    { SCCID_ERR_LONOCREATE,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LONOCREATE)},
    { SCCID_ERR_LODODIALOG,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LODODIALOG)},
    { SCCID_ERR_LODOACTION,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_LODOACTION)},
    { SCCID_ERR_NULLPOINTER,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NULLPOINTER)},
    { SCCID_ERR_NODERELEASED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODERELEASED)},
    { SCCID_ERR_NODEATTACHED,                          SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODEATTACHED)},
    { SCCID_ERR_NODENOTATTACHED,                       SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODENOTATTACHED)},
    { SCCID_ERR_ALLCHILDRENATTACHED,                   SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_ALLCHILDRENATTACHED)},
    { SCCID_ERR_NODEATTRIBUTESDONE,                    SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODEATTRIBUTESDONE)},
    { SCCID_ERR_DUPLICATEID,                           SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DUPLICATEID)},
    { SCCID_ERR_IDASSIGNED,                            SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_IDASSIGNED)},
    { SCCID_ERR_NODEATTRIBUTESNOTDONE,                 SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_NODEATTRIBUTESNOTDONE)},
    { SCCID_ERR_DIFFERENTTREE,                         SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ERR_DIFFERENTTREE)},

    {SCCID_XMP_NAMESPACE, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_XMP_NAMESPACE)},
    {SCCID_ACD2_ZOOMEXTENTSVIEW, SCC_CASTSTRING SCC_LOCALIZESTRING(STR_SCCID_ACD2_ZOOMEXTENTSVIEW)},

    /* ID 0xFFFFFFFF must be last - anything past it will never be accessed */
#if defined(_DARWIN_SOURCE)
  { 0xFFFFFFFF,                                        "", "" }
#else
  { 0xFFFFFFFF,                                        SCC_CASTSTRING "\0" }
#endif /* _DARWIN_SOURCE */
  };
